# This file is auto-generated by pyrandyos/gui/icons/update_from_spec.py  # noqa: E501
# Do not edit.
ic_fluent_access_time_20_filled = 57344
ic_fluent_access_time_20_regular = 57345
ic_fluent_accessibility_20_filled = 57346
ic_fluent_accessibility_20_regular = 57347
ic_fluent_accessibility_checkmark_20_filled = 57348
ic_fluent_accessibility_checkmark_20_regular = 57349
ic_fluent_accessibility_error_20_filled = 57350
ic_fluent_accessibility_error_20_regular = 57351
ic_fluent_accessibility_more_20_filled = 57352
ic_fluent_accessibility_more_20_regular = 57353
ic_fluent_accessibility_question_mark_20_filled = 57354
ic_fluent_accessibility_question_mark_20_regular = 57355
ic_fluent_add_20_filled = 57356
ic_fluent_add_20_regular = 57357
ic_fluent_add_circle_20_filled = 57358
ic_fluent_add_circle_20_regular = 57359
ic_fluent_add_square_20_filled = 57360
ic_fluent_add_square_20_regular = 57361
ic_fluent_add_square_multiple_20_filled = 57362
ic_fluent_add_square_multiple_20_regular = 57363
ic_fluent_add_starburst_20_filled = 57364
ic_fluent_add_starburst_20_regular = 57365
ic_fluent_add_subtract_circle_20_filled = 57366
ic_fluent_add_subtract_circle_20_regular = 57367
ic_fluent_agents_20_filled = 57368
ic_fluent_agents_20_regular = 57369
ic_fluent_agents_add_20_filled = 57370
ic_fluent_agents_add_20_regular = 57371
ic_fluent_airplane_20_filled = 57372
ic_fluent_airplane_20_regular = 57373
ic_fluent_airplane_landing_20_filled = 57374
ic_fluent_airplane_landing_20_regular = 57375
ic_fluent_airplane_take_off_20_filled = 57376
ic_fluent_airplane_take_off_20_regular = 57377
ic_fluent_album_20_filled = 57378
ic_fluent_album_20_regular = 57379
ic_fluent_album_add_20_filled = 57380
ic_fluent_album_add_20_regular = 57381
ic_fluent_alert_20_filled = 57382
ic_fluent_alert_20_regular = 57383
ic_fluent_alert_badge_20_filled = 57384
ic_fluent_alert_badge_20_regular = 57385
ic_fluent_alert_off_20_filled = 57386
ic_fluent_alert_off_20_regular = 57387
ic_fluent_alert_on_20_filled = 57388
ic_fluent_alert_on_20_regular = 57389
ic_fluent_alert_snooze_20_filled = 57390
ic_fluent_alert_snooze_20_regular = 57391
ic_fluent_alert_urgent_20_filled = 57392
ic_fluent_alert_urgent_20_regular = 57393
ic_fluent_align_bottom_20_filled = 57394
ic_fluent_align_bottom_20_regular = 57395
ic_fluent_align_center_horizontal_20_filled = 57396
ic_fluent_align_center_horizontal_20_regular = 57397
ic_fluent_align_center_vertical_20_filled = 57398
ic_fluent_align_center_vertical_20_regular = 57399
ic_fluent_align_end_horizontal_20_filled = 57400
ic_fluent_align_end_horizontal_20_regular = 57401
ic_fluent_align_end_vertical_20_filled = 57402
ic_fluent_align_end_vertical_20_regular = 57403
ic_fluent_align_left_20_filled = 57404
ic_fluent_align_left_20_regular = 57405
ic_fluent_align_right_20_filled = 57406
ic_fluent_align_right_20_regular = 57407
ic_fluent_align_space_around_horizontal_20_filled = 57408
ic_fluent_align_space_around_horizontal_20_regular = 57409
ic_fluent_align_space_around_vertical_20_filled = 57410
ic_fluent_align_space_around_vertical_20_regular = 57411
ic_fluent_align_space_between_horizontal_20_filled = 57412
ic_fluent_align_space_between_horizontal_20_regular = 57413
ic_fluent_align_space_between_vertical_20_filled = 57414
ic_fluent_align_space_between_vertical_20_regular = 57415
ic_fluent_align_space_evenly_horizontal_20_filled = 57416
ic_fluent_align_space_evenly_horizontal_20_regular = 57417
ic_fluent_align_space_evenly_vertical_20_filled = 57418
ic_fluent_align_space_evenly_vertical_20_regular = 57419
ic_fluent_align_space_fit_vertical_20_filled = 57420
ic_fluent_align_space_fit_vertical_20_regular = 57421
ic_fluent_align_start_horizontal_20_filled = 57422
ic_fluent_align_start_horizontal_20_regular = 57423
ic_fluent_align_start_vertical_20_filled = 57424
ic_fluent_align_start_vertical_20_regular = 57425
ic_fluent_align_straighten_20_filled = 57426
ic_fluent_align_straighten_20_regular = 57427
ic_fluent_align_stretch_horizontal_20_filled = 57428
ic_fluent_align_stretch_horizontal_20_regular = 57429
ic_fluent_align_stretch_vertical_20_filled = 57430
ic_fluent_align_stretch_vertical_20_regular = 57431
ic_fluent_align_top_20_filled = 57432
ic_fluent_align_top_20_regular = 57433
ic_fluent_animal_cat_20_filled = 57434
ic_fluent_animal_cat_20_regular = 57435
ic_fluent_animal_dog_20_filled = 57436
ic_fluent_animal_dog_20_regular = 57437
ic_fluent_animal_paw_print_20_filled = 57438
ic_fluent_animal_paw_print_20_regular = 57439
ic_fluent_animal_rabbit_20_filled = 57440
ic_fluent_animal_rabbit_20_regular = 57441
ic_fluent_animal_rabbit_off_20_filled = 57442
ic_fluent_animal_rabbit_off_20_regular = 57443
ic_fluent_animal_turtle_20_filled = 57444
ic_fluent_animal_turtle_20_regular = 57445
ic_fluent_app_folder_20_filled = 57446
ic_fluent_app_folder_20_regular = 57447
ic_fluent_app_generic_20_filled = 57448
ic_fluent_app_generic_20_regular = 57449
ic_fluent_app_recent_20_filled = 57450
ic_fluent_app_recent_20_regular = 57451
ic_fluent_app_title_20_filled = 57452
ic_fluent_app_title_20_regular = 57453
ic_fluent_approvals_app_20_filled = 57454
ic_fluent_approvals_app_20_regular = 57455
ic_fluent_apps_20_filled = 57456
ic_fluent_apps_20_regular = 57457
ic_fluent_apps_add_in_20_filled = 57458
ic_fluent_apps_add_in_20_regular = 57459
ic_fluent_apps_add_in_off_20_filled = 57460
ic_fluent_apps_add_in_off_20_regular = 57461
ic_fluent_apps_list_20_filled = 57462
ic_fluent_apps_list_20_regular = 57463
ic_fluent_apps_list_detail_20_filled = 57464
ic_fluent_apps_list_detail_20_regular = 57465
ic_fluent_apps_settings_20_filled = 57466
ic_fluent_apps_settings_20_regular = 57467
ic_fluent_apps_shield_20_filled = 57468
ic_fluent_apps_shield_20_regular = 57469
ic_fluent_archive_20_filled = 57470
ic_fluent_archive_20_regular = 57471
ic_fluent_archive_arrow_back_20_filled = 57472
ic_fluent_archive_arrow_back_20_regular = 57473
ic_fluent_archive_multiple_20_filled = 57474
ic_fluent_archive_multiple_20_regular = 57475
ic_fluent_archive_settings_20_filled = 57476
ic_fluent_archive_settings_20_regular = 57477
ic_fluent_arrow_autofit_content_20_filled = 57478
ic_fluent_arrow_autofit_content_20_regular = 57479
ic_fluent_arrow_autofit_down_20_filled = 57480
ic_fluent_arrow_autofit_down_20_regular = 57481
ic_fluent_arrow_autofit_height_20_filled = 57482
ic_fluent_arrow_autofit_height_20_regular = 57483
ic_fluent_arrow_autofit_height_dotted_20_filled = 57484
ic_fluent_arrow_autofit_height_dotted_20_regular = 57485
ic_fluent_arrow_autofit_height_in_20_filled = 57486
ic_fluent_arrow_autofit_height_in_20_regular = 57487
ic_fluent_arrow_autofit_up_20_filled = 57488
ic_fluent_arrow_autofit_up_20_regular = 57489
ic_fluent_arrow_autofit_width_20_filled = 57490
ic_fluent_arrow_autofit_width_20_regular = 57491
ic_fluent_arrow_autofit_width_dotted_20_filled = 57492
ic_fluent_arrow_autofit_width_dotted_20_regular = 57493
ic_fluent_arrow_between_down_20_filled = 57494
ic_fluent_arrow_between_down_20_regular = 57495
ic_fluent_arrow_between_up_20_filled = 57496
ic_fluent_arrow_between_up_20_regular = 57497
ic_fluent_arrow_bidirectional_left_right_20_filled = 57498
ic_fluent_arrow_bidirectional_left_right_20_regular = 57499
ic_fluent_arrow_bidirectional_up_down_20_filled = 57500
ic_fluent_arrow_bidirectional_up_down_20_regular = 57501
ic_fluent_arrow_bounce_20_filled = 57502
ic_fluent_arrow_bounce_20_regular = 57503
ic_fluent_arrow_circle_down_20_filled = 57504
ic_fluent_arrow_circle_down_20_regular = 57505
ic_fluent_arrow_circle_down_double_20_filled = 57506
ic_fluent_arrow_circle_down_double_20_regular = 57507
ic_fluent_arrow_circle_down_right_20_filled = 57508
ic_fluent_arrow_circle_down_right_20_regular = 57509
ic_fluent_arrow_circle_down_split_20_filled = 57510
ic_fluent_arrow_circle_down_split_20_regular = 57511
ic_fluent_arrow_circle_down_up_20_filled = 57512
ic_fluent_arrow_circle_down_up_20_regular = 57513
ic_fluent_arrow_circle_left_20_filled = 57514
ic_fluent_arrow_circle_left_20_regular = 57515
ic_fluent_arrow_circle_right_20_filled = 57516
ic_fluent_arrow_circle_right_20_regular = 57517
ic_fluent_arrow_circle_up_20_filled = 57518
ic_fluent_arrow_circle_up_20_regular = 57519
ic_fluent_arrow_circle_up_left_20_filled = 57520
ic_fluent_arrow_circle_up_left_20_regular = 57521
ic_fluent_arrow_circle_up_right_20_filled = 57522
ic_fluent_arrow_circle_up_right_20_regular = 57523
ic_fluent_arrow_circle_up_sparkle_20_filled = 57524
ic_fluent_arrow_circle_up_sparkle_20_regular = 57525
ic_fluent_arrow_clockwise_20_filled = 57526
ic_fluent_arrow_clockwise_20_regular = 57527
ic_fluent_arrow_clockwise_dashes_20_filled = 57528
ic_fluent_arrow_clockwise_dashes_20_regular = 57529
ic_fluent_arrow_clockwise_dashes_settings_20_filled = 57530
ic_fluent_arrow_clockwise_dashes_settings_20_regular = 57531
ic_fluent_arrow_collapse_all_20_filled = 57532
ic_fluent_arrow_collapse_all_20_regular = 57533
ic_fluent_arrow_counterclockwise_20_filled = 57534
ic_fluent_arrow_counterclockwise_20_regular = 57535
ic_fluent_arrow_counterclockwise_dashes_20_filled = 57536
ic_fluent_arrow_counterclockwise_dashes_20_regular = 57537
ic_fluent_arrow_counterclockwise_info_20_filled = 57538
ic_fluent_arrow_counterclockwise_info_20_regular = 57539
ic_fluent_arrow_curve_down_left_20_filled = 57540
ic_fluent_arrow_curve_down_left_20_regular = 57541
ic_fluent_arrow_curve_down_right_20_filled = 57542
ic_fluent_arrow_curve_down_right_20_regular = 57543
ic_fluent_arrow_curve_up_left_20_filled = 57544
ic_fluent_arrow_curve_up_left_20_regular = 57545
ic_fluent_arrow_curve_up_right_20_filled = 57546
ic_fluent_arrow_curve_up_right_20_regular = 57547
ic_fluent_arrow_down_20_filled = 57548
ic_fluent_arrow_down_20_regular = 57549
ic_fluent_arrow_down_exclamation_20_filled = 57550
ic_fluent_arrow_down_exclamation_20_regular = 57551
ic_fluent_arrow_down_left_20_filled = 57552
ic_fluent_arrow_down_left_20_regular = 57553
ic_fluent_arrow_down_right_20_filled = 57554
ic_fluent_arrow_down_right_20_regular = 57555
ic_fluent_arrow_download_20_filled = 57556
ic_fluent_arrow_download_20_regular = 57557
ic_fluent_arrow_download_off_20_filled = 57558
ic_fluent_arrow_download_off_20_regular = 57559
ic_fluent_arrow_eject_20_filled = 57560
ic_fluent_arrow_eject_20_regular = 57561
ic_fluent_arrow_enter_20_filled = 57562
ic_fluent_arrow_enter_20_regular = 57563
ic_fluent_arrow_enter_left_20_filled = 57564
ic_fluent_arrow_enter_left_20_regular = 57565
ic_fluent_arrow_enter_up_20_filled = 57566
ic_fluent_arrow_enter_up_20_regular = 57567
ic_fluent_arrow_exit_20_filled = 57568
ic_fluent_arrow_exit_20_regular = 57569
ic_fluent_arrow_expand_20_filled = 57570
ic_fluent_arrow_expand_20_regular = 57571
ic_fluent_arrow_expand_all_20_filled = 57572
ic_fluent_arrow_expand_all_20_regular = 57573
ic_fluent_arrow_export_20_filled = 57574
ic_fluent_arrow_export_20_regular = 57575
ic_fluent_arrow_export_ltr_20_filled = 57576
ic_fluent_arrow_export_ltr_20_regular = 57577
ic_fluent_arrow_export_rtl_20_filled = 57578
ic_fluent_arrow_export_rtl_20_regular = 57579
ic_fluent_arrow_export_up_20_filled = 57580
ic_fluent_arrow_export_up_20_regular = 57581
ic_fluent_arrow_fit_20_filled = 57582
ic_fluent_arrow_fit_20_regular = 57583
ic_fluent_arrow_fit_in_20_filled = 57584
ic_fluent_arrow_fit_in_20_regular = 57585
ic_fluent_arrow_flow_diagonal_up_right_20_filled = 57586
ic_fluent_arrow_flow_diagonal_up_right_20_regular = 57587
ic_fluent_arrow_flow_up_right_20_filled = 57588
ic_fluent_arrow_flow_up_right_20_regular = 57589
ic_fluent_arrow_flow_up_right_rectangle_multiple_20_filled = 57590
ic_fluent_arrow_flow_up_right_rectangle_multiple_20_regular = 57591
ic_fluent_arrow_forward_20_filled = 57592
ic_fluent_arrow_forward_20_regular = 57593
ic_fluent_arrow_forward_down_lightning_20_filled = 57594
ic_fluent_arrow_forward_down_lightning_20_regular = 57595
ic_fluent_arrow_forward_down_person_20_filled = 57596
ic_fluent_arrow_forward_down_person_20_regular = 57597
ic_fluent_arrow_hook_down_left_20_filled = 57598
ic_fluent_arrow_hook_down_left_20_regular = 57599
ic_fluent_arrow_hook_down_right_20_filled = 57600
ic_fluent_arrow_hook_down_right_20_regular = 57601
ic_fluent_arrow_hook_up_left_20_filled = 57602
ic_fluent_arrow_hook_up_left_20_regular = 57603
ic_fluent_arrow_hook_up_right_20_filled = 57604
ic_fluent_arrow_hook_up_right_20_regular = 57605
ic_fluent_arrow_import_20_filled = 57606
ic_fluent_arrow_import_20_regular = 57607
ic_fluent_arrow_join_20_filled = 57608
ic_fluent_arrow_join_20_regular = 57609
ic_fluent_arrow_left_20_filled = 57610
ic_fluent_arrow_left_20_regular = 57611
ic_fluent_arrow_maximize_20_filled = 57612
ic_fluent_arrow_maximize_20_regular = 57613
ic_fluent_arrow_maximize_vertical_20_filled = 57614
ic_fluent_arrow_maximize_vertical_20_regular = 57615
ic_fluent_arrow_minimize_20_filled = 57616
ic_fluent_arrow_minimize_20_regular = 57617
ic_fluent_arrow_minimize_vertical_20_filled = 57618
ic_fluent_arrow_minimize_vertical_20_regular = 57619
ic_fluent_arrow_move_20_filled = 57620
ic_fluent_arrow_move_20_regular = 57621
ic_fluent_arrow_move_inward_20_filled = 57622
ic_fluent_arrow_move_inward_20_regular = 57623
ic_fluent_arrow_next_20_filled = 57624
ic_fluent_arrow_next_20_regular = 57625
ic_fluent_arrow_outline_down_left_20_filled = 57626
ic_fluent_arrow_outline_down_left_20_regular = 57627
ic_fluent_arrow_outline_up_right_20_filled = 57628
ic_fluent_arrow_outline_up_right_20_regular = 57629
ic_fluent_arrow_paragraph_20_filled = 57630
ic_fluent_arrow_paragraph_20_regular = 57631
ic_fluent_arrow_previous_20_filled = 57632
ic_fluent_arrow_previous_20_regular = 57633
ic_fluent_arrow_redo_20_filled = 57634
ic_fluent_arrow_redo_20_regular = 57635
ic_fluent_arrow_repeat_1_20_filled = 57636
ic_fluent_arrow_repeat_1_20_regular = 57637
ic_fluent_arrow_repeat_all_20_filled = 57638
ic_fluent_arrow_repeat_all_20_regular = 57639
ic_fluent_arrow_repeat_all_off_20_filled = 57640
ic_fluent_arrow_repeat_all_off_20_regular = 57641
ic_fluent_arrow_reply_20_filled = 57642
ic_fluent_arrow_reply_20_regular = 57643
ic_fluent_arrow_reply_all_20_filled = 57644
ic_fluent_arrow_reply_all_20_regular = 57645
ic_fluent_arrow_reply_down_20_filled = 57646
ic_fluent_arrow_reply_down_20_regular = 57647
ic_fluent_arrow_reset_20_filled = 57648
ic_fluent_arrow_reset_20_regular = 57649
ic_fluent_arrow_right_20_filled = 57650
ic_fluent_arrow_right_20_regular = 57651
ic_fluent_arrow_rotate_clockwise_20_filled = 57652
ic_fluent_arrow_rotate_clockwise_20_regular = 57653
ic_fluent_arrow_rotate_counterclockwise_20_filled = 57654
ic_fluent_arrow_rotate_counterclockwise_20_regular = 57655
ic_fluent_arrow_routing_20_filled = 57656
ic_fluent_arrow_routing_20_regular = 57657
ic_fluent_arrow_routing_rectangle_multiple_20_filled = 57658
ic_fluent_arrow_routing_rectangle_multiple_20_regular = 57659
ic_fluent_arrow_shuffle_20_filled = 57660
ic_fluent_arrow_shuffle_20_regular = 57661
ic_fluent_arrow_shuffle_off_20_filled = 57662
ic_fluent_arrow_shuffle_off_20_regular = 57663
ic_fluent_arrow_sort_20_filled = 57664
ic_fluent_arrow_sort_20_regular = 57665
ic_fluent_arrow_sort_down_20_filled = 57666
ic_fluent_arrow_sort_down_20_regular = 57667
ic_fluent_arrow_sort_down_lines_20_filled = 57668
ic_fluent_arrow_sort_down_lines_20_regular = 57669
ic_fluent_arrow_sort_up_20_filled = 57670
ic_fluent_arrow_sort_up_20_regular = 57671
ic_fluent_arrow_sort_up_lines_20_filled = 57672
ic_fluent_arrow_sort_up_lines_20_regular = 57673
ic_fluent_arrow_split_20_filled = 57674
ic_fluent_arrow_split_20_regular = 57675
ic_fluent_arrow_sprint_20_filled = 57676
ic_fluent_arrow_sprint_20_regular = 57677
ic_fluent_arrow_square_down_20_filled = 57678
ic_fluent_arrow_square_down_20_regular = 57679
ic_fluent_arrow_square_up_right_20_filled = 57680
ic_fluent_arrow_square_up_right_20_regular = 57681
ic_fluent_arrow_step_back_20_filled = 57682
ic_fluent_arrow_step_back_20_regular = 57683
ic_fluent_arrow_step_in_20_filled = 57684
ic_fluent_arrow_step_in_20_regular = 57685
ic_fluent_arrow_step_in_diagonal_down_left_20_filled = 57686
ic_fluent_arrow_step_in_diagonal_down_left_20_regular = 57687
ic_fluent_arrow_step_in_left_20_filled = 57688
ic_fluent_arrow_step_in_left_20_regular = 57689
ic_fluent_arrow_step_in_right_20_filled = 57690
ic_fluent_arrow_step_in_right_20_regular = 57691
ic_fluent_arrow_step_out_20_filled = 57692
ic_fluent_arrow_step_out_20_regular = 57693
ic_fluent_arrow_step_over_20_filled = 57694
ic_fluent_arrow_step_over_20_regular = 57695
ic_fluent_arrow_swap_20_filled = 57696
ic_fluent_arrow_swap_20_regular = 57697
ic_fluent_arrow_sync_20_filled = 57698
ic_fluent_arrow_sync_20_regular = 57699
ic_fluent_arrow_sync_checkmark_20_filled = 57700
ic_fluent_arrow_sync_checkmark_20_regular = 57701
ic_fluent_arrow_sync_circle_20_filled = 57702
ic_fluent_arrow_sync_circle_20_regular = 57703
ic_fluent_arrow_sync_dismiss_20_filled = 57704
ic_fluent_arrow_sync_dismiss_20_regular = 57705
ic_fluent_arrow_sync_off_20_filled = 57706
ic_fluent_arrow_sync_off_20_regular = 57707
ic_fluent_arrow_trending_20_filled = 57708
ic_fluent_arrow_trending_20_regular = 57709
ic_fluent_arrow_trending_checkmark_20_filled = 57710
ic_fluent_arrow_trending_checkmark_20_regular = 57711
ic_fluent_arrow_trending_down_20_filled = 57712
ic_fluent_arrow_trending_down_20_regular = 57713
ic_fluent_arrow_trending_lines_20_filled = 57714
ic_fluent_arrow_trending_lines_20_regular = 57715
ic_fluent_arrow_trending_settings_20_filled = 57716
ic_fluent_arrow_trending_settings_20_regular = 57717
ic_fluent_arrow_trending_sparkle_20_filled = 57718
ic_fluent_arrow_trending_sparkle_20_regular = 57719
ic_fluent_arrow_trending_text_20_filled = 57720
ic_fluent_arrow_trending_text_20_regular = 57721
ic_fluent_arrow_trending_wrench_20_filled = 57722
ic_fluent_arrow_trending_wrench_20_regular = 57723
ic_fluent_arrow_turn_bidirectional_down_right_20_filled = 57724
ic_fluent_arrow_turn_bidirectional_down_right_20_regular = 57725
ic_fluent_arrow_turn_down_left_20_filled = 57726
ic_fluent_arrow_turn_down_left_20_regular = 57727
ic_fluent_arrow_turn_down_right_20_filled = 57728
ic_fluent_arrow_turn_down_right_20_regular = 57729
ic_fluent_arrow_turn_down_up_20_filled = 57730
ic_fluent_arrow_turn_down_up_20_regular = 57731
ic_fluent_arrow_turn_left_down_20_filled = 57732
ic_fluent_arrow_turn_left_down_20_regular = 57733
ic_fluent_arrow_turn_left_right_20_filled = 57734
ic_fluent_arrow_turn_left_right_20_regular = 57735
ic_fluent_arrow_turn_left_up_20_filled = 57736
ic_fluent_arrow_turn_left_up_20_regular = 57737
ic_fluent_arrow_turn_right_20_filled = 57738
ic_fluent_arrow_turn_right_20_regular = 57739
ic_fluent_arrow_turn_right_down_20_filled = 57740
ic_fluent_arrow_turn_right_down_20_regular = 57741
ic_fluent_arrow_turn_right_left_20_filled = 57742
ic_fluent_arrow_turn_right_left_20_regular = 57743
ic_fluent_arrow_turn_right_up_20_filled = 57744
ic_fluent_arrow_turn_right_up_20_regular = 57745
ic_fluent_arrow_turn_up_down_20_filled = 57746
ic_fluent_arrow_turn_up_down_20_regular = 57747
ic_fluent_arrow_turn_up_left_20_filled = 57748
ic_fluent_arrow_turn_up_left_20_regular = 57749
ic_fluent_arrow_undo_20_filled = 57750
ic_fluent_arrow_undo_20_regular = 57751
ic_fluent_arrow_up_20_filled = 57752
ic_fluent_arrow_up_20_regular = 57753
ic_fluent_arrow_up_exclamation_20_filled = 57754
ic_fluent_arrow_up_exclamation_20_regular = 57755
ic_fluent_arrow_up_left_20_filled = 57756
ic_fluent_arrow_up_left_20_regular = 57757
ic_fluent_arrow_up_right_20_filled = 57758
ic_fluent_arrow_up_right_20_regular = 57759
ic_fluent_arrow_up_right_dashes_20_filled = 57760
ic_fluent_arrow_up_right_dashes_20_regular = 57761
ic_fluent_arrow_upload_20_filled = 57762
ic_fluent_arrow_upload_20_regular = 57763
ic_fluent_arrow_wrap_20_filled = 57764
ic_fluent_arrow_wrap_20_regular = 57765
ic_fluent_arrow_wrap_off_20_filled = 57766
ic_fluent_arrow_wrap_off_20_regular = 57767
ic_fluent_arrow_wrap_up_to_down_20_filled = 57768
ic_fluent_arrow_wrap_up_to_down_20_regular = 57769
ic_fluent_arrows_bidirectional_20_filled = 57770
ic_fluent_arrows_bidirectional_20_regular = 57771
ic_fluent_attach_20_filled = 57772
ic_fluent_attach_20_regular = 57773
ic_fluent_attach_arrow_right_20_filled = 57774
ic_fluent_attach_arrow_right_20_regular = 57775
ic_fluent_attach_text_20_filled = 57776
ic_fluent_attach_text_20_regular = 57777
ic_fluent_auto_fit_height_20_filled = 57778
ic_fluent_auto_fit_height_20_regular = 57779
ic_fluent_auto_fit_width_20_filled = 57780
ic_fluent_auto_fit_width_20_regular = 57781
ic_fluent_autocorrect_20_filled = 57782
ic_fluent_autocorrect_20_regular = 57783
ic_fluent_autosum_20_filled = 57784
ic_fluent_autosum_20_regular = 57785
ic_fluent_backpack_20_filled = 57786
ic_fluent_backpack_20_regular = 57787
ic_fluent_backpack_add_20_filled = 57788
ic_fluent_backpack_add_20_regular = 57789
ic_fluent_backspace_20_filled = 57790
ic_fluent_backspace_20_regular = 57791
ic_fluent_badge_20_filled = 57792
ic_fluent_badge_20_regular = 57793
ic_fluent_balloon_20_filled = 57794
ic_fluent_balloon_20_regular = 57795
ic_fluent_barcode_scanner_20_filled = 57796
ic_fluent_barcode_scanner_20_regular = 57797
ic_fluent_barcode_scanner_add_20_filled = 57798
ic_fluent_barcode_scanner_add_20_regular = 57799
ic_fluent_barcode_scanner_dismiss_20_filled = 57800
ic_fluent_barcode_scanner_dismiss_20_regular = 57801
ic_fluent_battery_0_20_filled = 57802
ic_fluent_battery_0_20_regular = 57803
ic_fluent_battery_1_20_filled = 57804
ic_fluent_battery_1_20_regular = 57805
ic_fluent_battery_10_20_filled = 57806
ic_fluent_battery_10_20_regular = 57807
ic_fluent_battery_2_20_filled = 57808
ic_fluent_battery_2_20_regular = 57809
ic_fluent_battery_3_20_filled = 57810
ic_fluent_battery_3_20_regular = 57811
ic_fluent_battery_4_20_filled = 57812
ic_fluent_battery_4_20_regular = 57813
ic_fluent_battery_5_20_filled = 57814
ic_fluent_battery_5_20_regular = 57815
ic_fluent_battery_6_20_filled = 57816
ic_fluent_battery_6_20_regular = 57817
ic_fluent_battery_7_20_filled = 57818
ic_fluent_battery_7_20_regular = 57819
ic_fluent_battery_8_20_filled = 57820
ic_fluent_battery_8_20_regular = 57821
ic_fluent_battery_9_20_filled = 57822
ic_fluent_battery_9_20_regular = 57823
ic_fluent_battery_charge_20_filled = 57824
ic_fluent_battery_charge_20_regular = 57825
ic_fluent_battery_checkmark_20_filled = 57826
ic_fluent_battery_checkmark_20_regular = 57827
ic_fluent_battery_saver_20_filled = 57828
ic_fluent_battery_saver_20_regular = 57829
ic_fluent_battery_warning_20_filled = 57830
ic_fluent_battery_warning_20_regular = 57831
ic_fluent_beach_20_filled = 57832
ic_fluent_beach_20_regular = 57833
ic_fluent_beaker_20_filled = 57834
ic_fluent_beaker_20_regular = 57835
ic_fluent_beaker_add_20_filled = 57836
ic_fluent_beaker_add_20_regular = 57837
ic_fluent_beaker_dismiss_20_filled = 57838
ic_fluent_beaker_dismiss_20_regular = 57839
ic_fluent_beaker_edit_20_filled = 57840
ic_fluent_beaker_edit_20_regular = 57841
ic_fluent_beaker_off_20_filled = 57842
ic_fluent_beaker_off_20_regular = 57843
ic_fluent_beaker_settings_20_filled = 57844
ic_fluent_beaker_settings_20_regular = 57845
ic_fluent_bed_20_filled = 57846
ic_fluent_bed_20_regular = 57847
ic_fluent_bench_20_filled = 57848
ic_fluent_bench_20_regular = 57849
ic_fluent_bezier_curve_square_20_filled = 57850
ic_fluent_bezier_curve_square_20_regular = 57851
ic_fluent_bin_full_20_filled = 57852
ic_fluent_bin_full_20_regular = 57853
ic_fluent_bin_recycle_20_filled = 57854
ic_fluent_bin_recycle_20_regular = 57855
ic_fluent_bin_recycle_full_20_filled = 57856
ic_fluent_bin_recycle_full_20_regular = 57857
ic_fluent_binder_triangle_20_filled = 57858
ic_fluent_binder_triangle_20_regular = 57859
ic_fluent_bluetooth_20_filled = 57860
ic_fluent_bluetooth_20_regular = 57861
ic_fluent_bluetooth_connected_20_filled = 57862
ic_fluent_bluetooth_connected_20_regular = 57863
ic_fluent_bluetooth_disabled_20_filled = 57864
ic_fluent_bluetooth_disabled_20_regular = 57865
ic_fluent_bluetooth_searching_20_filled = 57866
ic_fluent_bluetooth_searching_20_regular = 57867
ic_fluent_blur_20_filled = 57868
ic_fluent_blur_20_regular = 57869
ic_fluent_board_20_filled = 57870
ic_fluent_board_20_regular = 57871
ic_fluent_board_games_20_filled = 57872
ic_fluent_board_games_20_regular = 57873
ic_fluent_board_heart_20_filled = 57874
ic_fluent_board_heart_20_regular = 57875
ic_fluent_board_split_20_filled = 57876
ic_fluent_board_split_20_regular = 57877
ic_fluent_book_20_filled = 57878
ic_fluent_book_20_regular = 57879
ic_fluent_book_add_20_filled = 57880
ic_fluent_book_add_20_regular = 57881
ic_fluent_book_arrow_clockwise_20_filled = 57882
ic_fluent_book_arrow_clockwise_20_regular = 57883
ic_fluent_book_clock_20_filled = 57884
ic_fluent_book_clock_20_regular = 57885
ic_fluent_book_coins_20_filled = 57886
ic_fluent_book_coins_20_regular = 57887
ic_fluent_book_compass_20_filled = 57888
ic_fluent_book_compass_20_regular = 57889
ic_fluent_book_contacts_20_filled = 57890
ic_fluent_book_contacts_20_regular = 57891
ic_fluent_book_database_20_filled = 57892
ic_fluent_book_database_20_regular = 57893
ic_fluent_book_default_20_filled = 57894
ic_fluent_book_dismiss_20_filled = 57895
ic_fluent_book_dismiss_20_regular = 57896
ic_fluent_book_exclamation_mark_20_filled = 57897
ic_fluent_book_exclamation_mark_20_regular = 57898
ic_fluent_book_globe_20_filled = 57899
ic_fluent_book_globe_20_regular = 57900
ic_fluent_book_information_20_filled = 57901
ic_fluent_book_information_20_regular = 57902
ic_fluent_book_letter_20_filled = 57903
ic_fluent_book_letter_20_regular = 57904
ic_fluent_book_number_20_filled = 57905
ic_fluent_book_number_20_regular = 57906
ic_fluent_book_open_20_filled = 57907
ic_fluent_book_open_20_regular = 57908
ic_fluent_book_open_globe_20_filled = 57909
ic_fluent_book_open_globe_20_regular = 57910
ic_fluent_book_open_lightbulb_20_filled = 57911
ic_fluent_book_open_lightbulb_20_regular = 57912
ic_fluent_book_open_microphone_20_filled = 57913
ic_fluent_book_open_microphone_20_regular = 57914
ic_fluent_book_pulse_20_filled = 57915
ic_fluent_book_pulse_20_regular = 57916
ic_fluent_book_question_mark_20_filled = 57917
ic_fluent_book_question_mark_20_regular = 57918
ic_fluent_book_question_mark_rtl_20_filled = 57919
ic_fluent_book_question_mark_rtl_20_regular = 57920
ic_fluent_book_search_20_filled = 57921
ic_fluent_book_search_20_regular = 57922
ic_fluent_book_star_20_filled = 57923
ic_fluent_book_star_20_regular = 57924
ic_fluent_book_template_20_filled = 57925
ic_fluent_book_template_20_regular = 57926
ic_fluent_book_theta_20_filled = 57927
ic_fluent_book_theta_20_regular = 57928
ic_fluent_book_toolbox_20_filled = 57929
ic_fluent_book_toolbox_20_regular = 57930
ic_fluent_bookmark_20_filled = 57931
ic_fluent_bookmark_20_regular = 57932
ic_fluent_bookmark_add_20_filled = 57933
ic_fluent_bookmark_add_20_regular = 57934
ic_fluent_bookmark_multiple_20_filled = 57935
ic_fluent_bookmark_multiple_20_regular = 57936
ic_fluent_bookmark_off_20_filled = 57937
ic_fluent_bookmark_off_20_regular = 57938
ic_fluent_bookmark_search_20_filled = 57939
ic_fluent_bookmark_search_20_regular = 57940
ic_fluent_border_all_20_filled = 57941
ic_fluent_border_all_20_regular = 57942
ic_fluent_border_bottom_20_filled = 57943
ic_fluent_border_bottom_20_regular = 57944
ic_fluent_border_bottom_double_20_filled = 57945
ic_fluent_border_bottom_double_20_regular = 57946
ic_fluent_border_bottom_thick_20_filled = 57947
ic_fluent_border_bottom_thick_20_regular = 57948
ic_fluent_border_inside_20_filled = 57949
ic_fluent_border_inside_20_regular = 57950
ic_fluent_border_left_20_filled = 57951
ic_fluent_border_left_20_regular = 57952
ic_fluent_border_left_right_20_filled = 57953
ic_fluent_border_left_right_20_regular = 57954
ic_fluent_border_none_20_filled = 57955
ic_fluent_border_none_20_regular = 57956
ic_fluent_border_outside_20_filled = 57957
ic_fluent_border_outside_20_regular = 57958
ic_fluent_border_outside_thick_20_filled = 57959
ic_fluent_border_outside_thick_20_regular = 57960
ic_fluent_border_right_20_filled = 57961
ic_fluent_border_right_20_regular = 57962
ic_fluent_border_top_20_filled = 57963
ic_fluent_border_top_20_regular = 57964
ic_fluent_border_top_bottom_20_filled = 57965
ic_fluent_border_top_bottom_20_regular = 57966
ic_fluent_border_top_bottom_double_20_filled = 57967
ic_fluent_border_top_bottom_double_20_regular = 57968
ic_fluent_border_top_bottom_thick_20_filled = 57969
ic_fluent_border_top_bottom_thick_20_regular = 57970
ic_fluent_bot_20_filled = 57971
ic_fluent_bot_20_regular = 57972
ic_fluent_bot_add_20_filled = 57973
ic_fluent_bot_add_20_regular = 57974
ic_fluent_bot_sparkle_20_filled = 57975
ic_fluent_bot_sparkle_20_regular = 57976
ic_fluent_bow_tie_20_filled = 57977
ic_fluent_bow_tie_20_regular = 57978
ic_fluent_bowl_chopsticks_20_filled = 57979
ic_fluent_bowl_chopsticks_20_regular = 57980
ic_fluent_bowl_salad_20_filled = 57981
ic_fluent_bowl_salad_20_regular = 57982
ic_fluent_box_20_filled = 57983
ic_fluent_box_20_regular = 57984
ic_fluent_box_arrow_left_20_filled = 57985
ic_fluent_box_arrow_left_20_regular = 57986
ic_fluent_box_arrow_up_20_filled = 57987
ic_fluent_box_arrow_up_20_regular = 57988
ic_fluent_box_checkmark_20_filled = 57989
ic_fluent_box_checkmark_20_regular = 57990
ic_fluent_box_dismiss_20_filled = 57991
ic_fluent_box_dismiss_20_regular = 57992
ic_fluent_box_edit_20_filled = 57993
ic_fluent_box_edit_20_regular = 57994
ic_fluent_box_multiple_20_filled = 57995
ic_fluent_box_multiple_20_regular = 57996
ic_fluent_box_multiple_arrow_left_20_filled = 57997
ic_fluent_box_multiple_arrow_left_20_regular = 57998
ic_fluent_box_multiple_arrow_right_20_filled = 57999
ic_fluent_box_multiple_arrow_right_20_regular = 58000
ic_fluent_box_multiple_checkmark_20_filled = 58001
ic_fluent_box_multiple_checkmark_20_regular = 58002
ic_fluent_box_multiple_search_20_filled = 58003
ic_fluent_box_multiple_search_20_regular = 58004
ic_fluent_box_search_20_filled = 58005
ic_fluent_box_search_20_regular = 58006
ic_fluent_box_toolbox_20_filled = 58007
ic_fluent_box_toolbox_20_regular = 58008
ic_fluent_braces_20_filled = 58009
ic_fluent_braces_20_regular = 58010
ic_fluent_braces_variable_20_filled = 58011
ic_fluent_braces_variable_20_regular = 58012
ic_fluent_brain_20_filled = 58013
ic_fluent_brain_20_regular = 58014
ic_fluent_brain_circuit_20_filled = 58015
ic_fluent_brain_circuit_20_regular = 58016
ic_fluent_brain_sparkle_20_filled = 58017
ic_fluent_brain_sparkle_20_regular = 58018
ic_fluent_branch_20_filled = 58019
ic_fluent_branch_20_regular = 58020
ic_fluent_branch_compare_20_filled = 58021
ic_fluent_branch_compare_20_regular = 58022
ic_fluent_branch_fork_20_filled = 58023
ic_fluent_branch_fork_20_regular = 58024
ic_fluent_branch_fork_hint_20_filled = 58025
ic_fluent_branch_fork_hint_20_regular = 58026
ic_fluent_branch_fork_link_20_filled = 58027
ic_fluent_branch_fork_link_20_regular = 58028
ic_fluent_branch_request_20_filled = 58029
ic_fluent_branch_request_20_regular = 58030
ic_fluent_branch_request_closed_20_filled = 58031
ic_fluent_branch_request_closed_20_regular = 58032
ic_fluent_branch_request_draft_20_filled = 58033
ic_fluent_branch_request_draft_20_regular = 58034
ic_fluent_breakout_room_20_filled = 58035
ic_fluent_breakout_room_20_regular = 58036
ic_fluent_briefcase_20_filled = 58037
ic_fluent_briefcase_20_regular = 58038
ic_fluent_briefcase_medical_20_filled = 58039
ic_fluent_briefcase_medical_20_regular = 58040
ic_fluent_briefcase_off_20_filled = 58041
ic_fluent_briefcase_off_20_regular = 58042
ic_fluent_briefcase_search_20_filled = 58043
ic_fluent_briefcase_search_20_regular = 58044
ic_fluent_brightness_high_20_filled = 58045
ic_fluent_brightness_high_20_regular = 58046
ic_fluent_brightness_low_20_filled = 58047
ic_fluent_brightness_low_20_regular = 58048
ic_fluent_broad_activity_feed_20_filled = 58049
ic_fluent_broad_activity_feed_20_regular = 58050
ic_fluent_broom_20_filled = 58051
ic_fluent_broom_20_regular = 58052
ic_fluent_broom_sparkle_20_filled = 58053
ic_fluent_broom_sparkle_20_regular = 58054
ic_fluent_bubble_multiple_20_filled = 58055
ic_fluent_bubble_multiple_20_regular = 58056
ic_fluent_bug_20_filled = 58057
ic_fluent_bug_20_regular = 58058
ic_fluent_bug_arrow_counterclockwise_20_filled = 58059
ic_fluent_bug_arrow_counterclockwise_20_regular = 58060
ic_fluent_bug_prohibited_20_filled = 58061
ic_fluent_bug_prohibited_20_regular = 58062
ic_fluent_building_20_filled = 58063
ic_fluent_building_20_regular = 58064
ic_fluent_building_bank_20_filled = 58065
ic_fluent_building_bank_20_regular = 58066
ic_fluent_building_bank_link_20_filled = 58067
ic_fluent_building_bank_link_20_regular = 58068
ic_fluent_building_bank_toolbox_20_filled = 58069
ic_fluent_building_bank_toolbox_20_regular = 58070
ic_fluent_building_checkmark_20_filled = 58071
ic_fluent_building_checkmark_20_regular = 58072
ic_fluent_building_desktop_20_filled = 58073
ic_fluent_building_desktop_20_regular = 58074
ic_fluent_building_factory_20_filled = 58075
ic_fluent_building_factory_20_regular = 58076
ic_fluent_building_government_20_filled = 58077
ic_fluent_building_government_20_regular = 58078
ic_fluent_building_government_search_20_filled = 58079
ic_fluent_building_government_search_20_regular = 58080
ic_fluent_building_home_20_filled = 58081
ic_fluent_building_home_20_regular = 58082
ic_fluent_building_lighthouse_20_filled = 58083
ic_fluent_building_lighthouse_20_regular = 58084
ic_fluent_building_mosque_20_filled = 58085
ic_fluent_building_mosque_20_regular = 58086
ic_fluent_building_multiple_20_filled = 58087
ic_fluent_building_multiple_20_regular = 58088
ic_fluent_building_people_20_filled = 58089
ic_fluent_building_people_20_regular = 58090
ic_fluent_building_retail_20_filled = 58091
ic_fluent_building_retail_20_regular = 58092
ic_fluent_building_retail_money_20_filled = 58093
ic_fluent_building_retail_money_20_regular = 58094
ic_fluent_building_retail_more_20_filled = 58095
ic_fluent_building_retail_more_20_regular = 58096
ic_fluent_building_retail_shield_20_filled = 58097
ic_fluent_building_retail_shield_20_regular = 58098
ic_fluent_building_retail_toolbox_20_filled = 58099
ic_fluent_building_retail_toolbox_20_regular = 58100
ic_fluent_building_shop_20_filled = 58101
ic_fluent_building_shop_20_regular = 58102
ic_fluent_building_skyscraper_20_filled = 58103
ic_fluent_building_skyscraper_20_regular = 58104
ic_fluent_building_swap_20_filled = 58105
ic_fluent_building_swap_20_regular = 58106
ic_fluent_building_townhouse_20_filled = 58107
ic_fluent_building_townhouse_20_regular = 58108
ic_fluent_button_20_filled = 58109
ic_fluent_button_20_regular = 58110
ic_fluent_calculator_20_filled = 58111
ic_fluent_calculator_20_regular = 58112
ic_fluent_calculator_arrow_clockwise_20_filled = 58113
ic_fluent_calculator_arrow_clockwise_20_regular = 58114
ic_fluent_calculator_multiple_20_filled = 58115
ic_fluent_calculator_multiple_20_regular = 58116
ic_fluent_calendar_20_filled = 58117
ic_fluent_calendar_20_regular = 58118
ic_fluent_calendar_3_day_20_filled = 58119
ic_fluent_calendar_3_day_20_regular = 58120
ic_fluent_calendar_add_20_filled = 58121
ic_fluent_calendar_add_20_regular = 58122
ic_fluent_calendar_agenda_20_filled = 58123
ic_fluent_calendar_agenda_20_regular = 58124
ic_fluent_calendar_arrow_counterclockwise_20_filled = 58125
ic_fluent_calendar_arrow_counterclockwise_20_regular = 58126
ic_fluent_calendar_arrow_down_20_filled = 58127
ic_fluent_calendar_arrow_down_20_regular = 58128
ic_fluent_calendar_arrow_repeat_all_20_filled = 58129
ic_fluent_calendar_arrow_repeat_all_20_regular = 58130
ic_fluent_calendar_arrow_right_20_filled = 58131
ic_fluent_calendar_arrow_right_20_regular = 58132
ic_fluent_calendar_assistant_20_filled = 58133
ic_fluent_calendar_assistant_20_regular = 58134
ic_fluent_calendar_cancel_20_filled = 58135
ic_fluent_calendar_cancel_20_regular = 58136
ic_fluent_calendar_chat_20_filled = 58137
ic_fluent_calendar_chat_20_regular = 58138
ic_fluent_calendar_checkmark_20_filled = 58139
ic_fluent_calendar_checkmark_20_regular = 58140
ic_fluent_calendar_clock_20_filled = 58141
ic_fluent_calendar_clock_20_regular = 58142
ic_fluent_calendar_data_bar_20_filled = 58143
ic_fluent_calendar_data_bar_20_regular = 58144
ic_fluent_calendar_date_20_filled = 58145
ic_fluent_calendar_date_20_regular = 58146
ic_fluent_calendar_day_20_filled = 58147
ic_fluent_calendar_day_20_regular = 58148
ic_fluent_calendar_edit_20_filled = 58149
ic_fluent_calendar_edit_20_regular = 58150
ic_fluent_calendar_empty_20_filled = 58151
ic_fluent_calendar_empty_20_regular = 58152
ic_fluent_calendar_error_20_filled = 58153
ic_fluent_calendar_error_20_regular = 58154
ic_fluent_calendar_eye_20_filled = 58155
ic_fluent_calendar_eye_20_regular = 58156
ic_fluent_calendar_info_20_filled = 58157
ic_fluent_calendar_info_20_regular = 58158
ic_fluent_calendar_lock_20_filled = 58159
ic_fluent_calendar_lock_20_regular = 58160
ic_fluent_calendar_ltr_20_filled = 58161
ic_fluent_calendar_ltr_20_regular = 58162
ic_fluent_calendar_mail_20_filled = 58163
ic_fluent_calendar_mail_20_regular = 58164
ic_fluent_calendar_mention_20_filled = 58165
ic_fluent_calendar_mention_20_regular = 58166
ic_fluent_calendar_month_20_filled = 58167
ic_fluent_calendar_month_20_regular = 58168
ic_fluent_calendar_multiple_20_filled = 58169
ic_fluent_calendar_multiple_20_regular = 58170
ic_fluent_calendar_note_20_filled = 58171
ic_fluent_calendar_note_20_regular = 58172
ic_fluent_calendar_pattern_20_filled = 58173
ic_fluent_calendar_pattern_20_regular = 58174
ic_fluent_calendar_person_20_filled = 58175
ic_fluent_calendar_person_20_regular = 58176
ic_fluent_calendar_phone_20_filled = 58177
ic_fluent_calendar_phone_20_regular = 58178
ic_fluent_calendar_play_20_filled = 58179
ic_fluent_calendar_play_20_regular = 58180
ic_fluent_calendar_question_mark_20_filled = 58181
ic_fluent_calendar_question_mark_20_regular = 58182
ic_fluent_calendar_record_20_filled = 58183
ic_fluent_calendar_record_20_regular = 58184
ic_fluent_calendar_reply_20_filled = 58185
ic_fluent_calendar_reply_20_regular = 58186
ic_fluent_calendar_rtl_20_filled = 58187
ic_fluent_calendar_rtl_20_regular = 58188
ic_fluent_calendar_search_20_filled = 58189
ic_fluent_calendar_search_20_regular = 58190
ic_fluent_calendar_settings_20_filled = 58191
ic_fluent_calendar_settings_20_regular = 58192
ic_fluent_calendar_shield_20_filled = 58193
ic_fluent_calendar_shield_20_regular = 58194
ic_fluent_calendar_sparkle_20_filled = 58195
ic_fluent_calendar_sparkle_20_regular = 58196
ic_fluent_calendar_star_20_filled = 58197
ic_fluent_calendar_star_20_regular = 58198
ic_fluent_calendar_sync_20_filled = 58199
ic_fluent_calendar_sync_20_regular = 58200
ic_fluent_calendar_template_20_filled = 58201
ic_fluent_calendar_template_20_regular = 58202
ic_fluent_calendar_today_20_filled = 58203
ic_fluent_calendar_today_20_regular = 58204
ic_fluent_calendar_toolbox_20_filled = 58205
ic_fluent_calendar_toolbox_20_regular = 58206
ic_fluent_calendar_video_20_filled = 58207
ic_fluent_calendar_video_20_regular = 58208
ic_fluent_calendar_week_numbers_20_filled = 58209
ic_fluent_calendar_week_numbers_20_regular = 58210
ic_fluent_calendar_week_start_20_filled = 58211
ic_fluent_calendar_week_start_20_regular = 58212
ic_fluent_calendar_work_week_20_filled = 58213
ic_fluent_calendar_work_week_20_regular = 58214
ic_fluent_call_20_filled = 58215
ic_fluent_call_20_regular = 58216
ic_fluent_call_add_20_filled = 58217
ic_fluent_call_add_20_regular = 58218
ic_fluent_call_checkmark_20_filled = 58219
ic_fluent_call_checkmark_20_regular = 58220
ic_fluent_call_connecting_20_filled = 58221
ic_fluent_call_connecting_20_regular = 58222
ic_fluent_call_dismiss_20_filled = 58223
ic_fluent_call_dismiss_20_regular = 58224
ic_fluent_call_end_20_filled = 58225
ic_fluent_call_end_20_regular = 58226
ic_fluent_call_exclamation_20_filled = 58227
ic_fluent_call_exclamation_20_regular = 58228
ic_fluent_call_forward_20_filled = 58229
ic_fluent_call_forward_20_regular = 58230
ic_fluent_call_inbound_20_filled = 58231
ic_fluent_call_inbound_20_regular = 58232
ic_fluent_call_missed_20_filled = 58233
ic_fluent_call_missed_20_regular = 58234
ic_fluent_call_outbound_20_filled = 58235
ic_fluent_call_outbound_20_regular = 58236
ic_fluent_call_park_20_filled = 58237
ic_fluent_call_park_20_regular = 58238
ic_fluent_call_pause_20_filled = 58239
ic_fluent_call_pause_20_regular = 58240
ic_fluent_call_prohibited_20_filled = 58241
ic_fluent_call_prohibited_20_regular = 58242
ic_fluent_call_rectangle_landscape_20_filled = 58243
ic_fluent_call_rectangle_landscape_20_regular = 58244
ic_fluent_call_square_20_filled = 58245
ic_fluent_call_square_20_regular = 58246
ic_fluent_call_transfer_20_filled = 58247
ic_fluent_call_transfer_20_regular = 58248
ic_fluent_call_warning_20_filled = 58249
ic_fluent_call_warning_20_regular = 58250
ic_fluent_calligraphy_pen_20_filled = 58251
ic_fluent_calligraphy_pen_20_regular = 58252
ic_fluent_calligraphy_pen_checkmark_20_filled = 58253
ic_fluent_calligraphy_pen_checkmark_20_regular = 58254
ic_fluent_calligraphy_pen_error_20_filled = 58255
ic_fluent_calligraphy_pen_error_20_regular = 58256
ic_fluent_calligraphy_pen_question_mark_20_filled = 58257
ic_fluent_calligraphy_pen_question_mark_20_regular = 58258
ic_fluent_camera_20_filled = 58259
ic_fluent_camera_20_regular = 58260
ic_fluent_camera_add_20_filled = 58261
ic_fluent_camera_add_20_regular = 58262
ic_fluent_camera_arrow_up_20_filled = 58263
ic_fluent_camera_arrow_up_20_regular = 58264
ic_fluent_camera_dome_20_filled = 58265
ic_fluent_camera_dome_20_regular = 58266
ic_fluent_camera_edit_20_filled = 58267
ic_fluent_camera_edit_20_regular = 58268
ic_fluent_camera_off_20_filled = 58269
ic_fluent_camera_off_20_regular = 58270
ic_fluent_camera_sparkles_20_filled = 58271
ic_fluent_camera_sparkles_20_regular = 58272
ic_fluent_camera_switch_20_filled = 58273
ic_fluent_camera_switch_20_regular = 58274
ic_fluent_card_ui_20_filled = 58275
ic_fluent_card_ui_20_regular = 58276
ic_fluent_card_ui_portrait_flip_20_filled = 58277
ic_fluent_card_ui_portrait_flip_20_regular = 58278
ic_fluent_caret_down_20_filled = 58279
ic_fluent_caret_down_20_regular = 58280
ic_fluent_caret_down_right_20_filled = 58281
ic_fluent_caret_down_right_20_regular = 58282
ic_fluent_caret_left_20_filled = 58283
ic_fluent_caret_left_20_regular = 58284
ic_fluent_caret_right_20_filled = 58285
ic_fluent_caret_right_20_regular = 58286
ic_fluent_caret_up_20_filled = 58287
ic_fluent_caret_up_20_regular = 58288
ic_fluent_cart_20_filled = 58289
ic_fluent_cart_20_regular = 58290
ic_fluent_cast_20_filled = 58291
ic_fluent_cast_20_regular = 58292
ic_fluent_cast_multiple_20_filled = 58293
ic_fluent_cast_multiple_20_regular = 58294
ic_fluent_catch_up_20_filled = 58295
ic_fluent_catch_up_20_regular = 58296
ic_fluent_cellular_3g_20_filled = 58297
ic_fluent_cellular_3g_20_regular = 58298
ic_fluent_cellular_4g_20_filled = 58299
ic_fluent_cellular_4g_20_regular = 58300
ic_fluent_cellular_5g_20_filled = 58301
ic_fluent_cellular_5g_20_regular = 58302
ic_fluent_cellular_data_1_20_filled = 58303
ic_fluent_cellular_data_1_20_regular = 58304
ic_fluent_cellular_data_2_20_filled = 58305
ic_fluent_cellular_data_2_20_regular = 58306
ic_fluent_cellular_data_3_20_filled = 58307
ic_fluent_cellular_data_3_20_regular = 58308
ic_fluent_cellular_data_4_20_filled = 58309
ic_fluent_cellular_data_4_20_regular = 58310
ic_fluent_cellular_data_5_20_filled = 58311
ic_fluent_cellular_data_5_20_regular = 58312
ic_fluent_cellular_off_20_filled = 58313
ic_fluent_cellular_off_20_regular = 58314
ic_fluent_cellular_warning_20_filled = 58315
ic_fluent_cellular_warning_20_regular = 58316
ic_fluent_center_horizontal_20_filled = 58317
ic_fluent_center_horizontal_20_regular = 58318
ic_fluent_center_vertical_20_filled = 58319
ic_fluent_center_vertical_20_regular = 58320
ic_fluent_certificate_20_filled = 58321
ic_fluent_certificate_20_regular = 58322
ic_fluent_channel_20_filled = 58323
ic_fluent_channel_20_regular = 58324
ic_fluent_channel_add_20_filled = 58325
ic_fluent_channel_add_20_regular = 58326
ic_fluent_channel_alert_20_filled = 58327
ic_fluent_channel_alert_20_regular = 58328
ic_fluent_channel_arrow_left_20_filled = 58329
ic_fluent_channel_arrow_left_20_regular = 58330
ic_fluent_channel_dismiss_20_filled = 58331
ic_fluent_channel_dismiss_20_regular = 58332
ic_fluent_channel_share_20_filled = 58333
ic_fluent_channel_share_20_regular = 58334
ic_fluent_channel_subtract_20_filled = 58335
ic_fluent_channel_subtract_20_regular = 58336
ic_fluent_chart_multiple_20_filled = 58337
ic_fluent_chart_multiple_20_regular = 58338
ic_fluent_chart_person_20_filled = 58339
ic_fluent_chart_person_20_regular = 58340
ic_fluent_chat_20_filled = 58341
ic_fluent_chat_20_regular = 58342
ic_fluent_chat_add_20_filled = 58343
ic_fluent_chat_add_20_regular = 58344
ic_fluent_chat_arrow_back_20_filled = 58345
ic_fluent_chat_arrow_back_20_regular = 58346
ic_fluent_chat_arrow_back_down_20_filled = 58347
ic_fluent_chat_arrow_back_down_20_regular = 58348
ic_fluent_chat_arrow_double_back_20_filled = 58349
ic_fluent_chat_arrow_double_back_20_regular = 58350
ic_fluent_chat_bubbles_question_20_filled = 58351
ic_fluent_chat_bubbles_question_20_regular = 58352
ic_fluent_chat_cursor_20_filled = 58353
ic_fluent_chat_cursor_20_regular = 58354
ic_fluent_chat_dismiss_20_filled = 58355
ic_fluent_chat_dismiss_20_regular = 58356
ic_fluent_chat_empty_20_filled = 58357
ic_fluent_chat_empty_20_regular = 58358
ic_fluent_chat_help_20_filled = 58359
ic_fluent_chat_help_20_regular = 58360
ic_fluent_chat_history_20_filled = 58361
ic_fluent_chat_history_20_regular = 58362
ic_fluent_chat_lock_20_filled = 58363
ic_fluent_chat_lock_20_regular = 58364
ic_fluent_chat_mail_20_filled = 58365
ic_fluent_chat_mail_20_regular = 58366
ic_fluent_chat_multiple_20_filled = 58367
ic_fluent_chat_multiple_20_regular = 58368
ic_fluent_chat_multiple_checkmark_20_filled = 58369
ic_fluent_chat_multiple_checkmark_20_regular = 58370
ic_fluent_chat_multiple_heart_20_filled = 58371
ic_fluent_chat_multiple_heart_20_regular = 58372
ic_fluent_chat_multiple_minus_20_filled = 58373
ic_fluent_chat_multiple_minus_20_regular = 58374
ic_fluent_chat_off_20_filled = 58375
ic_fluent_chat_off_20_regular = 58376
ic_fluent_chat_settings_20_filled = 58377
ic_fluent_chat_settings_20_regular = 58378
ic_fluent_chat_sparkle_20_filled = 58379
ic_fluent_chat_sparkle_20_regular = 58380
ic_fluent_chat_video_20_filled = 58381
ic_fluent_chat_video_20_regular = 58382
ic_fluent_chat_warning_20_filled = 58383
ic_fluent_chat_warning_20_regular = 58384
ic_fluent_check_20_filled = 58385
ic_fluent_check_20_regular = 58386
ic_fluent_checkbox_1_20_filled = 58387
ic_fluent_checkbox_1_20_regular = 58388
ic_fluent_checkbox_2_20_filled = 58389
ic_fluent_checkbox_2_20_regular = 58390
ic_fluent_checkbox_arrow_right_20_filled = 58391
ic_fluent_checkbox_arrow_right_20_regular = 58392
ic_fluent_checkbox_checked_20_filled = 58393
ic_fluent_checkbox_checked_20_regular = 58394
ic_fluent_checkbox_checked_sync_20_filled = 58395
ic_fluent_checkbox_checked_sync_20_regular = 58396
ic_fluent_checkbox_indeterminate_20_filled = 58397
ic_fluent_checkbox_indeterminate_20_regular = 58398
ic_fluent_checkbox_person_20_filled = 58399
ic_fluent_checkbox_person_20_regular = 58400
ic_fluent_checkbox_unchecked_20_filled = 58401
ic_fluent_checkbox_unchecked_20_regular = 58402
ic_fluent_checkbox_warning_20_filled = 58403
ic_fluent_checkbox_warning_20_regular = 58404
ic_fluent_checkmark_20_filled = 58405
ic_fluent_checkmark_20_regular = 58406
ic_fluent_checkmark_circle_20_filled = 58407
ic_fluent_checkmark_circle_20_regular = 58408
ic_fluent_checkmark_circle_square_20_filled = 58409
ic_fluent_checkmark_circle_square_20_regular = 58410
ic_fluent_checkmark_circle_warning_20_filled = 58411
ic_fluent_checkmark_circle_warning_20_regular = 58412
ic_fluent_checkmark_lock_20_filled = 58413
ic_fluent_checkmark_lock_20_regular = 58414
ic_fluent_checkmark_note_20_filled = 58415
ic_fluent_checkmark_note_20_regular = 58416
ic_fluent_checkmark_square_20_filled = 58417
ic_fluent_checkmark_square_20_regular = 58418
ic_fluent_checkmark_starburst_20_filled = 58419
ic_fluent_checkmark_starburst_20_regular = 58420
ic_fluent_checkmark_underline_circle_20_filled = 58421
ic_fluent_checkmark_underline_circle_20_regular = 58422
ic_fluent_chess_20_filled = 58423
ic_fluent_chess_20_regular = 58424
ic_fluent_chevron_circle_down_20_filled = 58425
ic_fluent_chevron_circle_down_20_regular = 58426
ic_fluent_chevron_circle_left_20_filled = 58427
ic_fluent_chevron_circle_left_20_regular = 58428
ic_fluent_chevron_circle_right_20_filled = 58429
ic_fluent_chevron_circle_right_20_regular = 58430
ic_fluent_chevron_circle_up_20_filled = 58431
ic_fluent_chevron_circle_up_20_regular = 58432
ic_fluent_chevron_double_down_20_filled = 58433
ic_fluent_chevron_double_down_20_regular = 58434
ic_fluent_chevron_double_left_20_filled = 58435
ic_fluent_chevron_double_left_20_regular = 58436
ic_fluent_chevron_double_right_20_filled = 58437
ic_fluent_chevron_double_right_20_regular = 58438
ic_fluent_chevron_double_up_20_filled = 58439
ic_fluent_chevron_double_up_20_regular = 58440
ic_fluent_chevron_down_20_filled = 58441
ic_fluent_chevron_down_20_regular = 58442
ic_fluent_chevron_down_up_20_filled = 58443
ic_fluent_chevron_down_up_20_regular = 58444
ic_fluent_chevron_left_20_filled = 58445
ic_fluent_chevron_left_20_regular = 58446
ic_fluent_chevron_right_20_filled = 58447
ic_fluent_chevron_right_20_regular = 58448
ic_fluent_chevron_up_20_filled = 58449
ic_fluent_chevron_up_20_regular = 58450
ic_fluent_chevron_up_down_20_filled = 58451
ic_fluent_chevron_up_down_20_regular = 58452
ic_fluent_circle_20_filled = 58453
ic_fluent_circle_20_regular = 58454
ic_fluent_circle_edit_20_filled = 58455
ic_fluent_circle_edit_20_regular = 58456
ic_fluent_circle_eraser_20_filled = 58457
ic_fluent_circle_eraser_20_regular = 58458
ic_fluent_circle_half_fill_20_filled = 58459
ic_fluent_circle_half_fill_20_regular = 58460
ic_fluent_circle_highlight_20_filled = 58461
ic_fluent_circle_highlight_20_regular = 58462
ic_fluent_circle_hint_20_filled = 58463
ic_fluent_circle_hint_20_regular = 58464
ic_fluent_circle_hint_cursor_20_filled = 58465
ic_fluent_circle_hint_cursor_20_regular = 58466
ic_fluent_circle_hint_dismiss_20_filled = 58467
ic_fluent_circle_hint_dismiss_20_regular = 58468
ic_fluent_circle_hint_half_vertical_20_filled = 58469
ic_fluent_circle_hint_half_vertical_20_regular = 58470
ic_fluent_circle_image_20_filled = 58471
ic_fluent_circle_image_20_regular = 58472
ic_fluent_circle_line_20_filled = 58473
ic_fluent_circle_line_20_regular = 58474
ic_fluent_circle_multiple_concentric_20_filled = 58475
ic_fluent_circle_multiple_concentric_20_regular = 58476
ic_fluent_circle_multiple_hint_checkmark_20_filled = 58477
ic_fluent_circle_multiple_hint_checkmark_20_regular = 58478
ic_fluent_circle_multiple_subtract_checkmark_20_filled = 58479
ic_fluent_circle_multiple_subtract_checkmark_20_regular = 58480
ic_fluent_circle_off_20_filled = 58481
ic_fluent_circle_off_20_regular = 58482
ic_fluent_circle_shadow_20_filled = 58483
ic_fluent_circle_shadow_20_regular = 58484
ic_fluent_circle_small_20_filled = 58485
ic_fluent_circle_small_20_regular = 58486
ic_fluent_circle_sparkle_20_filled = 58487
ic_fluent_circle_sparkle_20_regular = 58488
ic_fluent_city_20_filled = 58489
ic_fluent_city_20_regular = 58490
ic_fluent_class_20_filled = 58491
ic_fluent_class_20_regular = 58492
ic_fluent_classification_20_filled = 58493
ic_fluent_classification_20_regular = 58494
ic_fluent_clear_formatting_20_filled = 58495
ic_fluent_clear_formatting_20_regular = 58496
ic_fluent_clipboard_20_filled = 58497
ic_fluent_clipboard_20_regular = 58498
ic_fluent_clipboard_3_day_20_filled = 58499
ic_fluent_clipboard_3_day_20_regular = 58500
ic_fluent_clipboard_arrow_right_20_filled = 58501
ic_fluent_clipboard_arrow_right_20_regular = 58502
ic_fluent_clipboard_brush_20_filled = 58503
ic_fluent_clipboard_brush_20_regular = 58504
ic_fluent_clipboard_bullet_list_20_filled = 58505
ic_fluent_clipboard_bullet_list_20_regular = 58506
ic_fluent_clipboard_bullet_list_ltr_20_filled = 58507
ic_fluent_clipboard_bullet_list_ltr_20_regular = 58508
ic_fluent_clipboard_bullet_list_rtl_20_filled = 58509
ic_fluent_clipboard_bullet_list_rtl_20_regular = 58510
ic_fluent_clipboard_checkmark_20_filled = 58511
ic_fluent_clipboard_checkmark_20_regular = 58512
ic_fluent_clipboard_clock_20_filled = 58513
ic_fluent_clipboard_clock_20_regular = 58514
ic_fluent_clipboard_code_20_filled = 58515
ic_fluent_clipboard_code_20_regular = 58516
ic_fluent_clipboard_data_bar_20_filled = 58517
ic_fluent_clipboard_data_bar_20_regular = 58518
ic_fluent_clipboard_day_20_filled = 58519
ic_fluent_clipboard_day_20_regular = 58520
ic_fluent_clipboard_edit_20_filled = 58521
ic_fluent_clipboard_edit_20_regular = 58522
ic_fluent_clipboard_error_20_filled = 58523
ic_fluent_clipboard_error_20_regular = 58524
ic_fluent_clipboard_heart_20_filled = 58525
ic_fluent_clipboard_heart_20_regular = 58526
ic_fluent_clipboard_image_20_filled = 58527
ic_fluent_clipboard_image_20_regular = 58528
ic_fluent_clipboard_letter_20_filled = 58529
ic_fluent_clipboard_letter_20_regular = 58530
ic_fluent_clipboard_link_20_filled = 58531
ic_fluent_clipboard_link_20_regular = 58532
ic_fluent_clipboard_math_formula_20_filled = 58533
ic_fluent_clipboard_math_formula_20_regular = 58534
ic_fluent_clipboard_month_20_filled = 58535
ic_fluent_clipboard_month_20_regular = 58536
ic_fluent_clipboard_more_20_filled = 58537
ic_fluent_clipboard_more_20_regular = 58538
ic_fluent_clipboard_note_20_filled = 58539
ic_fluent_clipboard_note_20_regular = 58540
ic_fluent_clipboard_number_123_20_filled = 58541
ic_fluent_clipboard_number_123_20_regular = 58542
ic_fluent_clipboard_paste_20_filled = 58543
ic_fluent_clipboard_paste_20_regular = 58544
ic_fluent_clipboard_pulse_20_filled = 58545
ic_fluent_clipboard_pulse_20_regular = 58546
ic_fluent_clipboard_search_20_filled = 58547
ic_fluent_clipboard_search_20_regular = 58548
ic_fluent_clipboard_settings_20_filled = 58549
ic_fluent_clipboard_settings_20_regular = 58550
ic_fluent_clipboard_task_20_filled = 58551
ic_fluent_clipboard_task_20_regular = 58552
ic_fluent_clipboard_task_add_20_filled = 58553
ic_fluent_clipboard_task_add_20_regular = 58554
ic_fluent_clipboard_task_list_ltr_20_filled = 58555
ic_fluent_clipboard_task_list_ltr_20_regular = 58556
ic_fluent_clipboard_task_list_rtl_20_filled = 58557
ic_fluent_clipboard_task_list_rtl_20_regular = 58558
ic_fluent_clipboard_text_edit_20_filled = 58559
ic_fluent_clipboard_text_edit_20_regular = 58560
ic_fluent_clipboard_text_ltr_20_filled = 58561
ic_fluent_clipboard_text_ltr_20_regular = 58562
ic_fluent_clipboard_text_rtl_20_filled = 58563
ic_fluent_clipboard_text_rtl_20_regular = 58564
ic_fluent_clock_20_filled = 58565
ic_fluent_clock_20_regular = 58566
ic_fluent_clock_alarm_20_filled = 58567
ic_fluent_clock_alarm_20_regular = 58568
ic_fluent_clock_arrow_download_20_filled = 58569
ic_fluent_clock_arrow_download_20_regular = 58570
ic_fluent_clock_bill_20_filled = 58571
ic_fluent_clock_bill_20_regular = 58572
ic_fluent_clock_dismiss_20_filled = 58573
ic_fluent_clock_dismiss_20_regular = 58574
ic_fluent_clock_lock_20_filled = 58575
ic_fluent_clock_lock_20_regular = 58576
ic_fluent_clock_pause_20_filled = 58577
ic_fluent_clock_pause_20_regular = 58578
ic_fluent_clock_sparkle_20_filled = 58579
ic_fluent_clock_sparkle_20_regular = 58580
ic_fluent_clock_toolbox_20_filled = 58581
ic_fluent_clock_toolbox_20_regular = 58582
ic_fluent_closed_caption_20_filled = 58583
ic_fluent_closed_caption_20_regular = 58584
ic_fluent_closed_caption_off_20_filled = 58585
ic_fluent_closed_caption_off_20_regular = 58586
ic_fluent_clothes_hanger_20_filled = 58587
ic_fluent_clothes_hanger_20_regular = 58588
ic_fluent_cloud_20_filled = 58589
ic_fluent_cloud_20_regular = 58590
ic_fluent_cloud_add_20_filled = 58591
ic_fluent_cloud_add_20_regular = 58592
ic_fluent_cloud_archive_20_filled = 58593
ic_fluent_cloud_archive_20_regular = 58594
ic_fluent_cloud_arrow_down_20_filled = 58595
ic_fluent_cloud_arrow_down_20_regular = 58596
ic_fluent_cloud_arrow_right_20_filled = 58597
ic_fluent_cloud_arrow_right_20_regular = 58598
ic_fluent_cloud_arrow_up_20_filled = 58599
ic_fluent_cloud_arrow_up_20_regular = 58600
ic_fluent_cloud_beaker_20_filled = 58601
ic_fluent_cloud_beaker_20_regular = 58602
ic_fluent_cloud_bidirectional_20_filled = 58603
ic_fluent_cloud_bidirectional_20_regular = 58604
ic_fluent_cloud_checkmark_20_filled = 58605
ic_fluent_cloud_checkmark_20_regular = 58606
ic_fluent_cloud_cube_20_filled = 58607
ic_fluent_cloud_cube_20_regular = 58608
ic_fluent_cloud_database_20_filled = 58609
ic_fluent_cloud_database_20_regular = 58610
ic_fluent_cloud_desktop_20_filled = 58611
ic_fluent_cloud_desktop_20_regular = 58612
ic_fluent_cloud_dismiss_20_filled = 58613
ic_fluent_cloud_dismiss_20_regular = 58614
ic_fluent_cloud_edit_20_filled = 58615
ic_fluent_cloud_edit_20_regular = 58616
ic_fluent_cloud_error_20_filled = 58617
ic_fluent_cloud_error_20_regular = 58618
ic_fluent_cloud_flow_20_filled = 58619
ic_fluent_cloud_flow_20_regular = 58620
ic_fluent_cloud_link_20_filled = 58621
ic_fluent_cloud_link_20_regular = 58622
ic_fluent_cloud_off_20_filled = 58623
ic_fluent_cloud_off_20_regular = 58624
ic_fluent_cloud_swap_20_filled = 58625
ic_fluent_cloud_swap_20_regular = 58626
ic_fluent_cloud_sync_20_filled = 58627
ic_fluent_cloud_sync_20_regular = 58628
ic_fluent_cloud_words_20_filled = 58629
ic_fluent_cloud_words_20_regular = 58630
ic_fluent_clover_20_filled = 58631
ic_fluent_clover_20_regular = 58632
ic_fluent_code_20_filled = 58633
ic_fluent_code_20_regular = 58634
ic_fluent_code_block_20_filled = 58635
ic_fluent_code_block_20_regular = 58636
ic_fluent_code_block_edit_20_filled = 58637
ic_fluent_code_block_edit_20_regular = 58638
ic_fluent_code_circle_20_filled = 58639
ic_fluent_code_circle_20_regular = 58640
ic_fluent_code_text_20_filled = 58641
ic_fluent_code_text_20_regular = 58642
ic_fluent_code_text_edit_20_filled = 58643
ic_fluent_code_text_edit_20_regular = 58644
ic_fluent_coin_multiple_20_filled = 58645
ic_fluent_coin_multiple_20_regular = 58646
ic_fluent_coin_stack_20_filled = 58647
ic_fluent_coin_stack_20_regular = 58648
ic_fluent_collections_20_filled = 58649
ic_fluent_collections_20_regular = 58650
ic_fluent_collections_add_20_filled = 58651
ic_fluent_collections_add_20_regular = 58652
ic_fluent_collections_empty_20_filled = 58653
ic_fluent_collections_empty_20_regular = 58654
ic_fluent_color_20_filled = 58655
ic_fluent_color_20_regular = 58656
ic_fluent_color_background_20_filled = 58657
ic_fluent_color_background_20_regular = 58658
ic_fluent_color_background_accent_20_regular = 58659
ic_fluent_color_fill_20_filled = 58660
ic_fluent_color_fill_20_regular = 58661
ic_fluent_color_fill_accent_20_regular = 58662
ic_fluent_color_line_20_filled = 58663
ic_fluent_color_line_20_regular = 58664
ic_fluent_color_line_accent_20_regular = 58665
ic_fluent_column_20_filled = 58666
ic_fluent_column_20_regular = 58667
ic_fluent_column_arrow_right_20_filled = 58668
ic_fluent_column_arrow_right_20_regular = 58669
ic_fluent_column_double_compare_20_filled = 58670
ic_fluent_column_double_compare_20_regular = 58671
ic_fluent_column_edit_20_filled = 58672
ic_fluent_column_edit_20_regular = 58673
ic_fluent_column_single_compare_20_filled = 58674
ic_fluent_column_single_compare_20_regular = 58675
ic_fluent_column_triple_20_filled = 58676
ic_fluent_column_triple_20_regular = 58677
ic_fluent_column_triple_edit_20_filled = 58678
ic_fluent_column_triple_edit_20_regular = 58679
ic_fluent_comma_20_filled = 58680
ic_fluent_comma_20_regular = 58681
ic_fluent_comment_20_filled = 58682
ic_fluent_comment_20_regular = 58683
ic_fluent_comment_add_20_filled = 58684
ic_fluent_comment_add_20_regular = 58685
ic_fluent_comment_arrow_left_20_filled = 58686
ic_fluent_comment_arrow_left_20_regular = 58687
ic_fluent_comment_arrow_right_20_filled = 58688
ic_fluent_comment_arrow_right_20_regular = 58689
ic_fluent_comment_badge_20_filled = 58690
ic_fluent_comment_badge_20_regular = 58691
ic_fluent_comment_checkmark_20_filled = 58692
ic_fluent_comment_checkmark_20_regular = 58693
ic_fluent_comment_dismiss_20_filled = 58694
ic_fluent_comment_dismiss_20_regular = 58695
ic_fluent_comment_edit_20_filled = 58696
ic_fluent_comment_edit_20_regular = 58697
ic_fluent_comment_error_20_filled = 58698
ic_fluent_comment_error_20_regular = 58699
ic_fluent_comment_lightning_20_filled = 58700
ic_fluent_comment_lightning_20_regular = 58701
ic_fluent_comment_link_20_filled = 58702
ic_fluent_comment_link_20_regular = 58703
ic_fluent_comment_mention_20_filled = 58704
ic_fluent_comment_mention_20_regular = 58705
ic_fluent_comment_multiple_20_filled = 58706
ic_fluent_comment_multiple_20_regular = 58707
ic_fluent_comment_multiple_checkmark_20_filled = 58708
ic_fluent_comment_multiple_checkmark_20_regular = 58709
ic_fluent_comment_multiple_link_20_filled = 58710
ic_fluent_comment_multiple_link_20_regular = 58711
ic_fluent_comment_multiple_mention_20_filled = 58712
ic_fluent_comment_multiple_mention_20_regular = 58713
ic_fluent_comment_note_20_filled = 58714
ic_fluent_comment_note_20_regular = 58715
ic_fluent_comment_off_20_filled = 58716
ic_fluent_comment_off_20_regular = 58717
ic_fluent_comment_quote_20_filled = 58718
ic_fluent_comment_quote_20_regular = 58719
ic_fluent_comment_text_20_filled = 58720
ic_fluent_comment_text_20_regular = 58721
ic_fluent_communication_20_filled = 58722
ic_fluent_communication_20_regular = 58723
ic_fluent_communication_person_20_filled = 58724
ic_fluent_communication_person_20_regular = 58725
ic_fluent_communication_shield_20_filled = 58726
ic_fluent_communication_shield_20_regular = 58727
ic_fluent_compass_northwest_20_filled = 58728
ic_fluent_compass_northwest_20_regular = 58729
ic_fluent_compose_20_filled = 58730
ic_fluent_compose_20_regular = 58731
ic_fluent_conference_room_20_filled = 58732
ic_fluent_conference_room_20_regular = 58733
ic_fluent_connected_20_filled = 58734
ic_fluent_connected_20_regular = 58735
ic_fluent_connector_20_filled = 58736
ic_fluent_connector_20_regular = 58737
ic_fluent_contact_card_20_filled = 58738
ic_fluent_contact_card_20_regular = 58739
ic_fluent_contact_card_group_20_filled = 58740
ic_fluent_contact_card_group_20_regular = 58741
ic_fluent_contact_card_link_20_filled = 58742
ic_fluent_contact_card_link_20_regular = 58743
ic_fluent_contact_card_ribbon_20_filled = 58744
ic_fluent_contact_card_ribbon_20_regular = 58745
ic_fluent_content_settings_20_filled = 58746
ic_fluent_content_settings_20_regular = 58747
ic_fluent_content_view_20_filled = 58748
ic_fluent_content_view_20_regular = 58749
ic_fluent_content_view_gallery_20_filled = 58750
ic_fluent_content_view_gallery_20_regular = 58751
ic_fluent_content_view_gallery_lightning_20_filled = 58752
ic_fluent_content_view_gallery_lightning_20_regular = 58753
ic_fluent_contract_down_left_20_filled = 58754
ic_fluent_contract_down_left_20_regular = 58755
ic_fluent_contract_up_right_20_filled = 58756
ic_fluent_contract_up_right_20_regular = 58757
ic_fluent_control_button_20_filled = 58758
ic_fluent_control_button_20_regular = 58759
ic_fluent_convert_range_20_filled = 58760
ic_fluent_convert_range_20_regular = 58761
ic_fluent_cookies_20_filled = 58762
ic_fluent_cookies_20_regular = 58763
ic_fluent_copy_20_filled = 58764
ic_fluent_copy_20_regular = 58765
ic_fluent_copy_add_20_filled = 58766
ic_fluent_copy_add_20_regular = 58767
ic_fluent_copy_arrow_right_20_filled = 58768
ic_fluent_copy_arrow_right_20_regular = 58769
ic_fluent_copy_select_20_filled = 58770
ic_fluent_copy_select_20_regular = 58771
ic_fluent_couch_20_filled = 58772
ic_fluent_couch_20_regular = 58773
ic_fluent_credit_card_clock_20_filled = 58774
ic_fluent_credit_card_clock_20_regular = 58775
ic_fluent_credit_card_person_20_filled = 58776
ic_fluent_credit_card_person_20_regular = 58777
ic_fluent_credit_card_toolbox_20_filled = 58778
ic_fluent_credit_card_toolbox_20_regular = 58779
ic_fluent_crop_20_filled = 58780
ic_fluent_crop_20_regular = 58781
ic_fluent_crop_arrow_rotate_20_filled = 58782
ic_fluent_crop_arrow_rotate_20_regular = 58783
ic_fluent_crop_interim_20_filled = 58784
ic_fluent_crop_interim_20_regular = 58785
ic_fluent_crop_interim_off_20_filled = 58786
ic_fluent_crop_interim_off_20_regular = 58787
ic_fluent_crown_20_filled = 58788
ic_fluent_crown_20_regular = 58789
ic_fluent_crown_subtract_20_filled = 58790
ic_fluent_crown_subtract_20_regular = 58791
ic_fluent_cube_20_filled = 58792
ic_fluent_cube_20_regular = 58793
ic_fluent_cube_add_20_filled = 58794
ic_fluent_cube_add_20_regular = 58795
ic_fluent_cube_arrow_curve_down_20_filled = 58796
ic_fluent_cube_arrow_curve_down_20_regular = 58797
ic_fluent_cube_checkmark_20_filled = 58798
ic_fluent_cube_checkmark_20_regular = 58799
ic_fluent_cube_link_20_filled = 58800
ic_fluent_cube_link_20_regular = 58801
ic_fluent_cube_multiple_20_filled = 58802
ic_fluent_cube_multiple_20_regular = 58803
ic_fluent_cube_quick_20_filled = 58804
ic_fluent_cube_quick_20_regular = 58805
ic_fluent_cube_rotate_20_filled = 58806
ic_fluent_cube_rotate_20_regular = 58807
ic_fluent_cube_sync_20_filled = 58808
ic_fluent_cube_sync_20_regular = 58809
ic_fluent_cube_tree_20_filled = 58810
ic_fluent_cube_tree_20_regular = 58811
ic_fluent_currency_dollar_euro_20_filled = 58812
ic_fluent_currency_dollar_euro_20_regular = 58813
ic_fluent_currency_dollar_rupee_20_filled = 58814
ic_fluent_currency_dollar_rupee_20_regular = 58815
ic_fluent_cursor_20_filled = 58816
ic_fluent_cursor_20_regular = 58817
ic_fluent_cursor_click_20_filled = 58818
ic_fluent_cursor_click_20_regular = 58819
ic_fluent_cursor_hover_20_filled = 58820
ic_fluent_cursor_hover_20_regular = 58821
ic_fluent_cursor_hover_off_20_filled = 58822
ic_fluent_cursor_hover_off_20_regular = 58823
ic_fluent_cursor_prohibited_20_filled = 58824
ic_fluent_cursor_prohibited_20_regular = 58825
ic_fluent_cut_20_filled = 58826
ic_fluent_cut_20_regular = 58827
ic_fluent_dark_theme_20_filled = 58828
ic_fluent_dark_theme_20_regular = 58829
ic_fluent_data_area_20_filled = 58830
ic_fluent_data_area_20_regular = 58831
ic_fluent_data_bar_horizontal_20_filled = 58832
ic_fluent_data_bar_horizontal_20_regular = 58833
ic_fluent_data_bar_vertical_20_filled = 58834
ic_fluent_data_bar_vertical_20_regular = 58835
ic_fluent_data_bar_vertical_add_20_filled = 58836
ic_fluent_data_bar_vertical_add_20_regular = 58837
ic_fluent_data_bar_vertical_arrow_down_20_filled = 58838
ic_fluent_data_bar_vertical_arrow_down_20_regular = 58839
ic_fluent_data_bar_vertical_ascending_20_filled = 58840
ic_fluent_data_bar_vertical_ascending_20_regular = 58841
ic_fluent_data_bar_vertical_edit_20_filled = 58842
ic_fluent_data_bar_vertical_edit_20_regular = 58843
ic_fluent_data_bar_vertical_star_20_filled = 58844
ic_fluent_data_bar_vertical_star_20_regular = 58845
ic_fluent_data_funnel_20_filled = 58846
ic_fluent_data_funnel_20_regular = 58847
ic_fluent_data_histogram_20_filled = 58848
ic_fluent_data_histogram_20_regular = 58849
ic_fluent_data_line_20_filled = 58850
ic_fluent_data_line_20_regular = 58851
ic_fluent_data_pie_20_filled = 58852
ic_fluent_data_pie_20_regular = 58853
ic_fluent_data_scatter_20_filled = 58854
ic_fluent_data_scatter_20_regular = 58855
ic_fluent_data_sunburst_20_filled = 58856
ic_fluent_data_sunburst_20_regular = 58857
ic_fluent_data_treemap_20_filled = 58858
ic_fluent_data_treemap_20_regular = 58859
ic_fluent_data_trending_20_filled = 58860
ic_fluent_data_trending_20_regular = 58861
ic_fluent_data_usage_20_filled = 58862
ic_fluent_data_usage_20_regular = 58863
ic_fluent_data_usage_checkmark_20_filled = 58864
ic_fluent_data_usage_checkmark_20_regular = 58865
ic_fluent_data_usage_edit_20_filled = 58866
ic_fluent_data_usage_edit_20_regular = 58867
ic_fluent_data_usage_settings_20_filled = 58868
ic_fluent_data_usage_settings_20_regular = 58869
ic_fluent_data_usage_sparkle_20_filled = 58870
ic_fluent_data_usage_sparkle_20_regular = 58871
ic_fluent_data_usage_toolbox_20_filled = 58872
ic_fluent_data_usage_toolbox_20_regular = 58873
ic_fluent_data_waterfall_20_filled = 58874
ic_fluent_data_waterfall_20_regular = 58875
ic_fluent_data_whisker_20_filled = 58876
ic_fluent_data_whisker_20_regular = 58877
ic_fluent_database_20_filled = 58878
ic_fluent_database_20_regular = 58879
ic_fluent_database_arrow_down_20_filled = 58880
ic_fluent_database_arrow_down_20_regular = 58881
ic_fluent_database_arrow_right_20_filled = 58882
ic_fluent_database_arrow_right_20_regular = 58883
ic_fluent_database_arrow_up_20_filled = 58884
ic_fluent_database_arrow_up_20_regular = 58885
ic_fluent_database_checkmark_20_filled = 58886
ic_fluent_database_checkmark_20_regular = 58887
ic_fluent_database_lightning_20_filled = 58888
ic_fluent_database_lightning_20_regular = 58889
ic_fluent_database_link_20_filled = 58890
ic_fluent_database_link_20_regular = 58891
ic_fluent_database_multiple_20_filled = 58892
ic_fluent_database_multiple_20_regular = 58893
ic_fluent_database_person_20_filled = 58894
ic_fluent_database_person_20_regular = 58895
ic_fluent_database_plug_connected_20_filled = 58896
ic_fluent_database_plug_connected_20_regular = 58897
ic_fluent_database_search_20_filled = 58898
ic_fluent_database_search_20_regular = 58899
ic_fluent_database_switch_20_filled = 58900
ic_fluent_database_switch_20_regular = 58901
ic_fluent_database_warning_20_filled = 58902
ic_fluent_database_warning_20_regular = 58903
ic_fluent_database_window_20_filled = 58904
ic_fluent_database_window_20_regular = 58905
ic_fluent_decimal_arrow_left_20_filled = 58906
ic_fluent_decimal_arrow_left_20_regular = 58907
ic_fluent_decimal_arrow_right_20_filled = 58908
ic_fluent_decimal_arrow_right_20_regular = 58909
ic_fluent_delete_20_filled = 58910
ic_fluent_delete_20_regular = 58911
ic_fluent_delete_arrow_back_20_filled = 58912
ic_fluent_delete_arrow_back_20_regular = 58913
ic_fluent_delete_dismiss_20_filled = 58914
ic_fluent_delete_dismiss_20_regular = 58915
ic_fluent_delete_lines_20_filled = 58916
ic_fluent_delete_lines_20_regular = 58917
ic_fluent_delete_off_20_filled = 58918
ic_fluent_delete_off_20_regular = 58919
ic_fluent_dentist_20_filled = 58920
ic_fluent_dentist_20_regular = 58921
ic_fluent_design_ideas_20_filled = 58922
ic_fluent_design_ideas_20_regular = 58923
ic_fluent_desk_20_filled = 58924
ic_fluent_desk_20_regular = 58925
ic_fluent_desk_multiple_20_filled = 58926
ic_fluent_desk_multiple_20_regular = 58927
ic_fluent_desk_sparkle_20_filled = 58928
ic_fluent_desk_sparkle_20_regular = 58929
ic_fluent_desktop_20_filled = 58930
ic_fluent_desktop_20_regular = 58931
ic_fluent_desktop_arrow_down_20_filled = 58932
ic_fluent_desktop_arrow_down_20_regular = 58933
ic_fluent_desktop_arrow_down_off_20_filled = 58934
ic_fluent_desktop_arrow_down_off_20_regular = 58935
ic_fluent_desktop_arrow_right_20_filled = 58936
ic_fluent_desktop_arrow_right_20_regular = 58937
ic_fluent_desktop_checkmark_20_filled = 58938
ic_fluent_desktop_checkmark_20_regular = 58939
ic_fluent_desktop_cursor_20_filled = 58940
ic_fluent_desktop_cursor_20_regular = 58941
ic_fluent_desktop_edit_20_filled = 58942
ic_fluent_desktop_edit_20_regular = 58943
ic_fluent_desktop_flow_20_filled = 58944
ic_fluent_desktop_flow_20_regular = 58945
ic_fluent_desktop_keyboard_20_filled = 58946
ic_fluent_desktop_keyboard_20_regular = 58947
ic_fluent_desktop_mac_20_filled = 58948
ic_fluent_desktop_mac_20_regular = 58949
ic_fluent_desktop_off_20_filled = 58950
ic_fluent_desktop_off_20_regular = 58951
ic_fluent_desktop_pulse_20_filled = 58952
ic_fluent_desktop_pulse_20_regular = 58953
ic_fluent_desktop_signal_20_filled = 58954
ic_fluent_desktop_signal_20_regular = 58955
ic_fluent_desktop_speaker_20_filled = 58956
ic_fluent_desktop_speaker_20_regular = 58957
ic_fluent_desktop_speaker_off_20_filled = 58958
ic_fluent_desktop_speaker_off_20_regular = 58959
ic_fluent_desktop_sync_20_filled = 58960
ic_fluent_desktop_sync_20_regular = 58961
ic_fluent_desktop_toolbox_20_filled = 58962
ic_fluent_desktop_toolbox_20_regular = 58963
ic_fluent_desktop_tower_20_filled = 58964
ic_fluent_desktop_tower_20_regular = 58965
ic_fluent_developer_board_20_filled = 58966
ic_fluent_developer_board_20_regular = 58967
ic_fluent_developer_board_lightning_20_filled = 58968
ic_fluent_developer_board_lightning_20_regular = 58969
ic_fluent_developer_board_lightning_toolbox_20_filled = 58970
ic_fluent_developer_board_lightning_toolbox_20_regular = 58971
ic_fluent_developer_board_search_20_filled = 58972
ic_fluent_developer_board_search_20_regular = 58973
ic_fluent_device_eq_20_filled = 58974
ic_fluent_device_eq_20_regular = 58975
ic_fluent_device_meeting_room_20_filled = 58976
ic_fluent_device_meeting_room_20_regular = 58977
ic_fluent_device_meeting_room_remote_20_filled = 58978
ic_fluent_device_meeting_room_remote_20_regular = 58979
ic_fluent_diagram_20_filled = 58980
ic_fluent_diagram_20_regular = 58981
ic_fluent_dialpad_20_filled = 58982
ic_fluent_dialpad_20_regular = 58983
ic_fluent_dialpad_off_20_filled = 58984
ic_fluent_dialpad_off_20_regular = 58985
ic_fluent_dialpad_question_mark_20_filled = 58986
ic_fluent_dialpad_question_mark_20_regular = 58987
ic_fluent_diamond_20_filled = 58988
ic_fluent_diamond_20_regular = 58989
ic_fluent_diamond_dismiss_20_filled = 58990
ic_fluent_diamond_dismiss_20_regular = 58991
ic_fluent_directions_20_filled = 58992
ic_fluent_directions_20_regular = 58993
ic_fluent_dishwasher_20_filled = 58994
ic_fluent_dishwasher_20_regular = 58995
ic_fluent_dismiss_20_filled = 58996
ic_fluent_dismiss_20_regular = 58997
ic_fluent_dismiss_circle_20_filled = 58998
ic_fluent_dismiss_circle_20_regular = 58999
ic_fluent_dismiss_square_20_filled = 59000
ic_fluent_dismiss_square_20_regular = 59001
ic_fluent_dismiss_square_multiple_20_filled = 59002
ic_fluent_dismiss_square_multiple_20_regular = 59003
ic_fluent_diversity_20_filled = 59004
ic_fluent_diversity_20_regular = 59005
ic_fluent_divider_short_20_filled = 59006
ic_fluent_divider_short_20_regular = 59007
ic_fluent_divider_tall_20_filled = 59008
ic_fluent_divider_tall_20_regular = 59009
ic_fluent_dock_20_filled = 59010
ic_fluent_dock_20_regular = 59011
ic_fluent_dock_row_20_filled = 59012
ic_fluent_dock_row_20_regular = 59013
ic_fluent_doctor_20_filled = 59014
ic_fluent_doctor_20_regular = 59015
ic_fluent_document_100_20_filled = 59016
ic_fluent_document_100_20_regular = 59017
ic_fluent_document_20_filled = 59018
ic_fluent_document_20_regular = 59019
ic_fluent_document_add_20_filled = 59020
ic_fluent_document_add_20_regular = 59021
ic_fluent_document_arrow_down_20_filled = 59022
ic_fluent_document_arrow_down_20_regular = 59023
ic_fluent_document_arrow_left_20_filled = 59024
ic_fluent_document_arrow_left_20_regular = 59025
ic_fluent_document_arrow_right_20_filled = 59026
ic_fluent_document_arrow_right_20_regular = 59027
ic_fluent_document_arrow_up_20_filled = 59028
ic_fluent_document_arrow_up_20_regular = 59029
ic_fluent_document_border_20_filled = 59030
ic_fluent_document_border_20_regular = 59031
ic_fluent_document_border_print_20_filled = 59032
ic_fluent_document_border_print_20_regular = 59033
ic_fluent_document_briefcase_20_filled = 59034
ic_fluent_document_briefcase_20_regular = 59035
ic_fluent_document_bullet_list_20_filled = 59036
ic_fluent_document_bullet_list_20_regular = 59037
ic_fluent_document_bullet_list_arrow_left_20_filled = 59038
ic_fluent_document_bullet_list_arrow_left_20_regular = 59039
ic_fluent_document_bullet_list_clock_20_filled = 59040
ic_fluent_document_bullet_list_clock_20_regular = 59041
ic_fluent_document_bullet_list_cube_20_filled = 59042
ic_fluent_document_bullet_list_cube_20_regular = 59043
ic_fluent_document_bullet_list_multiple_20_filled = 59044
ic_fluent_document_bullet_list_multiple_20_regular = 59045
ic_fluent_document_bullet_list_off_20_filled = 59046
ic_fluent_document_bullet_list_off_20_regular = 59047
ic_fluent_document_catch_up_20_filled = 59048
ic_fluent_document_catch_up_20_regular = 59049
ic_fluent_document_checkmark_20_filled = 59050
ic_fluent_document_checkmark_20_regular = 59051
ic_fluent_document_chevron_double_20_filled = 59052
ic_fluent_document_chevron_double_20_regular = 59053
ic_fluent_document_copy_20_filled = 59054
ic_fluent_document_copy_20_regular = 59055
ic_fluent_document_css_20_filled = 59056
ic_fluent_document_css_20_regular = 59057
ic_fluent_document_cube_20_filled = 59058
ic_fluent_document_cube_20_regular = 59059
ic_fluent_document_data_20_filled = 59060
ic_fluent_document_data_20_regular = 59061
ic_fluent_document_data_link_20_filled = 59062
ic_fluent_document_data_link_20_regular = 59063
ic_fluent_document_data_lock_20_filled = 59064
ic_fluent_document_data_lock_20_regular = 59065
ic_fluent_document_database_20_filled = 59066
ic_fluent_document_database_20_regular = 59067
ic_fluent_document_dismiss_20_filled = 59068
ic_fluent_document_dismiss_20_regular = 59069
ic_fluent_document_edit_20_filled = 59070
ic_fluent_document_edit_20_regular = 59071
ic_fluent_document_endnote_20_filled = 59072
ic_fluent_document_endnote_20_regular = 59073
ic_fluent_document_error_20_filled = 59074
ic_fluent_document_error_20_regular = 59075
ic_fluent_document_fit_20_filled = 59076
ic_fluent_document_fit_20_regular = 59077
ic_fluent_document_flowchart_20_filled = 59078
ic_fluent_document_flowchart_20_regular = 59079
ic_fluent_document_folder_20_filled = 59080
ic_fluent_document_folder_20_regular = 59081
ic_fluent_document_footer_20_filled = 59082
ic_fluent_document_footer_20_regular = 59083
ic_fluent_document_footer_dismiss_20_filled = 59084
ic_fluent_document_footer_dismiss_20_regular = 59085
ic_fluent_document_globe_20_filled = 59086
ic_fluent_document_globe_20_regular = 59087
ic_fluent_document_header_20_filled = 59088
ic_fluent_document_header_20_regular = 59089
ic_fluent_document_header_arrow_down_20_filled = 59090
ic_fluent_document_header_arrow_down_20_regular = 59091
ic_fluent_document_header_dismiss_20_filled = 59092
ic_fluent_document_header_dismiss_20_regular = 59093
ic_fluent_document_header_footer_20_filled = 59094
ic_fluent_document_header_footer_20_regular = 59095
ic_fluent_document_heart_20_filled = 59096
ic_fluent_document_heart_20_regular = 59097
ic_fluent_document_heart_pulse_20_filled = 59098
ic_fluent_document_heart_pulse_20_regular = 59099
ic_fluent_document_image_20_filled = 59100
ic_fluent_document_image_20_regular = 59101
ic_fluent_document_java_20_filled = 59102
ic_fluent_document_java_20_regular = 59103
ic_fluent_document_javascript_20_filled = 59104
ic_fluent_document_javascript_20_regular = 59105
ic_fluent_document_key_20_filled = 59106
ic_fluent_document_key_20_regular = 59107
ic_fluent_document_landscape_20_filled = 59108
ic_fluent_document_landscape_20_regular = 59109
ic_fluent_document_landscape_data_20_filled = 59110
ic_fluent_document_landscape_data_20_regular = 59111
ic_fluent_document_landscape_split_20_filled = 59112
ic_fluent_document_landscape_split_20_regular = 59113
ic_fluent_document_landscape_split_hint_20_filled = 59114
ic_fluent_document_landscape_split_hint_20_regular = 59115
ic_fluent_document_lightning_20_filled = 59116
ic_fluent_document_lightning_20_regular = 59117
ic_fluent_document_link_20_filled = 59118
ic_fluent_document_link_20_regular = 59119
ic_fluent_document_lock_20_filled = 59120
ic_fluent_document_lock_20_regular = 59121
ic_fluent_document_margins_20_filled = 59122
ic_fluent_document_margins_20_regular = 59123
ic_fluent_document_mention_20_filled = 59124
ic_fluent_document_mention_20_regular = 59125
ic_fluent_document_multiple_20_filled = 59126
ic_fluent_document_multiple_20_regular = 59127
ic_fluent_document_multiple_percent_20_filled = 59128
ic_fluent_document_multiple_percent_20_regular = 59129
ic_fluent_document_multiple_prohibited_20_filled = 59130
ic_fluent_document_multiple_prohibited_20_regular = 59131
ic_fluent_document_multiple_sync_20_filled = 59132
ic_fluent_document_multiple_sync_20_regular = 59133
ic_fluent_document_one_page_20_filled = 59134
ic_fluent_document_one_page_20_regular = 59135
ic_fluent_document_one_page_add_20_filled = 59136
ic_fluent_document_one_page_add_20_regular = 59137
ic_fluent_document_one_page_columns_20_filled = 59138
ic_fluent_document_one_page_columns_20_regular = 59139
ic_fluent_document_one_page_link_20_filled = 59140
ic_fluent_document_one_page_link_20_regular = 59141
ic_fluent_document_one_page_multiple_20_filled = 59142
ic_fluent_document_one_page_multiple_20_regular = 59143
ic_fluent_document_one_page_multiple_sparkle_20_filled = 59144
ic_fluent_document_one_page_multiple_sparkle_20_regular = 59145
ic_fluent_document_one_page_sparkle_20_filled = 59146
ic_fluent_document_one_page_sparkle_20_regular = 59147
ic_fluent_document_page_bottom_center_20_filled = 59148
ic_fluent_document_page_bottom_center_20_regular = 59149
ic_fluent_document_page_bottom_left_20_filled = 59150
ic_fluent_document_page_bottom_left_20_regular = 59151
ic_fluent_document_page_bottom_right_20_filled = 59152
ic_fluent_document_page_bottom_right_20_regular = 59153
ic_fluent_document_page_break_20_filled = 59154
ic_fluent_document_page_break_20_regular = 59155
ic_fluent_document_page_number_20_filled = 59156
ic_fluent_document_page_number_20_regular = 59157
ic_fluent_document_page_top_center_20_filled = 59158
ic_fluent_document_page_top_center_20_regular = 59159
ic_fluent_document_page_top_left_20_filled = 59160
ic_fluent_document_page_top_left_20_regular = 59161
ic_fluent_document_page_top_right_20_filled = 59162
ic_fluent_document_page_top_right_20_regular = 59163
ic_fluent_document_pdf_20_filled = 59164
ic_fluent_document_pdf_20_regular = 59165
ic_fluent_document_percent_20_filled = 59166
ic_fluent_document_percent_20_regular = 59167
ic_fluent_document_person_20_filled = 59168
ic_fluent_document_person_20_regular = 59169
ic_fluent_document_pill_20_filled = 59170
ic_fluent_document_pill_20_regular = 59171
ic_fluent_document_print_20_filled = 59172
ic_fluent_document_print_20_regular = 59173
ic_fluent_document_prohibited_20_filled = 59174
ic_fluent_document_prohibited_20_regular = 59175
ic_fluent_document_question_mark_20_filled = 59176
ic_fluent_document_question_mark_20_regular = 59177
ic_fluent_document_queue_20_filled = 59178
ic_fluent_document_queue_20_regular = 59179
ic_fluent_document_queue_add_20_filled = 59180
ic_fluent_document_queue_add_20_regular = 59181
ic_fluent_document_queue_multiple_20_filled = 59182
ic_fluent_document_queue_multiple_20_regular = 59183
ic_fluent_document_ribbon_20_filled = 59184
ic_fluent_document_ribbon_20_regular = 59185
ic_fluent_document_sass_20_filled = 59186
ic_fluent_document_sass_20_regular = 59187
ic_fluent_document_save_20_filled = 59188
ic_fluent_document_save_20_regular = 59189
ic_fluent_document_search_20_filled = 59190
ic_fluent_document_search_20_regular = 59191
ic_fluent_document_settings_20_filled = 59192
ic_fluent_document_settings_20_regular = 59193
ic_fluent_document_signature_20_filled = 59194
ic_fluent_document_signature_20_regular = 59195
ic_fluent_document_sparkle_20_filled = 59196
ic_fluent_document_sparkle_20_regular = 59197
ic_fluent_document_split_hint_20_filled = 59198
ic_fluent_document_split_hint_20_regular = 59199
ic_fluent_document_split_hint_off_20_filled = 59200
ic_fluent_document_split_hint_off_20_regular = 59201
ic_fluent_document_sync_20_filled = 59202
ic_fluent_document_sync_20_regular = 59203
ic_fluent_document_table_20_filled = 59204
ic_fluent_document_table_20_regular = 59205
ic_fluent_document_table_arrow_right_20_filled = 59206
ic_fluent_document_table_arrow_right_20_regular = 59207
ic_fluent_document_table_checkmark_20_filled = 59208
ic_fluent_document_table_checkmark_20_regular = 59209
ic_fluent_document_table_cube_20_filled = 59210
ic_fluent_document_table_cube_20_regular = 59211
ic_fluent_document_table_search_20_filled = 59212
ic_fluent_document_table_search_20_regular = 59213
ic_fluent_document_table_truck_20_filled = 59214
ic_fluent_document_table_truck_20_regular = 59215
ic_fluent_document_target_20_filled = 59216
ic_fluent_document_target_20_regular = 59217
ic_fluent_document_text_20_filled = 59218
ic_fluent_document_text_20_regular = 59219
ic_fluent_document_text_clock_20_filled = 59220
ic_fluent_document_text_clock_20_regular = 59221
ic_fluent_document_text_extract_20_filled = 59222
ic_fluent_document_text_extract_20_regular = 59223
ic_fluent_document_text_link_20_filled = 59224
ic_fluent_document_text_link_20_regular = 59225
ic_fluent_document_text_toolbox_20_filled = 59226
ic_fluent_document_text_toolbox_20_regular = 59227
ic_fluent_document_toolbox_20_filled = 59228
ic_fluent_document_toolbox_20_regular = 59229
ic_fluent_document_width_20_filled = 59230
ic_fluent_document_width_20_regular = 59231
ic_fluent_document_yml_20_filled = 59232
ic_fluent_document_yml_20_regular = 59233
ic_fluent_door_20_filled = 59234
ic_fluent_door_20_regular = 59235
ic_fluent_door_arrow_left_20_filled = 59236
ic_fluent_door_arrow_left_20_regular = 59237
ic_fluent_door_arrow_right_20_filled = 59238
ic_fluent_door_arrow_right_20_regular = 59239
ic_fluent_door_tag_20_filled = 59240
ic_fluent_door_tag_20_regular = 59241
ic_fluent_double_swipe_down_20_filled = 59242
ic_fluent_double_swipe_down_20_regular = 59243
ic_fluent_double_swipe_up_20_filled = 59244
ic_fluent_double_swipe_up_20_regular = 59245
ic_fluent_double_tap_swipe_down_20_filled = 59246
ic_fluent_double_tap_swipe_down_20_regular = 59247
ic_fluent_double_tap_swipe_up_20_filled = 59248
ic_fluent_double_tap_swipe_up_20_regular = 59249
ic_fluent_drafts_20_filled = 59250
ic_fluent_drafts_20_regular = 59251
ic_fluent_drag_20_filled = 59252
ic_fluent_drag_20_regular = 59253
ic_fluent_draw_image_20_filled = 59254
ic_fluent_draw_image_20_regular = 59255
ic_fluent_draw_shape_20_filled = 59256
ic_fluent_draw_shape_20_regular = 59257
ic_fluent_draw_text_20_filled = 59258
ic_fluent_draw_text_20_regular = 59259
ic_fluent_drawer_20_filled = 59260
ic_fluent_drawer_20_regular = 59261
ic_fluent_drawer_add_20_filled = 59262
ic_fluent_drawer_add_20_regular = 59263
ic_fluent_drawer_arrow_download_20_filled = 59264
ic_fluent_drawer_arrow_download_20_regular = 59265
ic_fluent_drawer_dismiss_20_filled = 59266
ic_fluent_drawer_dismiss_20_regular = 59267
ic_fluent_drawer_play_20_filled = 59268
ic_fluent_drawer_play_20_regular = 59269
ic_fluent_drawer_subtract_20_filled = 59270
ic_fluent_drawer_subtract_20_regular = 59271
ic_fluent_drink_beer_20_filled = 59272
ic_fluent_drink_beer_20_regular = 59273
ic_fluent_drink_bottle_20_filled = 59274
ic_fluent_drink_bottle_20_regular = 59275
ic_fluent_drink_bottle_off_20_filled = 59276
ic_fluent_drink_bottle_off_20_regular = 59277
ic_fluent_drink_coffee_20_filled = 59278
ic_fluent_drink_coffee_20_regular = 59279
ic_fluent_drink_margarita_20_filled = 59280
ic_fluent_drink_margarita_20_regular = 59281
ic_fluent_drink_to_go_20_filled = 59282
ic_fluent_drink_to_go_20_regular = 59283
ic_fluent_drink_wine_20_filled = 59284
ic_fluent_drink_wine_20_regular = 59285
ic_fluent_drive_train_20_filled = 59286
ic_fluent_drive_train_20_regular = 59287
ic_fluent_drop_20_filled = 59288
ic_fluent_drop_20_regular = 59289
ic_fluent_dual_screen_20_filled = 59290
ic_fluent_dual_screen_20_regular = 59291
ic_fluent_dual_screen_add_20_filled = 59292
ic_fluent_dual_screen_add_20_regular = 59293
ic_fluent_dual_screen_arrow_right_20_filled = 59294
ic_fluent_dual_screen_arrow_right_20_regular = 59295
ic_fluent_dual_screen_arrow_up_20_filled = 59296
ic_fluent_dual_screen_arrow_up_20_regular = 59297
ic_fluent_dual_screen_clock_20_filled = 59298
ic_fluent_dual_screen_clock_20_regular = 59299
ic_fluent_dual_screen_closed_alert_20_filled = 59300
ic_fluent_dual_screen_closed_alert_20_regular = 59301
ic_fluent_dual_screen_desktop_20_filled = 59302
ic_fluent_dual_screen_desktop_20_regular = 59303
ic_fluent_dual_screen_dismiss_20_filled = 59304
ic_fluent_dual_screen_dismiss_20_regular = 59305
ic_fluent_dual_screen_group_20_filled = 59306
ic_fluent_dual_screen_group_20_regular = 59307
ic_fluent_dual_screen_header_20_filled = 59308
ic_fluent_dual_screen_header_20_regular = 59309
ic_fluent_dual_screen_lock_20_filled = 59310
ic_fluent_dual_screen_lock_20_regular = 59311
ic_fluent_dual_screen_mirror_20_filled = 59312
ic_fluent_dual_screen_mirror_20_regular = 59313
ic_fluent_dual_screen_pagination_20_filled = 59314
ic_fluent_dual_screen_pagination_20_regular = 59315
ic_fluent_dual_screen_settings_20_filled = 59316
ic_fluent_dual_screen_settings_20_regular = 59317
ic_fluent_dual_screen_span_20_filled = 59318
ic_fluent_dual_screen_span_20_regular = 59319
ic_fluent_dual_screen_speaker_20_filled = 59320
ic_fluent_dual_screen_speaker_20_regular = 59321
ic_fluent_dual_screen_status_bar_20_filled = 59322
ic_fluent_dual_screen_status_bar_20_regular = 59323
ic_fluent_dual_screen_tablet_20_filled = 59324
ic_fluent_dual_screen_tablet_20_regular = 59325
ic_fluent_dual_screen_update_20_filled = 59326
ic_fluent_dual_screen_update_20_regular = 59327
ic_fluent_dual_screen_vertical_scroll_20_filled = 59328
ic_fluent_dual_screen_vertical_scroll_20_regular = 59329
ic_fluent_dual_screen_vibrate_20_filled = 59330
ic_fluent_dual_screen_vibrate_20_regular = 59331
ic_fluent_dumbbell_20_filled = 59332
ic_fluent_dumbbell_20_regular = 59333
ic_fluent_dust_20_filled = 59334
ic_fluent_dust_20_regular = 59335
ic_fluent_earth_20_filled = 59336
ic_fluent_earth_20_regular = 59337
ic_fluent_earth_leaf_20_filled = 59338
ic_fluent_earth_leaf_20_regular = 59339
ic_fluent_edit_20_filled = 59340
ic_fluent_edit_20_regular = 59341
ic_fluent_edit_arrow_back_20_filled = 59342
ic_fluent_edit_arrow_back_20_regular = 59343
ic_fluent_edit_line_horizontal_3_20_filled = 59344
ic_fluent_edit_line_horizontal_3_20_regular = 59345
ic_fluent_edit_lock_20_filled = 59346
ic_fluent_edit_lock_20_regular = 59347
ic_fluent_edit_off_20_filled = 59348
ic_fluent_edit_off_20_regular = 59349
ic_fluent_edit_person_20_filled = 59350
ic_fluent_edit_person_20_regular = 59351
ic_fluent_edit_prohibited_20_filled = 59352
ic_fluent_edit_prohibited_20_regular = 59353
ic_fluent_edit_settings_20_filled = 59354
ic_fluent_edit_settings_20_regular = 59355
ic_fluent_elevator_20_filled = 59356
ic_fluent_elevator_20_regular = 59357
ic_fluent_emoji_20_filled = 59358
ic_fluent_emoji_20_regular = 59359
ic_fluent_emoji_add_20_filled = 59360
ic_fluent_emoji_add_20_regular = 59361
ic_fluent_emoji_angry_20_filled = 59362
ic_fluent_emoji_angry_20_regular = 59363
ic_fluent_emoji_edit_20_filled = 59364
ic_fluent_emoji_edit_20_regular = 59365
ic_fluent_emoji_hand_20_filled = 59366
ic_fluent_emoji_hand_20_regular = 59367
ic_fluent_emoji_hint_20_filled = 59368
ic_fluent_emoji_hint_20_regular = 59369
ic_fluent_emoji_laugh_20_filled = 59370
ic_fluent_emoji_laugh_20_regular = 59371
ic_fluent_emoji_meh_20_filled = 59372
ic_fluent_emoji_meh_20_regular = 59373
ic_fluent_emoji_meme_20_filled = 59374
ic_fluent_emoji_meme_20_regular = 59375
ic_fluent_emoji_multiple_20_filled = 59376
ic_fluent_emoji_multiple_20_regular = 59377
ic_fluent_emoji_sad_20_filled = 59378
ic_fluent_emoji_sad_20_regular = 59379
ic_fluent_emoji_sad_slight_20_filled = 59380
ic_fluent_emoji_sad_slight_20_regular = 59381
ic_fluent_emoji_smile_slight_20_filled = 59382
ic_fluent_emoji_smile_slight_20_regular = 59383
ic_fluent_emoji_sparkle_20_filled = 59384
ic_fluent_emoji_sparkle_20_regular = 59385
ic_fluent_emoji_surprise_20_filled = 59386
ic_fluent_emoji_surprise_20_regular = 59387
ic_fluent_engine_20_filled = 59388
ic_fluent_engine_20_regular = 59389
ic_fluent_equal_circle_20_filled = 59390
ic_fluent_equal_circle_20_regular = 59391
ic_fluent_equal_off_20_filled = 59392
ic_fluent_equal_off_20_regular = 59393
ic_fluent_eraser_20_filled = 59394
ic_fluent_eraser_20_regular = 59395
ic_fluent_eraser_medium_20_filled = 59396
ic_fluent_eraser_medium_20_regular = 59397
ic_fluent_eraser_segment_20_filled = 59398
ic_fluent_eraser_segment_20_regular = 59399
ic_fluent_eraser_small_20_filled = 59400
ic_fluent_eraser_small_20_regular = 59401
ic_fluent_eraser_tool_20_filled = 59402
ic_fluent_eraser_tool_20_regular = 59403
ic_fluent_error_circle_20_filled = 59404
ic_fluent_error_circle_20_regular = 59405
ic_fluent_error_circle_settings_20_filled = 59406
ic_fluent_error_circle_settings_20_regular = 59407
ic_fluent_expand_up_left_20_filled = 59408
ic_fluent_expand_up_left_20_regular = 59409
ic_fluent_expand_up_right_20_filled = 59410
ic_fluent_expand_up_right_20_regular = 59411
ic_fluent_extended_dock_20_filled = 59412
ic_fluent_extended_dock_20_regular = 59413
ic_fluent_eye_20_filled = 59414
ic_fluent_eye_20_regular = 59415
ic_fluent_eye_lines_20_filled = 59416
ic_fluent_eye_lines_20_regular = 59417
ic_fluent_eye_off_20_filled = 59418
ic_fluent_eye_off_20_regular = 59419
ic_fluent_eye_tracking_20_filled = 59420
ic_fluent_eye_tracking_20_regular = 59421
ic_fluent_eye_tracking_off_20_filled = 59422
ic_fluent_eye_tracking_off_20_regular = 59423
ic_fluent_eyedropper_20_filled = 59424
ic_fluent_eyedropper_20_regular = 59425
ic_fluent_eyedropper_off_20_filled = 59426
ic_fluent_eyedropper_off_20_regular = 59427
ic_fluent_f_stop_20_filled = 59428
ic_fluent_f_stop_20_regular = 59429
ic_fluent_fast_acceleration_20_filled = 59430
ic_fluent_fast_acceleration_20_regular = 59431
ic_fluent_fast_forward_20_filled = 59432
ic_fluent_fast_forward_20_regular = 59433
ic_fluent_fax_20_filled = 59434
ic_fluent_fax_20_regular = 59435
ic_fluent_feed_20_filled = 59436
ic_fluent_feed_20_regular = 59437
ic_fluent_filmstrip_20_filled = 59438
ic_fluent_filmstrip_20_regular = 59439
ic_fluent_filmstrip_image_20_filled = 59440
ic_fluent_filmstrip_image_20_regular = 59441
ic_fluent_filmstrip_play_20_filled = 59442
ic_fluent_filmstrip_play_20_regular = 59443
ic_fluent_filmstrip_split_20_filled = 59444
ic_fluent_filmstrip_split_20_regular = 59445
ic_fluent_filter_20_filled = 59446
ic_fluent_filter_20_regular = 59447
ic_fluent_filter_add_20_filled = 59448
ic_fluent_filter_add_20_regular = 59449
ic_fluent_filter_dismiss_20_filled = 59450
ic_fluent_filter_dismiss_20_regular = 59451
ic_fluent_filter_sync_20_filled = 59452
ic_fluent_filter_sync_20_regular = 59453
ic_fluent_fingerprint_20_filled = 59454
ic_fluent_fingerprint_20_regular = 59455
ic_fluent_fire_20_filled = 59456
ic_fluent_fire_20_regular = 59457
ic_fluent_fireplace_20_filled = 59458
ic_fluent_fireplace_20_regular = 59459
ic_fluent_fixed_width_20_filled = 59460
ic_fluent_fixed_width_20_regular = 59461
ic_fluent_flag_20_filled = 59462
ic_fluent_flag_20_regular = 59463
ic_fluent_flag_checkered_20_filled = 59464
ic_fluent_flag_checkered_20_regular = 59465
ic_fluent_flag_clock_20_filled = 59466
ic_fluent_flag_clock_20_regular = 59467
ic_fluent_flag_off_20_filled = 59468
ic_fluent_flag_off_20_regular = 59469
ic_fluent_flag_pride_20_filled = 59470
ic_fluent_flag_pride_intersex_inclusive_progress_20_filled = 59471
ic_fluent_flag_pride_philadelphia_20_filled = 59472
ic_fluent_flag_pride_progress_20_filled = 59473
ic_fluent_flash_20_filled = 59474
ic_fluent_flash_20_regular = 59475
ic_fluent_flash_add_20_filled = 59476
ic_fluent_flash_add_20_regular = 59477
ic_fluent_flash_auto_20_filled = 59478
ic_fluent_flash_auto_20_regular = 59479
ic_fluent_flash_checkmark_20_filled = 59480
ic_fluent_flash_checkmark_20_regular = 59481
ic_fluent_flash_flow_20_filled = 59482
ic_fluent_flash_flow_20_regular = 59483
ic_fluent_flash_off_20_filled = 59484
ic_fluent_flash_off_20_regular = 59485
ic_fluent_flash_play_20_filled = 59486
ic_fluent_flash_play_20_regular = 59487
ic_fluent_flash_settings_20_filled = 59488
ic_fluent_flash_settings_20_regular = 59489
ic_fluent_flash_sparkle_20_filled = 59490
ic_fluent_flash_sparkle_20_regular = 59491
ic_fluent_flashlight_20_filled = 59492
ic_fluent_flashlight_20_regular = 59493
ic_fluent_flashlight_off_20_filled = 59494
ic_fluent_flashlight_off_20_regular = 59495
ic_fluent_flip_horizontal_20_filled = 59496
ic_fluent_flip_horizontal_20_regular = 59497
ic_fluent_flip_vertical_20_filled = 59498
ic_fluent_flip_vertical_20_regular = 59499
ic_fluent_flow_20_filled = 59500
ic_fluent_flow_20_regular = 59501
ic_fluent_flow_sparkle_20_filled = 59502
ic_fluent_flow_sparkle_20_regular = 59503
ic_fluent_flowchart_20_filled = 59504
ic_fluent_flowchart_20_regular = 59505
ic_fluent_flowchart_circle_20_filled = 59506
ic_fluent_flowchart_circle_20_regular = 59507
ic_fluent_fluent_20_filled = 59508
ic_fluent_fluent_20_regular = 59509
ic_fluent_fluid_20_filled = 59510
ic_fluent_fluid_20_regular = 59511
ic_fluent_folder_20_filled = 59512
ic_fluent_folder_20_regular = 59513
ic_fluent_folder_add_20_filled = 59514
ic_fluent_folder_add_20_regular = 59515
ic_fluent_folder_arrow_left_20_filled = 59516
ic_fluent_folder_arrow_left_20_regular = 59517
ic_fluent_folder_arrow_right_20_filled = 59518
ic_fluent_folder_arrow_right_20_regular = 59519
ic_fluent_folder_arrow_up_20_filled = 59520
ic_fluent_folder_arrow_up_20_regular = 59521
ic_fluent_folder_briefcase_20_filled = 59522
ic_fluent_folder_briefcase_20_regular = 59523
ic_fluent_folder_document_20_filled = 59524
ic_fluent_folder_document_20_regular = 59525
ic_fluent_folder_globe_20_filled = 59526
ic_fluent_folder_globe_20_regular = 59527
ic_fluent_folder_lightning_20_filled = 59528
ic_fluent_folder_lightning_20_regular = 59529
ic_fluent_folder_link_20_filled = 59530
ic_fluent_folder_link_20_regular = 59531
ic_fluent_folder_list_20_filled = 59532
ic_fluent_folder_list_20_regular = 59533
ic_fluent_folder_mail_20_filled = 59534
ic_fluent_folder_mail_20_regular = 59535
ic_fluent_folder_open_20_filled = 59536
ic_fluent_folder_open_20_regular = 59537
ic_fluent_folder_open_down_20_filled = 59538
ic_fluent_folder_open_down_20_regular = 59539
ic_fluent_folder_open_vertical_20_filled = 59540
ic_fluent_folder_open_vertical_20_regular = 59541
ic_fluent_folder_people_20_filled = 59542
ic_fluent_folder_people_20_regular = 59543
ic_fluent_folder_person_20_filled = 59544
ic_fluent_folder_person_20_regular = 59545
ic_fluent_folder_prohibited_20_filled = 59546
ic_fluent_folder_prohibited_20_regular = 59547
ic_fluent_folder_search_20_filled = 59548
ic_fluent_folder_search_20_regular = 59549
ic_fluent_folder_swap_20_filled = 59550
ic_fluent_folder_swap_20_regular = 59551
ic_fluent_folder_sync_20_filled = 59552
ic_fluent_folder_sync_20_regular = 59553
ic_fluent_folder_zip_20_filled = 59554
ic_fluent_folder_zip_20_regular = 59555
ic_fluent_font_decrease_20_filled = 59556
ic_fluent_font_decrease_20_regular = 59557
ic_fluent_font_increase_20_filled = 59558
ic_fluent_font_increase_20_regular = 59559
ic_fluent_font_space_tracking_in_20_filled = 59560
ic_fluent_font_space_tracking_in_20_regular = 59561
ic_fluent_font_space_tracking_out_20_filled = 59562
ic_fluent_font_space_tracking_out_20_regular = 59563
ic_fluent_food_20_filled = 59564
ic_fluent_food_20_regular = 59565
ic_fluent_food_apple_20_filled = 59566
ic_fluent_food_apple_20_regular = 59567
ic_fluent_food_cake_20_filled = 59568
ic_fluent_food_cake_20_regular = 59569
ic_fluent_food_carrot_20_filled = 59570
ic_fluent_food_carrot_20_regular = 59571
ic_fluent_food_chicken_leg_20_filled = 59572
ic_fluent_food_chicken_leg_20_regular = 59573
ic_fluent_food_egg_20_filled = 59574
ic_fluent_food_egg_20_regular = 59575
ic_fluent_food_fish_20_filled = 59576
ic_fluent_food_fish_20_regular = 59577
ic_fluent_food_grains_20_filled = 59578
ic_fluent_food_grains_20_regular = 59579
ic_fluent_food_pizza_20_filled = 59580
ic_fluent_food_pizza_20_regular = 59581
ic_fluent_food_toast_20_filled = 59582
ic_fluent_food_toast_20_regular = 59583
ic_fluent_form_20_filled = 59584
ic_fluent_form_20_regular = 59585
ic_fluent_form_multiple_20_filled = 59586
ic_fluent_form_multiple_20_regular = 59587
ic_fluent_form_new_20_filled = 59588
ic_fluent_form_new_20_regular = 59589
ic_fluent_form_sparkle_20_filled = 59590
ic_fluent_form_sparkle_20_regular = 59591
ic_fluent_fps_120_20_filled = 59592
ic_fluent_fps_120_20_regular = 59593
ic_fluent_fps_240_20_filled = 59594
ic_fluent_fps_240_20_regular = 59595
ic_fluent_fps_30_20_filled = 59596
ic_fluent_fps_30_20_regular = 59597
ic_fluent_fps_60_20_filled = 59598
ic_fluent_fps_60_20_regular = 59599
ic_fluent_fps_960_20_filled = 59600
ic_fluent_fps_960_20_regular = 59601
ic_fluent_frame_20_filled = 59602
ic_fluent_frame_20_regular = 59603
ic_fluent_full_screen_maximize_20_filled = 59604
ic_fluent_full_screen_maximize_20_regular = 59605
ic_fluent_full_screen_minimize_20_filled = 59606
ic_fluent_full_screen_minimize_20_regular = 59607
ic_fluent_game_chat_20_filled = 59608
ic_fluent_game_chat_20_regular = 59609
ic_fluent_games_20_filled = 59610
ic_fluent_games_20_regular = 59611
ic_fluent_gantt_chart_20_filled = 59612
ic_fluent_gantt_chart_20_regular = 59613
ic_fluent_gas_20_filled = 59614
ic_fluent_gas_20_regular = 59615
ic_fluent_gas_pump_20_filled = 59616
ic_fluent_gas_pump_20_regular = 59617
ic_fluent_gather_20_filled = 59618
ic_fluent_gather_20_regular = 59619
ic_fluent_gauge_20_filled = 59620
ic_fluent_gauge_20_regular = 59621
ic_fluent_gauge_add_20_filled = 59622
ic_fluent_gauge_add_20_regular = 59623
ic_fluent_gavel_20_filled = 59624
ic_fluent_gavel_20_regular = 59625
ic_fluent_gavel_prohibited_20_filled = 59626
ic_fluent_gavel_prohibited_20_regular = 59627
ic_fluent_gesture_20_filled = 59628
ic_fluent_gesture_20_regular = 59629
ic_fluent_gif_20_filled = 59630
ic_fluent_gif_20_regular = 59631
ic_fluent_gift_20_filled = 59632
ic_fluent_gift_20_regular = 59633
ic_fluent_gift_card_20_filled = 59634
ic_fluent_gift_card_20_regular = 59635
ic_fluent_gift_card_add_20_filled = 59636
ic_fluent_gift_card_add_20_regular = 59637
ic_fluent_gift_card_arrow_right_20_filled = 59638
ic_fluent_gift_card_arrow_right_20_regular = 59639
ic_fluent_gift_card_money_20_filled = 59640
ic_fluent_gift_card_money_20_regular = 59641
ic_fluent_gift_card_multiple_20_filled = 59642
ic_fluent_gift_card_multiple_20_regular = 59643
ic_fluent_gift_open_20_filled = 59644
ic_fluent_gift_open_20_regular = 59645
ic_fluent_glance_20_filled = 59646
ic_fluent_glance_20_regular = 59647
ic_fluent_glance_horizontal_20_filled = 59648
ic_fluent_glance_horizontal_20_regular = 59649
ic_fluent_glance_horizontal_sparkles_20_filled = 59650
ic_fluent_glance_horizontal_sparkles_20_regular = 59651
ic_fluent_glasses_20_filled = 59652
ic_fluent_glasses_20_regular = 59653
ic_fluent_glasses_off_20_filled = 59654
ic_fluent_glasses_off_20_regular = 59655
ic_fluent_globe_20_filled = 59656
ic_fluent_globe_20_regular = 59657
ic_fluent_globe_add_20_filled = 59658
ic_fluent_globe_add_20_regular = 59659
ic_fluent_globe_arrow_forward_20_filled = 59660
ic_fluent_globe_arrow_forward_20_regular = 59661
ic_fluent_globe_arrow_up_20_filled = 59662
ic_fluent_globe_arrow_up_20_regular = 59663
ic_fluent_globe_clock_20_filled = 59664
ic_fluent_globe_clock_20_regular = 59665
ic_fluent_globe_desktop_20_filled = 59666
ic_fluent_globe_desktop_20_regular = 59667
ic_fluent_globe_error_20_filled = 59668
ic_fluent_globe_error_20_regular = 59669
ic_fluent_globe_location_20_filled = 59670
ic_fluent_globe_location_20_regular = 59671
ic_fluent_globe_off_20_filled = 59672
ic_fluent_globe_off_20_regular = 59673
ic_fluent_globe_person_20_filled = 59674
ic_fluent_globe_person_20_regular = 59675
ic_fluent_globe_prohibited_20_filled = 59676
ic_fluent_globe_prohibited_20_regular = 59677
ic_fluent_globe_search_20_filled = 59678
ic_fluent_globe_search_20_regular = 59679
ic_fluent_globe_shield_20_filled = 59680
ic_fluent_globe_shield_20_regular = 59681
ic_fluent_globe_star_20_filled = 59682
ic_fluent_globe_star_20_regular = 59683
ic_fluent_globe_surface_20_filled = 59684
ic_fluent_globe_surface_20_regular = 59685
ic_fluent_globe_sync_20_filled = 59686
ic_fluent_globe_sync_20_regular = 59687
ic_fluent_globe_video_20_filled = 59688
ic_fluent_globe_video_20_regular = 59689
ic_fluent_globe_warning_20_filled = 59690
ic_fluent_globe_warning_20_regular = 59691
ic_fluent_grid_20_filled = 59692
ic_fluent_grid_20_regular = 59693
ic_fluent_grid_dots_20_filled = 59694
ic_fluent_grid_dots_20_regular = 59695
ic_fluent_grid_kanban_20_filled = 59696
ic_fluent_grid_kanban_20_regular = 59697
ic_fluent_group_20_filled = 59698
ic_fluent_group_20_regular = 59699
ic_fluent_group_dismiss_20_filled = 59700
ic_fluent_group_dismiss_20_regular = 59701
ic_fluent_group_list_20_filled = 59702
ic_fluent_group_list_20_regular = 59703
ic_fluent_group_return_20_filled = 59704
ic_fluent_group_return_20_regular = 59705
ic_fluent_guardian_20_filled = 59706
ic_fluent_guardian_20_regular = 59707
ic_fluent_guest_20_filled = 59708
ic_fluent_guest_20_regular = 59709
ic_fluent_guest_add_20_filled = 59710
ic_fluent_guest_add_20_regular = 59711
ic_fluent_guitar_20_filled = 59712
ic_fluent_guitar_20_regular = 59713
ic_fluent_hand_draw_20_filled = 59714
ic_fluent_hand_draw_20_regular = 59715
ic_fluent_hand_left_20_filled = 59716
ic_fluent_hand_left_20_regular = 59717
ic_fluent_hand_left_chat_20_filled = 59718
ic_fluent_hand_left_chat_20_regular = 59719
ic_fluent_hand_multiple_20_filled = 59720
ic_fluent_hand_multiple_20_regular = 59721
ic_fluent_hand_open_heart_20_filled = 59722
ic_fluent_hand_open_heart_20_regular = 59723
ic_fluent_hand_point_20_filled = 59724
ic_fluent_hand_point_20_regular = 59725
ic_fluent_hand_right_20_filled = 59726
ic_fluent_hand_right_20_regular = 59727
ic_fluent_hand_right_off_20_filled = 59728
ic_fluent_hand_right_off_20_regular = 59729
ic_fluent_hand_wave_20_filled = 59730
ic_fluent_hand_wave_20_regular = 59731
ic_fluent_handshake_20_filled = 59732
ic_fluent_handshake_20_regular = 59733
ic_fluent_haptic_strong_20_filled = 59734
ic_fluent_haptic_strong_20_regular = 59735
ic_fluent_haptic_weak_20_filled = 59736
ic_fluent_haptic_weak_20_regular = 59737
ic_fluent_hard_drive_20_filled = 59738
ic_fluent_hard_drive_20_regular = 59739
ic_fluent_hat_graduation_20_filled = 59740
ic_fluent_hat_graduation_20_regular = 59741
ic_fluent_hat_graduation_add_20_filled = 59742
ic_fluent_hat_graduation_add_20_regular = 59743
ic_fluent_hat_graduation_sparkle_20_filled = 59744
ic_fluent_hat_graduation_sparkle_20_regular = 59745
ic_fluent_hd_20_filled = 59746
ic_fluent_hd_20_regular = 59747
ic_fluent_hd_off_20_filled = 59748
ic_fluent_hd_off_20_regular = 59749
ic_fluent_hdr_20_filled = 59750
ic_fluent_hdr_20_regular = 59751
ic_fluent_hdr_off_20_filled = 59752
ic_fluent_hdr_off_20_regular = 59753
ic_fluent_headphones_20_filled = 59754
ic_fluent_headphones_20_regular = 59755
ic_fluent_headphones_sound_wave_20_filled = 59756
ic_fluent_headphones_sound_wave_20_regular = 59757
ic_fluent_headset_20_filled = 59758
ic_fluent_headset_20_regular = 59759
ic_fluent_headset_add_20_filled = 59760
ic_fluent_headset_add_20_regular = 59761
ic_fluent_headset_vr_20_filled = 59762
ic_fluent_headset_vr_20_regular = 59763
ic_fluent_heart_20_filled = 59764
ic_fluent_heart_20_regular = 59765
ic_fluent_heart_broken_20_filled = 59766
ic_fluent_heart_broken_20_regular = 59767
ic_fluent_heart_circle_20_filled = 59768
ic_fluent_heart_circle_20_regular = 59769
ic_fluent_heart_circle_hint_20_filled = 59770
ic_fluent_heart_circle_hint_20_regular = 59771
ic_fluent_heart_off_20_filled = 59772
ic_fluent_heart_off_20_regular = 59773
ic_fluent_heart_pulse_20_filled = 59774
ic_fluent_heart_pulse_20_regular = 59775
ic_fluent_heart_pulse_checkmark_20_filled = 59776
ic_fluent_heart_pulse_checkmark_20_regular = 59777
ic_fluent_heart_pulse_error_20_filled = 59778
ic_fluent_heart_pulse_error_20_regular = 59779
ic_fluent_heart_pulse_warning_20_filled = 59780
ic_fluent_heart_pulse_warning_20_regular = 59781
ic_fluent_hexagon_20_filled = 59782
ic_fluent_hexagon_20_regular = 59783
ic_fluent_hexagon_sparkle_20_filled = 59784
ic_fluent_hexagon_sparkle_20_regular = 59785
ic_fluent_hexagon_three_20_filled = 59786
ic_fluent_hexagon_three_20_regular = 59787
ic_fluent_highlight_20_filled = 59788
ic_fluent_highlight_20_regular = 59789
ic_fluent_highlight_accent_20_filled = 59790
ic_fluent_highlight_link_20_filled = 59791
ic_fluent_highlight_link_20_regular = 59792
ic_fluent_highway_20_filled = 59793
ic_fluent_highway_20_regular = 59794
ic_fluent_history_20_filled = 59795
ic_fluent_history_20_regular = 59796
ic_fluent_history_dismiss_20_filled = 59797
ic_fluent_history_dismiss_20_regular = 59798
ic_fluent_home_20_filled = 59799
ic_fluent_home_20_regular = 59800
ic_fluent_home_add_20_filled = 59801
ic_fluent_home_add_20_regular = 59802
ic_fluent_home_checkmark_20_filled = 59803
ic_fluent_home_checkmark_20_regular = 59804
ic_fluent_home_database_20_filled = 59805
ic_fluent_home_database_20_regular = 59806
ic_fluent_home_empty_20_filled = 59807
ic_fluent_home_empty_20_regular = 59808
ic_fluent_home_garage_20_filled = 59809
ic_fluent_home_garage_20_regular = 59810
ic_fluent_home_heart_20_filled = 59811
ic_fluent_home_heart_20_regular = 59812
ic_fluent_home_more_20_filled = 59813
ic_fluent_home_more_20_regular = 59814
ic_fluent_home_person_20_filled = 59815
ic_fluent_home_person_20_regular = 59816
ic_fluent_home_split_20_filled = 59817
ic_fluent_home_split_20_regular = 59818
ic_fluent_hourglass_20_filled = 59819
ic_fluent_hourglass_20_regular = 59820
ic_fluent_hourglass_half_20_filled = 59821
ic_fluent_hourglass_half_20_regular = 59822
ic_fluent_hourglass_one_quarter_20_filled = 59823
ic_fluent_hourglass_one_quarter_20_regular = 59824
ic_fluent_hourglass_three_quarter_20_filled = 59825
ic_fluent_hourglass_three_quarter_20_regular = 59826
ic_fluent_icons_20_filled = 59827
ic_fluent_icons_20_regular = 59828
ic_fluent_image_20_filled = 59829
ic_fluent_image_20_regular = 59830
ic_fluent_image_add_20_filled = 59831
ic_fluent_image_add_20_regular = 59832
ic_fluent_image_alt_text_20_filled = 59833
ic_fluent_image_alt_text_20_regular = 59834
ic_fluent_image_arrow_back_20_filled = 59835
ic_fluent_image_arrow_back_20_regular = 59836
ic_fluent_image_arrow_counterclockwise_20_filled = 59837
ic_fluent_image_arrow_counterclockwise_20_regular = 59838
ic_fluent_image_arrow_forward_20_filled = 59839
ic_fluent_image_arrow_forward_20_regular = 59840
ic_fluent_image_border_20_filled = 59841
ic_fluent_image_border_20_regular = 59842
ic_fluent_image_circle_20_filled = 59843
ic_fluent_image_circle_20_regular = 59844
ic_fluent_image_copy_20_filled = 59845
ic_fluent_image_copy_20_regular = 59846
ic_fluent_image_edit_20_filled = 59847
ic_fluent_image_edit_20_regular = 59848
ic_fluent_image_globe_20_filled = 59849
ic_fluent_image_globe_20_regular = 59850
ic_fluent_image_multiple_20_filled = 59851
ic_fluent_image_multiple_20_regular = 59852
ic_fluent_image_multiple_off_20_filled = 59853
ic_fluent_image_multiple_off_20_regular = 59854
ic_fluent_image_off_20_filled = 59855
ic_fluent_image_off_20_regular = 59856
ic_fluent_image_prohibited_20_filled = 59857
ic_fluent_image_prohibited_20_regular = 59858
ic_fluent_image_reflection_20_filled = 59859
ic_fluent_image_reflection_20_regular = 59860
ic_fluent_image_search_20_filled = 59861
ic_fluent_image_search_20_regular = 59862
ic_fluent_image_shadow_20_filled = 59863
ic_fluent_image_shadow_20_regular = 59864
ic_fluent_image_sparkle_20_filled = 59865
ic_fluent_image_sparkle_20_regular = 59866
ic_fluent_image_split_20_filled = 59867
ic_fluent_image_split_20_regular = 59868
ic_fluent_image_stack_20_filled = 59869
ic_fluent_image_stack_20_regular = 59870
ic_fluent_image_table_20_filled = 59871
ic_fluent_image_table_20_regular = 59872
ic_fluent_immersive_reader_20_filled = 59873
ic_fluent_immersive_reader_20_regular = 59874
ic_fluent_important_20_filled = 59875
ic_fluent_important_20_regular = 59876
ic_fluent_incognito_20_filled = 59877
ic_fluent_incognito_20_regular = 59878
ic_fluent_info_20_filled = 59879
ic_fluent_info_20_regular = 59880
ic_fluent_info_shield_20_filled = 59881
ic_fluent_info_shield_20_regular = 59882
ic_fluent_info_sparkle_20_filled = 59883
ic_fluent_info_sparkle_20_regular = 59884
ic_fluent_ink_stroke_20_filled = 59885
ic_fluent_ink_stroke_20_regular = 59886
ic_fluent_ink_stroke_arrow_down_20_filled = 59887
ic_fluent_ink_stroke_arrow_down_20_regular = 59888
ic_fluent_ink_stroke_arrow_up_down_20_filled = 59889
ic_fluent_ink_stroke_arrow_up_down_20_regular = 59890
ic_fluent_inking_tool_20_filled = 59891
ic_fluent_inking_tool_20_regular = 59892
ic_fluent_inking_tool_accent_20_filled = 59893
ic_fluent_inprivate_account_20_filled = 59894
ic_fluent_inprivate_account_20_regular = 59895
ic_fluent_insert_20_filled = 59896
ic_fluent_insert_20_regular = 59897
ic_fluent_ios_chevron_right_20_filled = 59898
ic_fluent_ios_chevron_right_20_regular = 59899
ic_fluent_iot_20_filled = 59900
ic_fluent_iot_20_regular = 59901
ic_fluent_iot_alert_20_filled = 59902
ic_fluent_iot_alert_20_regular = 59903
ic_fluent_javascript_20_filled = 59904
ic_fluent_javascript_20_regular = 59905
ic_fluent_joystick_20_filled = 59906
ic_fluent_joystick_20_regular = 59907
ic_fluent_key_20_filled = 59908
ic_fluent_key_20_regular = 59909
ic_fluent_key_command_20_filled = 59910
ic_fluent_key_command_20_regular = 59911
ic_fluent_key_multiple_20_filled = 59912
ic_fluent_key_multiple_20_regular = 59913
ic_fluent_key_reset_20_filled = 59914
ic_fluent_key_reset_20_regular = 59915
ic_fluent_keyboard_123_20_filled = 59916
ic_fluent_keyboard_123_20_regular = 59917
ic_fluent_keyboard_20_filled = 59918
ic_fluent_keyboard_20_regular = 59919
ic_fluent_keyboard_dock_20_filled = 59920
ic_fluent_keyboard_dock_20_regular = 59921
ic_fluent_keyboard_layout_float_20_filled = 59922
ic_fluent_keyboard_layout_float_20_regular = 59923
ic_fluent_keyboard_layout_one_handed_left_20_filled = 59924
ic_fluent_keyboard_layout_one_handed_left_20_regular = 59925
ic_fluent_keyboard_layout_resize_20_filled = 59926
ic_fluent_keyboard_layout_resize_20_regular = 59927
ic_fluent_keyboard_layout_split_20_filled = 59928
ic_fluent_keyboard_layout_split_20_regular = 59929
ic_fluent_keyboard_shift_20_filled = 59930
ic_fluent_keyboard_shift_20_regular = 59931
ic_fluent_keyboard_shift_uppercase_20_filled = 59932
ic_fluent_keyboard_shift_uppercase_20_regular = 59933
ic_fluent_keyboard_tab_20_filled = 59934
ic_fluent_keyboard_tab_20_regular = 59935
ic_fluent_laptop_20_filled = 59936
ic_fluent_laptop_20_regular = 59937
ic_fluent_laptop_briefcase_20_filled = 59938
ic_fluent_laptop_briefcase_20_regular = 59939
ic_fluent_laptop_dismiss_20_filled = 59940
ic_fluent_laptop_dismiss_20_regular = 59941
ic_fluent_laptop_person_20_filled = 59942
ic_fluent_laptop_person_20_regular = 59943
ic_fluent_laptop_settings_20_filled = 59944
ic_fluent_laptop_settings_20_regular = 59945
ic_fluent_laptop_shield_20_filled = 59946
ic_fluent_laptop_shield_20_regular = 59947
ic_fluent_laser_tool_20_filled = 59948
ic_fluent_laser_tool_20_regular = 59949
ic_fluent_lasso_20_filled = 59950
ic_fluent_lasso_20_regular = 59951
ic_fluent_launcher_settings_20_filled = 59952
ic_fluent_launcher_settings_20_regular = 59953
ic_fluent_layer_20_filled = 59954
ic_fluent_layer_20_regular = 59955
ic_fluent_layer_diagonal_20_filled = 59956
ic_fluent_layer_diagonal_20_regular = 59957
ic_fluent_layer_diagonal_add_20_filled = 59958
ic_fluent_layer_diagonal_add_20_regular = 59959
ic_fluent_layer_diagonal_person_20_filled = 59960
ic_fluent_layer_diagonal_person_20_regular = 59961
ic_fluent_layer_diagonal_sparkle_20_filled = 59962
ic_fluent_layer_diagonal_sparkle_20_regular = 59963
ic_fluent_layout_cell_four_20_filled = 59964
ic_fluent_layout_cell_four_20_regular = 59965
ic_fluent_layout_cell_four_focus_bottom_left_20_filled = 59966
ic_fluent_layout_cell_four_focus_bottom_right_20_filled = 59967
ic_fluent_layout_cell_four_focus_top_left_20_filled = 59968
ic_fluent_layout_cell_four_focus_top_right_20_filled = 59969
ic_fluent_layout_column_four_20_filled = 59970
ic_fluent_layout_column_four_20_regular = 59971
ic_fluent_layout_column_four_focus_center_left_20_filled = 59972
ic_fluent_layout_column_four_focus_center_right_20_filled = 59973
ic_fluent_layout_column_four_focus_left_20_filled = 59974
ic_fluent_layout_column_four_focus_right_20_filled = 59975
ic_fluent_layout_column_one_third_left_20_filled = 59976
ic_fluent_layout_column_one_third_left_20_regular = 59977
ic_fluent_layout_column_one_third_right_20_filled = 59978
ic_fluent_layout_column_one_third_right_20_regular = 59979
ic_fluent_layout_column_one_third_right_hint_20_filled = 59980
ic_fluent_layout_column_one_third_right_hint_20_regular = 59981
ic_fluent_layout_column_three_20_filled = 59982
ic_fluent_layout_column_three_20_regular = 59983
ic_fluent_layout_column_three_focus_center_20_filled = 59984
ic_fluent_layout_column_three_focus_left_20_filled = 59985
ic_fluent_layout_column_three_focus_right_20_filled = 59986
ic_fluent_layout_column_two_20_filled = 59987
ic_fluent_layout_column_two_20_regular = 59988
ic_fluent_layout_column_two_focus_left_20_filled = 59989
ic_fluent_layout_column_two_focus_right_20_filled = 59990
ic_fluent_layout_column_two_split_left_20_filled = 59991
ic_fluent_layout_column_two_split_left_20_regular = 59992
ic_fluent_layout_column_two_split_left_focus_bottom_left_20_filled = 59993
ic_fluent_layout_column_two_split_left_focus_right_20_filled = 59994
ic_fluent_layout_column_two_split_left_focus_top_left_20_filled = 59995
ic_fluent_layout_column_two_split_right_20_filled = 59996
ic_fluent_layout_column_two_split_right_20_regular = 59997
ic_fluent_layout_column_two_split_right_focus_bottom_right_20_filled = 59998
ic_fluent_layout_column_two_split_right_focus_left_20_filled = 59999
ic_fluent_layout_column_two_split_right_focus_top_right_20_filled = 60000
ic_fluent_layout_row_four_20_filled = 60001
ic_fluent_layout_row_four_20_regular = 60002
ic_fluent_layout_row_four_focus_bottom_20_filled = 60003
ic_fluent_layout_row_four_focus_center_bottom_20_filled = 60004
ic_fluent_layout_row_four_focus_center_top_20_filled = 60005
ic_fluent_layout_row_four_focus_top_20_filled = 60006
ic_fluent_layout_row_three_20_filled = 60007
ic_fluent_layout_row_three_20_regular = 60008
ic_fluent_layout_row_three_focus_bottom_20_filled = 60009
ic_fluent_layout_row_three_focus_center_20_filled = 60010
ic_fluent_layout_row_three_focus_top_20_filled = 60011
ic_fluent_layout_row_two_20_filled = 60012
ic_fluent_layout_row_two_20_regular = 60013
ic_fluent_layout_row_two_focus_bottom_20_filled = 60014
ic_fluent_layout_row_two_focus_top_20_filled = 60015
ic_fluent_layout_row_two_focus_top_settings_20_filled = 60016
ic_fluent_layout_row_two_settings_20_filled = 60017
ic_fluent_layout_row_two_settings_20_regular = 60018
ic_fluent_layout_row_two_split_bottom_20_filled = 60019
ic_fluent_layout_row_two_split_bottom_20_regular = 60020
ic_fluent_layout_row_two_split_bottom_focus_bottom_left_20_filled = 60021
ic_fluent_layout_row_two_split_bottom_focus_bottom_right_20_filled = 60022
ic_fluent_layout_row_two_split_bottom_focus_top_20_filled = 60023
ic_fluent_layout_row_two_split_top_20_filled = 60024
ic_fluent_layout_row_two_split_top_20_regular = 60025
ic_fluent_layout_row_two_split_top_focus_bottom_20_filled = 60026
ic_fluent_layout_row_two_split_top_focus_top_left_20_filled = 60027
ic_fluent_layout_row_two_split_top_focus_top_right_20_filled = 60028
ic_fluent_leaf_one_20_filled = 60029
ic_fluent_leaf_one_20_regular = 60030
ic_fluent_leaf_three_20_filled = 60031
ic_fluent_leaf_three_20_regular = 60032
ic_fluent_leaf_two_20_filled = 60033
ic_fluent_leaf_two_20_regular = 60034
ic_fluent_learning_app_20_filled = 60035
ic_fluent_learning_app_20_regular = 60036
ic_fluent_library_20_filled = 60037
ic_fluent_library_20_regular = 60038
ic_fluent_lightbulb_20_filled = 60039
ic_fluent_lightbulb_20_regular = 60040
ic_fluent_lightbulb_checkmark_20_filled = 60041
ic_fluent_lightbulb_checkmark_20_regular = 60042
ic_fluent_lightbulb_circle_20_filled = 60043
ic_fluent_lightbulb_circle_20_regular = 60044
ic_fluent_lightbulb_filament_20_filled = 60045
ic_fluent_lightbulb_filament_20_regular = 60046
ic_fluent_lightbulb_person_20_filled = 60047
ic_fluent_lightbulb_person_20_regular = 60048
ic_fluent_likert_20_filled = 60049
ic_fluent_likert_20_regular = 60050
ic_fluent_line_20_filled = 60051
ic_fluent_line_20_regular = 60052
ic_fluent_line_dashes_20_filled = 60053
ic_fluent_line_dashes_20_regular = 60054
ic_fluent_line_flow_diagonal_up_right_20_filled = 60055
ic_fluent_line_flow_diagonal_up_right_20_regular = 60056
ic_fluent_line_horizontal_1_20_filled = 60057
ic_fluent_line_horizontal_1_20_regular = 60058
ic_fluent_line_horizontal_1_dash_dot_dash_20_filled = 60059
ic_fluent_line_horizontal_1_dash_dot_dash_20_regular = 60060
ic_fluent_line_horizontal_1_dashes_20_filled = 60061
ic_fluent_line_horizontal_1_dashes_20_regular = 60062
ic_fluent_line_horizontal_1_dot_20_filled = 60063
ic_fluent_line_horizontal_1_dot_20_regular = 60064
ic_fluent_line_horizontal_2_dashes_solid_20_filled = 60065
ic_fluent_line_horizontal_2_dashes_solid_20_regular = 60066
ic_fluent_line_horizontal_3_20_filled = 60067
ic_fluent_line_horizontal_3_20_regular = 60068
ic_fluent_line_horizontal_4_20_filled = 60069
ic_fluent_line_horizontal_4_20_regular = 60070
ic_fluent_line_horizontal_4_search_20_filled = 60071
ic_fluent_line_horizontal_4_search_20_regular = 60072
ic_fluent_line_horizontal_5_20_filled = 60073
ic_fluent_line_horizontal_5_20_regular = 60074
ic_fluent_line_horizontal_5_error_20_filled = 60075
ic_fluent_line_horizontal_5_error_20_regular = 60076
ic_fluent_line_style_20_filled = 60077
ic_fluent_line_style_20_regular = 60078
ic_fluent_line_style_sketch_20_filled = 60079
ic_fluent_line_style_sketch_20_regular = 60080
ic_fluent_line_thickness_20_filled = 60081
ic_fluent_line_thickness_20_regular = 60082
ic_fluent_link_20_filled = 60083
ic_fluent_link_20_regular = 60084
ic_fluent_link_add_20_filled = 60085
ic_fluent_link_add_20_regular = 60086
ic_fluent_link_dismiss_20_filled = 60087
ic_fluent_link_dismiss_20_regular = 60088
ic_fluent_link_edit_20_filled = 60089
ic_fluent_link_edit_20_regular = 60090
ic_fluent_link_multiple_20_filled = 60091
ic_fluent_link_multiple_20_regular = 60092
ic_fluent_link_person_20_filled = 60093
ic_fluent_link_person_20_regular = 60094
ic_fluent_link_square_20_filled = 60095
ic_fluent_link_square_20_regular = 60096
ic_fluent_link_toolbox_20_filled = 60097
ic_fluent_link_toolbox_20_regular = 60098
ic_fluent_list_20_filled = 60099
ic_fluent_list_20_regular = 60100
ic_fluent_list_bar_20_filled = 60101
ic_fluent_list_bar_20_regular = 60102
ic_fluent_list_bar_tree_20_filled = 60103
ic_fluent_list_bar_tree_20_regular = 60104
ic_fluent_list_bar_tree_offset_20_filled = 60105
ic_fluent_list_bar_tree_offset_20_regular = 60106
ic_fluent_list_rtl_20_filled = 60107
ic_fluent_list_rtl_20_regular = 60108
ic_fluent_live_20_filled = 60109
ic_fluent_live_20_regular = 60110
ic_fluent_live_off_20_filled = 60111
ic_fluent_live_off_20_regular = 60112
ic_fluent_local_language_20_filled = 60113
ic_fluent_local_language_20_regular = 60114
ic_fluent_location_20_filled = 60115
ic_fluent_location_20_regular = 60116
ic_fluent_location_add_20_filled = 60117
ic_fluent_location_add_20_regular = 60118
ic_fluent_location_add_left_20_filled = 60119
ic_fluent_location_add_left_20_regular = 60120
ic_fluent_location_add_right_20_filled = 60121
ic_fluent_location_add_right_20_regular = 60122
ic_fluent_location_add_up_20_filled = 60123
ic_fluent_location_add_up_20_regular = 60124
ic_fluent_location_arrow_20_filled = 60125
ic_fluent_location_arrow_20_regular = 60126
ic_fluent_location_arrow_left_20_filled = 60127
ic_fluent_location_arrow_left_20_regular = 60128
ic_fluent_location_arrow_right_20_filled = 60129
ic_fluent_location_arrow_right_20_regular = 60130
ic_fluent_location_arrow_up_20_filled = 60131
ic_fluent_location_arrow_up_20_regular = 60132
ic_fluent_location_checkmark_20_filled = 60133
ic_fluent_location_checkmark_20_regular = 60134
ic_fluent_location_dismiss_20_filled = 60135
ic_fluent_location_dismiss_20_regular = 60136
ic_fluent_location_live_20_filled = 60137
ic_fluent_location_live_20_regular = 60138
ic_fluent_location_off_20_filled = 60139
ic_fluent_location_off_20_regular = 60140
ic_fluent_location_ripple_20_filled = 60141
ic_fluent_location_ripple_20_regular = 60142
ic_fluent_location_settings_20_filled = 60143
ic_fluent_location_settings_20_regular = 60144
ic_fluent_location_target_square_20_filled = 60145
ic_fluent_location_target_square_20_regular = 60146
ic_fluent_lock_closed_20_filled = 60147
ic_fluent_lock_closed_20_regular = 60148
ic_fluent_lock_closed_key_20_filled = 60149
ic_fluent_lock_closed_key_20_regular = 60150
ic_fluent_lock_closed_ribbon_20_filled = 60151
ic_fluent_lock_closed_ribbon_20_regular = 60152
ic_fluent_lock_multiple_20_filled = 60153
ic_fluent_lock_multiple_20_regular = 60154
ic_fluent_lock_open_20_filled = 60155
ic_fluent_lock_open_20_regular = 60156
ic_fluent_lock_shield_20_filled = 60157
ic_fluent_lock_shield_20_regular = 60158
ic_fluent_lottery_20_filled = 60159
ic_fluent_lottery_20_regular = 60160
ic_fluent_luggage_20_filled = 60161
ic_fluent_luggage_20_regular = 60162
ic_fluent_mail_20_filled = 60163
ic_fluent_mail_20_regular = 60164
ic_fluent_mail_add_20_filled = 60165
ic_fluent_mail_add_20_regular = 60166
ic_fluent_mail_alert_20_filled = 60167
ic_fluent_mail_alert_20_regular = 60168
ic_fluent_mail_all_read_20_filled = 60169
ic_fluent_mail_all_read_20_regular = 60170
ic_fluent_mail_all_unread_20_filled = 60171
ic_fluent_mail_all_unread_20_regular = 60172
ic_fluent_mail_arrow_clockwise_20_filled = 60173
ic_fluent_mail_arrow_clockwise_20_regular = 60174
ic_fluent_mail_arrow_double_back_20_filled = 60175
ic_fluent_mail_arrow_double_back_20_regular = 60176
ic_fluent_mail_arrow_down_20_filled = 60177
ic_fluent_mail_arrow_down_20_regular = 60178
ic_fluent_mail_arrow_forward_20_filled = 60179
ic_fluent_mail_arrow_forward_20_regular = 60180
ic_fluent_mail_arrow_up_20_filled = 60181
ic_fluent_mail_arrow_up_20_regular = 60182
ic_fluent_mail_attach_20_filled = 60183
ic_fluent_mail_attach_20_regular = 60184
ic_fluent_mail_checkmark_20_filled = 60185
ic_fluent_mail_checkmark_20_regular = 60186
ic_fluent_mail_clock_20_filled = 60187
ic_fluent_mail_clock_20_regular = 60188
ic_fluent_mail_copy_20_filled = 60189
ic_fluent_mail_copy_20_regular = 60190
ic_fluent_mail_data_bar_20_filled = 60191
ic_fluent_mail_data_bar_20_regular = 60192
ic_fluent_mail_dismiss_20_filled = 60193
ic_fluent_mail_dismiss_20_regular = 60194
ic_fluent_mail_edit_20_filled = 60195
ic_fluent_mail_edit_20_regular = 60196
ic_fluent_mail_error_20_filled = 60197
ic_fluent_mail_error_20_regular = 60198
ic_fluent_mail_fish_hook_20_filled = 60199
ic_fluent_mail_fish_hook_20_regular = 60200
ic_fluent_mail_inbox_20_filled = 60201
ic_fluent_mail_inbox_20_regular = 60202
ic_fluent_mail_inbox_add_20_filled = 60203
ic_fluent_mail_inbox_add_20_regular = 60204
ic_fluent_mail_inbox_all_20_filled = 60205
ic_fluent_mail_inbox_all_20_regular = 60206
ic_fluent_mail_inbox_arrow_down_20_filled = 60207
ic_fluent_mail_inbox_arrow_down_20_regular = 60208
ic_fluent_mail_inbox_arrow_right_20_filled = 60209
ic_fluent_mail_inbox_arrow_right_20_regular = 60210
ic_fluent_mail_inbox_arrow_up_20_filled = 60211
ic_fluent_mail_inbox_arrow_up_20_regular = 60212
ic_fluent_mail_inbox_checkmark_20_filled = 60213
ic_fluent_mail_inbox_checkmark_20_regular = 60214
ic_fluent_mail_inbox_dismiss_20_filled = 60215
ic_fluent_mail_inbox_dismiss_20_regular = 60216
ic_fluent_mail_inbox_person_20_filled = 60217
ic_fluent_mail_inbox_person_20_regular = 60218
ic_fluent_mail_link_20_filled = 60219
ic_fluent_mail_link_20_regular = 60220
ic_fluent_mail_list_20_filled = 60221
ic_fluent_mail_list_20_regular = 60222
ic_fluent_mail_multiple_20_filled = 60223
ic_fluent_mail_multiple_20_regular = 60224
ic_fluent_mail_off_20_filled = 60225
ic_fluent_mail_off_20_regular = 60226
ic_fluent_mail_open_person_20_filled = 60227
ic_fluent_mail_open_person_20_regular = 60228
ic_fluent_mail_pause_20_filled = 60229
ic_fluent_mail_pause_20_regular = 60230
ic_fluent_mail_prohibited_20_filled = 60231
ic_fluent_mail_prohibited_20_regular = 60232
ic_fluent_mail_read_20_filled = 60233
ic_fluent_mail_read_20_regular = 60234
ic_fluent_mail_read_briefcase_20_filled = 60235
ic_fluent_mail_read_briefcase_20_regular = 60236
ic_fluent_mail_read_multiple_20_filled = 60237
ic_fluent_mail_read_multiple_20_regular = 60238
ic_fluent_mail_rewind_20_filled = 60239
ic_fluent_mail_rewind_20_regular = 60240
ic_fluent_mail_settings_20_filled = 60241
ic_fluent_mail_settings_20_regular = 60242
ic_fluent_mail_shield_20_filled = 60243
ic_fluent_mail_shield_20_regular = 60244
ic_fluent_mail_template_20_filled = 60245
ic_fluent_mail_template_20_regular = 60246
ic_fluent_mail_unread_20_filled = 60247
ic_fluent_mail_unread_20_regular = 60248
ic_fluent_mail_warning_20_filled = 60249
ic_fluent_mail_warning_20_regular = 60250
ic_fluent_mailbox_20_filled = 60251
ic_fluent_mailbox_20_regular = 60252
ic_fluent_map_20_filled = 60253
ic_fluent_map_20_regular = 60254
ic_fluent_map_drive_20_filled = 60255
ic_fluent_map_drive_20_regular = 60256
ic_fluent_markdown_20_filled = 60257
ic_fluent_markdown_20_regular = 60258
ic_fluent_match_app_layout_20_filled = 60259
ic_fluent_match_app_layout_20_regular = 60260
ic_fluent_math_format_linear_20_filled = 60261
ic_fluent_math_format_linear_20_regular = 60262
ic_fluent_math_format_professional_20_filled = 60263
ic_fluent_math_format_professional_20_regular = 60264
ic_fluent_math_formula_20_filled = 60265
ic_fluent_math_formula_20_regular = 60266
ic_fluent_math_formula_sparkle_20_filled = 60267
ic_fluent_math_formula_sparkle_20_regular = 60268
ic_fluent_math_symbols_20_filled = 60269
ic_fluent_math_symbols_20_regular = 60270
ic_fluent_maximize_20_filled = 60271
ic_fluent_maximize_20_regular = 60272
ic_fluent_meet_now_20_filled = 60273
ic_fluent_meet_now_20_regular = 60274
ic_fluent_megaphone_20_filled = 60275
ic_fluent_megaphone_20_regular = 60276
ic_fluent_megaphone_circle_20_filled = 60277
ic_fluent_megaphone_circle_20_regular = 60278
ic_fluent_megaphone_loud_20_filled = 60279
ic_fluent_megaphone_loud_20_regular = 60280
ic_fluent_megaphone_off_20_filled = 60281
ic_fluent_megaphone_off_20_regular = 60282
ic_fluent_mention_20_filled = 60283
ic_fluent_mention_20_regular = 60284
ic_fluent_mention_arrow_down_20_filled = 60285
ic_fluent_mention_arrow_down_20_regular = 60286
ic_fluent_mention_brackets_20_filled = 60287
ic_fluent_mention_brackets_20_regular = 60288
ic_fluent_merge_20_filled = 60289
ic_fluent_merge_20_regular = 60290
ic_fluent_mic_20_filled = 60291
ic_fluent_mic_20_regular = 60292
ic_fluent_mic_link_20_filled = 60293
ic_fluent_mic_link_20_regular = 60294
ic_fluent_mic_off_20_filled = 60295
ic_fluent_mic_off_20_regular = 60296
ic_fluent_mic_prohibited_20_filled = 60297
ic_fluent_mic_prohibited_20_regular = 60298
ic_fluent_mic_pulse_20_filled = 60299
ic_fluent_mic_pulse_20_regular = 60300
ic_fluent_mic_pulse_off_20_filled = 60301
ic_fluent_mic_pulse_off_20_regular = 60302
ic_fluent_mic_record_20_filled = 60303
ic_fluent_mic_record_20_regular = 60304
ic_fluent_mic_settings_20_filled = 60305
ic_fluent_mic_settings_20_regular = 60306
ic_fluent_mic_sparkle_20_filled = 60307
ic_fluent_mic_sparkle_20_regular = 60308
ic_fluent_mic_sync_20_filled = 60309
ic_fluent_mic_sync_20_regular = 60310
ic_fluent_microscope_20_filled = 60311
ic_fluent_microscope_20_regular = 60312
ic_fluent_midi_20_filled = 60313
ic_fluent_midi_20_regular = 60314
ic_fluent_mobile_optimized_20_filled = 60315
ic_fluent_mobile_optimized_20_regular = 60316
ic_fluent_mold_20_filled = 60317
ic_fluent_mold_20_regular = 60318
ic_fluent_molecule_20_filled = 60319
ic_fluent_molecule_20_regular = 60320
ic_fluent_money_20_filled = 60321
ic_fluent_money_20_regular = 60322
ic_fluent_money_calculator_20_filled = 60323
ic_fluent_money_calculator_20_regular = 60324
ic_fluent_money_dismiss_20_filled = 60325
ic_fluent_money_dismiss_20_regular = 60326
ic_fluent_money_hand_20_filled = 60327
ic_fluent_money_hand_20_regular = 60328
ic_fluent_money_off_20_filled = 60329
ic_fluent_money_off_20_regular = 60330
ic_fluent_money_settings_20_filled = 60331
ic_fluent_money_settings_20_regular = 60332
ic_fluent_more_circle_20_filled = 60333
ic_fluent_more_circle_20_regular = 60334
ic_fluent_more_horizontal_20_filled = 60335
ic_fluent_more_horizontal_20_regular = 60336
ic_fluent_more_vertical_20_filled = 60337
ic_fluent_more_vertical_20_regular = 60338
ic_fluent_mountain_location_bottom_20_filled = 60339
ic_fluent_mountain_location_bottom_20_regular = 60340
ic_fluent_mountain_location_top_20_filled = 60341
ic_fluent_mountain_location_top_20_regular = 60342
ic_fluent_mountain_trail_20_filled = 60343
ic_fluent_mountain_trail_20_regular = 60344
ic_fluent_movies_and_tv_20_filled = 60345
ic_fluent_movies_and_tv_20_regular = 60346
ic_fluent_multiplier_1_2x_20_filled = 60347
ic_fluent_multiplier_1_2x_20_regular = 60348
ic_fluent_multiplier_1_5x_20_filled = 60349
ic_fluent_multiplier_1_5x_20_regular = 60350
ic_fluent_multiplier_1_8x_20_filled = 60351
ic_fluent_multiplier_1_8x_20_regular = 60352
ic_fluent_multiplier_1x_20_filled = 60353
ic_fluent_multiplier_1x_20_regular = 60354
ic_fluent_multiplier_2x_20_filled = 60355
ic_fluent_multiplier_2x_20_regular = 60356
ic_fluent_multiplier_5x_20_filled = 60357
ic_fluent_multiplier_5x_20_regular = 60358
ic_fluent_multiselect_ltr_20_filled = 60359
ic_fluent_multiselect_ltr_20_regular = 60360
ic_fluent_multiselect_rtl_20_filled = 60361
ic_fluent_multiselect_rtl_20_regular = 60362
ic_fluent_music_note_1_20_filled = 60363
ic_fluent_music_note_1_20_regular = 60364
ic_fluent_music_note_2_20_filled = 60365
ic_fluent_music_note_2_20_regular = 60366
ic_fluent_music_note_2_play_20_filled = 60367
ic_fluent_music_note_2_play_20_regular = 60368
ic_fluent_music_note_off_1_20_filled = 60369
ic_fluent_music_note_off_1_20_regular = 60370
ic_fluent_music_note_off_2_20_filled = 60371
ic_fluent_music_note_off_2_20_regular = 60372
ic_fluent_my_location_20_filled = 60373
ic_fluent_my_location_20_regular = 60374
ic_fluent_navigation_20_filled = 60375
ic_fluent_navigation_20_regular = 60376
ic_fluent_navigation_briefcase_20_filled = 60377
ic_fluent_navigation_briefcase_20_regular = 60378
ic_fluent_navigation_location_target_20_filled = 60379
ic_fluent_navigation_location_target_20_regular = 60380
ic_fluent_navigation_person_20_filled = 60381
ic_fluent_navigation_person_20_regular = 60382
ic_fluent_navigation_play_20_filled = 60383
ic_fluent_navigation_play_20_regular = 60384
ic_fluent_navigation_unread_20_filled = 60385
ic_fluent_navigation_unread_20_regular = 60386
ic_fluent_network_check_20_filled = 60387
ic_fluent_network_check_20_regular = 60388
ic_fluent_new_20_filled = 60389
ic_fluent_new_20_regular = 60390
ic_fluent_news_20_filled = 60391
ic_fluent_news_20_regular = 60392
ic_fluent_next_20_filled = 60393
ic_fluent_next_20_regular = 60394
ic_fluent_next_frame_20_filled = 60395
ic_fluent_next_frame_20_regular = 60396
ic_fluent_note_20_filled = 60397
ic_fluent_note_20_regular = 60398
ic_fluent_note_add_20_filled = 60399
ic_fluent_note_add_20_regular = 60400
ic_fluent_note_edit_20_filled = 60401
ic_fluent_note_edit_20_regular = 60402
ic_fluent_note_pin_20_filled = 60403
ic_fluent_note_pin_20_regular = 60404
ic_fluent_notebook_20_filled = 60405
ic_fluent_notebook_20_regular = 60406
ic_fluent_notebook_add_20_filled = 60407
ic_fluent_notebook_add_20_regular = 60408
ic_fluent_notebook_arrow_curve_down_20_filled = 60409
ic_fluent_notebook_arrow_curve_down_20_regular = 60410
ic_fluent_notebook_error_20_filled = 60411
ic_fluent_notebook_error_20_regular = 60412
ic_fluent_notebook_eye_20_filled = 60413
ic_fluent_notebook_eye_20_regular = 60414
ic_fluent_notebook_lightning_20_filled = 60415
ic_fluent_notebook_lightning_20_regular = 60416
ic_fluent_notebook_question_mark_20_filled = 60417
ic_fluent_notebook_question_mark_20_regular = 60418
ic_fluent_notebook_section_20_filled = 60419
ic_fluent_notebook_section_20_regular = 60420
ic_fluent_notebook_section_arrow_right_20_filled = 60421
ic_fluent_notebook_section_arrow_right_20_regular = 60422
ic_fluent_notebook_subsection_20_filled = 60423
ic_fluent_notebook_subsection_20_regular = 60424
ic_fluent_notebook_sync_20_filled = 60425
ic_fluent_notebook_sync_20_regular = 60426
ic_fluent_notepad_20_filled = 60427
ic_fluent_notepad_20_regular = 60428
ic_fluent_notepad_edit_20_filled = 60429
ic_fluent_notepad_edit_20_regular = 60430
ic_fluent_notepad_person_20_filled = 60431
ic_fluent_notepad_person_20_regular = 60432
ic_fluent_notepad_person_off_20_filled = 60433
ic_fluent_notepad_person_off_20_regular = 60434
ic_fluent_notepad_sparkle_20_filled = 60435
ic_fluent_notepad_sparkle_20_regular = 60436
ic_fluent_number_circle_0_20_filled = 60437
ic_fluent_number_circle_0_20_regular = 60438
ic_fluent_number_circle_1_20_filled = 60439
ic_fluent_number_circle_1_20_regular = 60440
ic_fluent_number_circle_2_20_filled = 60441
ic_fluent_number_circle_2_20_regular = 60442
ic_fluent_number_circle_3_20_filled = 60443
ic_fluent_number_circle_3_20_regular = 60444
ic_fluent_number_circle_4_20_filled = 60445
ic_fluent_number_circle_4_20_regular = 60446
ic_fluent_number_circle_5_20_filled = 60447
ic_fluent_number_circle_5_20_regular = 60448
ic_fluent_number_circle_6_20_filled = 60449
ic_fluent_number_circle_6_20_regular = 60450
ic_fluent_number_circle_7_20_filled = 60451
ic_fluent_number_circle_7_20_regular = 60452
ic_fluent_number_circle_8_20_filled = 60453
ic_fluent_number_circle_8_20_regular = 60454
ic_fluent_number_circle_9_20_filled = 60455
ic_fluent_number_circle_9_20_regular = 60456
ic_fluent_number_row_20_filled = 60457
ic_fluent_number_row_20_regular = 60458
ic_fluent_number_symbol_20_filled = 60459
ic_fluent_number_symbol_20_regular = 60460
ic_fluent_number_symbol_dismiss_20_filled = 60461
ic_fluent_number_symbol_dismiss_20_regular = 60462
ic_fluent_number_symbol_square_20_filled = 60463
ic_fluent_number_symbol_square_20_regular = 60464
ic_fluent_open_20_filled = 60465
ic_fluent_open_20_regular = 60466
ic_fluent_open_folder_20_filled = 60467
ic_fluent_open_folder_20_regular = 60468
ic_fluent_open_off_20_filled = 60469
ic_fluent_open_off_20_regular = 60470
ic_fluent_options_20_filled = 60471
ic_fluent_options_20_regular = 60472
ic_fluent_organization_20_filled = 60473
ic_fluent_organization_20_regular = 60474
ic_fluent_organization_horizontal_20_filled = 60475
ic_fluent_organization_horizontal_20_regular = 60476
ic_fluent_orientation_20_filled = 60477
ic_fluent_orientation_20_regular = 60478
ic_fluent_oval_20_filled = 60479
ic_fluent_oval_20_regular = 60480
ic_fluent_oven_20_filled = 60481
ic_fluent_oven_20_regular = 60482
ic_fluent_padding_down_20_filled = 60483
ic_fluent_padding_down_20_regular = 60484
ic_fluent_padding_left_20_filled = 60485
ic_fluent_padding_left_20_regular = 60486
ic_fluent_padding_right_20_filled = 60487
ic_fluent_padding_right_20_regular = 60488
ic_fluent_padding_top_20_filled = 60489
ic_fluent_padding_top_20_regular = 60490
ic_fluent_page_fit_20_filled = 60491
ic_fluent_page_fit_20_regular = 60492
ic_fluent_paint_brush_20_filled = 60493
ic_fluent_paint_brush_20_regular = 60494
ic_fluent_paint_brush_arrow_down_20_filled = 60495
ic_fluent_paint_brush_arrow_down_20_regular = 60496
ic_fluent_paint_brush_arrow_up_20_filled = 60497
ic_fluent_paint_brush_arrow_up_20_regular = 60498
ic_fluent_paint_brush_sparkle_20_filled = 60499
ic_fluent_paint_brush_sparkle_20_regular = 60500
ic_fluent_paint_brush_subtract_20_filled = 60501
ic_fluent_paint_brush_subtract_20_regular = 60502
ic_fluent_paint_bucket_20_filled = 60503
ic_fluent_paint_bucket_20_regular = 60504
ic_fluent_paint_bucket_brush_20_filled = 60505
ic_fluent_paint_bucket_brush_20_regular = 60506
ic_fluent_pair_20_filled = 60507
ic_fluent_pair_20_regular = 60508
ic_fluent_panel_bottom_20_filled = 60509
ic_fluent_panel_bottom_20_regular = 60510
ic_fluent_panel_bottom_contract_20_filled = 60511
ic_fluent_panel_bottom_contract_20_regular = 60512
ic_fluent_panel_bottom_expand_20_filled = 60513
ic_fluent_panel_bottom_expand_20_regular = 60514
ic_fluent_panel_left_20_filled = 60515
ic_fluent_panel_left_20_regular = 60516
ic_fluent_panel_left_add_20_filled = 60517
ic_fluent_panel_left_add_20_regular = 60518
ic_fluent_panel_left_contract_20_filled = 60519
ic_fluent_panel_left_contract_20_regular = 60520
ic_fluent_panel_left_expand_20_filled = 60521
ic_fluent_panel_left_expand_20_regular = 60522
ic_fluent_panel_left_focus_right_20_filled = 60523
ic_fluent_panel_left_header_20_filled = 60524
ic_fluent_panel_left_header_20_regular = 60525
ic_fluent_panel_left_header_add_20_filled = 60526
ic_fluent_panel_left_header_add_20_regular = 60527
ic_fluent_panel_left_header_key_20_filled = 60528
ic_fluent_panel_left_header_key_20_regular = 60529
ic_fluent_panel_left_key_20_filled = 60530
ic_fluent_panel_left_key_20_regular = 60531
ic_fluent_panel_left_text_20_filled = 60532
ic_fluent_panel_left_text_20_regular = 60533
ic_fluent_panel_left_text_add_20_filled = 60534
ic_fluent_panel_left_text_add_20_regular = 60535
ic_fluent_panel_left_text_dismiss_20_filled = 60536
ic_fluent_panel_left_text_dismiss_20_regular = 60537
ic_fluent_panel_right_20_filled = 60538
ic_fluent_panel_right_20_regular = 60539
ic_fluent_panel_right_add_20_filled = 60540
ic_fluent_panel_right_add_20_regular = 60541
ic_fluent_panel_right_contract_20_filled = 60542
ic_fluent_panel_right_contract_20_regular = 60543
ic_fluent_panel_right_cursor_20_filled = 60544
ic_fluent_panel_right_cursor_20_regular = 60545
ic_fluent_panel_right_expand_20_filled = 60546
ic_fluent_panel_right_expand_20_regular = 60547
ic_fluent_panel_right_gallery_20_filled = 60548
ic_fluent_panel_right_gallery_20_regular = 60549
ic_fluent_panel_separate_window_20_filled = 60550
ic_fluent_panel_separate_window_20_regular = 60551
ic_fluent_panel_top_contract_20_filled = 60552
ic_fluent_panel_top_contract_20_regular = 60553
ic_fluent_panel_top_expand_20_filled = 60554
ic_fluent_panel_top_expand_20_regular = 60555
ic_fluent_panel_top_gallery_20_filled = 60556
ic_fluent_panel_top_gallery_20_regular = 60557
ic_fluent_password_20_filled = 60558
ic_fluent_password_20_regular = 60559
ic_fluent_password_clock_20_filled = 60560
ic_fluent_password_clock_20_regular = 60561
ic_fluent_patch_20_filled = 60562
ic_fluent_patch_20_regular = 60563
ic_fluent_patient_20_filled = 60564
ic_fluent_patient_20_regular = 60565
ic_fluent_pause_20_filled = 60566
ic_fluent_pause_20_regular = 60567
ic_fluent_pause_circle_20_filled = 60568
ic_fluent_pause_circle_20_regular = 60569
ic_fluent_pause_off_20_filled = 60570
ic_fluent_pause_off_20_regular = 60571
ic_fluent_pause_settings_20_filled = 60572
ic_fluent_pause_settings_20_regular = 60573
ic_fluent_payment_20_filled = 60574
ic_fluent_payment_20_regular = 60575
ic_fluent_payment_wireless_20_filled = 60576
ic_fluent_payment_wireless_20_regular = 60577
ic_fluent_pen_20_filled = 60578
ic_fluent_pen_20_regular = 60579
ic_fluent_pen_dismiss_20_filled = 60580
ic_fluent_pen_dismiss_20_regular = 60581
ic_fluent_pen_off_20_filled = 60582
ic_fluent_pen_off_20_regular = 60583
ic_fluent_pen_prohibited_20_filled = 60584
ic_fluent_pen_prohibited_20_regular = 60585
ic_fluent_pen_sparkle_20_filled = 60586
ic_fluent_pen_sparkle_20_regular = 60587
ic_fluent_pen_sync_20_filled = 60588
ic_fluent_pen_sync_20_regular = 60589
ic_fluent_pentagon_20_filled = 60590
ic_fluent_pentagon_20_regular = 60591
ic_fluent_people_20_filled = 60592
ic_fluent_people_20_regular = 60593
ic_fluent_people_add_20_filled = 60594
ic_fluent_people_add_20_regular = 60595
ic_fluent_people_audience_20_filled = 60596
ic_fluent_people_audience_20_regular = 60597
ic_fluent_people_call_20_filled = 60598
ic_fluent_people_call_20_regular = 60599
ic_fluent_people_chat_20_filled = 60600
ic_fluent_people_chat_20_regular = 60601
ic_fluent_people_checkmark_20_filled = 60602
ic_fluent_people_checkmark_20_regular = 60603
ic_fluent_people_community_20_filled = 60604
ic_fluent_people_community_20_regular = 60605
ic_fluent_people_community_add_20_filled = 60606
ic_fluent_people_community_add_20_regular = 60607
ic_fluent_people_edit_20_filled = 60608
ic_fluent_people_edit_20_regular = 60609
ic_fluent_people_error_20_filled = 60610
ic_fluent_people_error_20_regular = 60611
ic_fluent_people_eye_20_filled = 60612
ic_fluent_people_eye_20_regular = 60613
ic_fluent_people_interwoven_20_filled = 60614
ic_fluent_people_interwoven_20_regular = 60615
ic_fluent_people_link_20_filled = 60616
ic_fluent_people_link_20_regular = 60617
ic_fluent_people_list_20_filled = 60618
ic_fluent_people_list_20_regular = 60619
ic_fluent_people_lock_20_filled = 60620
ic_fluent_people_lock_20_regular = 60621
ic_fluent_people_money_20_filled = 60622
ic_fluent_people_money_20_regular = 60623
ic_fluent_people_prohibited_20_filled = 60624
ic_fluent_people_prohibited_20_regular = 60625
ic_fluent_people_queue_20_filled = 60626
ic_fluent_people_queue_20_regular = 60627
ic_fluent_people_search_20_filled = 60628
ic_fluent_people_search_20_regular = 60629
ic_fluent_people_settings_20_filled = 60630
ic_fluent_people_settings_20_regular = 60631
ic_fluent_people_star_20_filled = 60632
ic_fluent_people_star_20_regular = 60633
ic_fluent_people_subtract_20_filled = 60634
ic_fluent_people_subtract_20_regular = 60635
ic_fluent_people_swap_20_filled = 60636
ic_fluent_people_swap_20_regular = 60637
ic_fluent_people_sync_20_filled = 60638
ic_fluent_people_sync_20_regular = 60639
ic_fluent_people_team_20_filled = 60640
ic_fluent_people_team_20_regular = 60641
ic_fluent_people_team_add_20_filled = 60642
ic_fluent_people_team_add_20_regular = 60643
ic_fluent_people_team_delete_20_filled = 60644
ic_fluent_people_team_delete_20_regular = 60645
ic_fluent_people_team_toolbox_20_filled = 60646
ic_fluent_people_team_toolbox_20_regular = 60647
ic_fluent_people_toolbox_20_filled = 60648
ic_fluent_people_toolbox_20_regular = 60649
ic_fluent_person_20_filled = 60650
ic_fluent_person_20_regular = 60651
ic_fluent_person_5_20_filled = 60652
ic_fluent_person_5_20_regular = 60653
ic_fluent_person_6_20_filled = 60654
ic_fluent_person_6_20_regular = 60655
ic_fluent_person_accounts_20_filled = 60656
ic_fluent_person_accounts_20_regular = 60657
ic_fluent_person_add_20_filled = 60658
ic_fluent_person_add_20_regular = 60659
ic_fluent_person_alert_20_filled = 60660
ic_fluent_person_alert_20_regular = 60661
ic_fluent_person_alert_off_20_filled = 60662
ic_fluent_person_alert_off_20_regular = 60663
ic_fluent_person_arrow_back_20_filled = 60664
ic_fluent_person_arrow_back_20_regular = 60665
ic_fluent_person_arrow_left_20_filled = 60666
ic_fluent_person_arrow_left_20_regular = 60667
ic_fluent_person_arrow_right_20_filled = 60668
ic_fluent_person_arrow_right_20_regular = 60669
ic_fluent_person_available_20_filled = 60670
ic_fluent_person_available_20_regular = 60671
ic_fluent_person_board_20_filled = 60672
ic_fluent_person_board_20_regular = 60673
ic_fluent_person_board_add_20_filled = 60674
ic_fluent_person_board_add_20_regular = 60675
ic_fluent_person_briefcase_20_filled = 60676
ic_fluent_person_briefcase_20_regular = 60677
ic_fluent_person_call_20_filled = 60678
ic_fluent_person_call_20_regular = 60679
ic_fluent_person_chat_20_filled = 60680
ic_fluent_person_chat_20_regular = 60681
ic_fluent_person_circle_20_filled = 60682
ic_fluent_person_circle_20_regular = 60683
ic_fluent_person_clock_20_filled = 60684
ic_fluent_person_clock_20_regular = 60685
ic_fluent_person_delete_20_filled = 60686
ic_fluent_person_delete_20_regular = 60687
ic_fluent_person_desktop_20_filled = 60688
ic_fluent_person_desktop_20_regular = 60689
ic_fluent_person_edit_20_filled = 60690
ic_fluent_person_edit_20_regular = 60691
ic_fluent_person_error_20_filled = 60692
ic_fluent_person_error_20_regular = 60693
ic_fluent_person_feedback_20_filled = 60694
ic_fluent_person_feedback_20_regular = 60695
ic_fluent_person_head_hint_20_filled = 60696
ic_fluent_person_head_hint_20_regular = 60697
ic_fluent_person_heart_20_filled = 60698
ic_fluent_person_heart_20_regular = 60699
ic_fluent_person_home_20_filled = 60700
ic_fluent_person_home_20_regular = 60701
ic_fluent_person_info_20_filled = 60702
ic_fluent_person_info_20_regular = 60703
ic_fluent_person_key_20_filled = 60704
ic_fluent_person_key_20_regular = 60705
ic_fluent_person_lightbulb_20_filled = 60706
ic_fluent_person_lightbulb_20_regular = 60707
ic_fluent_person_lightning_20_filled = 60708
ic_fluent_person_lightning_20_regular = 60709
ic_fluent_person_link_20_filled = 60710
ic_fluent_person_link_20_regular = 60711
ic_fluent_person_lock_20_filled = 60712
ic_fluent_person_lock_20_regular = 60713
ic_fluent_person_mail_20_filled = 60714
ic_fluent_person_mail_20_regular = 60715
ic_fluent_person_money_20_filled = 60716
ic_fluent_person_money_20_regular = 60717
ic_fluent_person_note_20_filled = 60718
ic_fluent_person_note_20_regular = 60719
ic_fluent_person_passkey_20_filled = 60720
ic_fluent_person_passkey_20_regular = 60721
ic_fluent_person_pill_20_filled = 60722
ic_fluent_person_pill_20_regular = 60723
ic_fluent_person_prohibited_20_filled = 60724
ic_fluent_person_prohibited_20_regular = 60725
ic_fluent_person_question_mark_20_filled = 60726
ic_fluent_person_question_mark_20_regular = 60727
ic_fluent_person_ribbon_20_filled = 60728
ic_fluent_person_ribbon_20_regular = 60729
ic_fluent_person_running_20_filled = 60730
ic_fluent_person_running_20_regular = 60731
ic_fluent_person_search_20_filled = 60732
ic_fluent_person_search_20_regular = 60733
ic_fluent_person_settings_20_filled = 60734
ic_fluent_person_settings_20_regular = 60735
ic_fluent_person_shield_20_filled = 60736
ic_fluent_person_shield_20_regular = 60737
ic_fluent_person_sound_spatial_20_filled = 60738
ic_fluent_person_sound_spatial_20_regular = 60739
ic_fluent_person_square_20_filled = 60740
ic_fluent_person_square_20_regular = 60741
ic_fluent_person_square_add_20_filled = 60742
ic_fluent_person_square_add_20_regular = 60743
ic_fluent_person_square_checkmark_20_filled = 60744
ic_fluent_person_square_checkmark_20_regular = 60745
ic_fluent_person_star_20_filled = 60746
ic_fluent_person_star_20_regular = 60747
ic_fluent_person_starburst_20_filled = 60748
ic_fluent_person_starburst_20_regular = 60749
ic_fluent_person_subtract_20_filled = 60750
ic_fluent_person_subtract_20_regular = 60751
ic_fluent_person_support_20_filled = 60752
ic_fluent_person_support_20_regular = 60753
ic_fluent_person_swap_20_filled = 60754
ic_fluent_person_swap_20_regular = 60755
ic_fluent_person_sync_20_filled = 60756
ic_fluent_person_sync_20_regular = 60757
ic_fluent_person_tag_20_filled = 60758
ic_fluent_person_tag_20_regular = 60759
ic_fluent_person_tentative_20_filled = 60760
ic_fluent_person_tentative_20_regular = 60761
ic_fluent_person_voice_20_filled = 60762
ic_fluent_person_voice_20_regular = 60763
ic_fluent_person_walking_20_filled = 60764
ic_fluent_person_walking_20_regular = 60765
ic_fluent_person_warning_20_filled = 60766
ic_fluent_person_warning_20_regular = 60767
ic_fluent_person_wrench_20_filled = 60768
ic_fluent_person_wrench_20_regular = 60769
ic_fluent_phone_20_filled = 60770
ic_fluent_phone_20_regular = 60771
ic_fluent_phone_add_20_filled = 60772
ic_fluent_phone_add_20_regular = 60773
ic_fluent_phone_arrow_right_20_filled = 60774
ic_fluent_phone_arrow_right_20_regular = 60775
ic_fluent_phone_chat_20_filled = 60776
ic_fluent_phone_chat_20_regular = 60777
ic_fluent_phone_checkmark_20_filled = 60778
ic_fluent_phone_checkmark_20_regular = 60779
ic_fluent_phone_desktop_20_filled = 60780
ic_fluent_phone_desktop_20_regular = 60781
ic_fluent_phone_desktop_add_20_filled = 60782
ic_fluent_phone_desktop_add_20_regular = 60783
ic_fluent_phone_dismiss_20_filled = 60784
ic_fluent_phone_dismiss_20_regular = 60785
ic_fluent_phone_edit_20_filled = 60786
ic_fluent_phone_edit_20_regular = 60787
ic_fluent_phone_eraser_20_filled = 60788
ic_fluent_phone_eraser_20_regular = 60789
ic_fluent_phone_footer_arrow_down_20_filled = 60790
ic_fluent_phone_footer_arrow_down_20_regular = 60791
ic_fluent_phone_header_arrow_up_20_filled = 60792
ic_fluent_phone_header_arrow_up_20_regular = 60793
ic_fluent_phone_key_20_filled = 60794
ic_fluent_phone_key_20_regular = 60795
ic_fluent_phone_laptop_20_filled = 60796
ic_fluent_phone_laptop_20_regular = 60797
ic_fluent_phone_link_setup_20_filled = 60798
ic_fluent_phone_link_setup_20_regular = 60799
ic_fluent_phone_lock_20_filled = 60800
ic_fluent_phone_lock_20_regular = 60801
ic_fluent_phone_page_header_20_filled = 60802
ic_fluent_phone_page_header_20_regular = 60803
ic_fluent_phone_pagination_20_filled = 60804
ic_fluent_phone_pagination_20_regular = 60805
ic_fluent_phone_screen_time_20_filled = 60806
ic_fluent_phone_screen_time_20_regular = 60807
ic_fluent_phone_shake_20_filled = 60808
ic_fluent_phone_shake_20_regular = 60809
ic_fluent_phone_span_in_20_filled = 60810
ic_fluent_phone_span_in_20_regular = 60811
ic_fluent_phone_span_out_20_filled = 60812
ic_fluent_phone_span_out_20_regular = 60813
ic_fluent_phone_speaker_20_filled = 60814
ic_fluent_phone_speaker_20_regular = 60815
ic_fluent_phone_status_bar_20_filled = 60816
ic_fluent_phone_status_bar_20_regular = 60817
ic_fluent_phone_tablet_20_filled = 60818
ic_fluent_phone_tablet_20_regular = 60819
ic_fluent_phone_update_20_filled = 60820
ic_fluent_phone_update_20_regular = 60821
ic_fluent_phone_update_checkmark_20_filled = 60822
ic_fluent_phone_update_checkmark_20_regular = 60823
ic_fluent_phone_vertical_scroll_20_filled = 60824
ic_fluent_phone_vertical_scroll_20_regular = 60825
ic_fluent_phone_vibrate_20_filled = 60826
ic_fluent_phone_vibrate_20_regular = 60827
ic_fluent_photo_filter_20_filled = 60828
ic_fluent_photo_filter_20_regular = 60829
ic_fluent_pi_20_filled = 60830
ic_fluent_pi_20_regular = 60831
ic_fluent_picture_in_picture_20_filled = 60832
ic_fluent_picture_in_picture_20_regular = 60833
ic_fluent_picture_in_picture_enter_20_filled = 60834
ic_fluent_picture_in_picture_enter_20_regular = 60835
ic_fluent_picture_in_picture_exit_20_filled = 60836
ic_fluent_picture_in_picture_exit_20_regular = 60837
ic_fluent_pill_20_filled = 60838
ic_fluent_pill_20_regular = 60839
ic_fluent_pin_20_filled = 60840
ic_fluent_pin_20_regular = 60841
ic_fluent_pin_globe_20_filled = 60842
ic_fluent_pin_globe_20_regular = 60843
ic_fluent_pin_off_20_filled = 60844
ic_fluent_pin_off_20_regular = 60845
ic_fluent_pipeline_20_filled = 60846
ic_fluent_pipeline_20_regular = 60847
ic_fluent_pipeline_add_20_filled = 60848
ic_fluent_pipeline_add_20_regular = 60849
ic_fluent_pipeline_arrow_curve_down_20_filled = 60850
ic_fluent_pipeline_arrow_curve_down_20_regular = 60851
ic_fluent_pipeline_play_20_filled = 60852
ic_fluent_pipeline_play_20_regular = 60853
ic_fluent_pivot_20_filled = 60854
ic_fluent_pivot_20_regular = 60855
ic_fluent_planet_20_filled = 60856
ic_fluent_planet_20_regular = 60857
ic_fluent_plant_cattail_20_filled = 60858
ic_fluent_plant_cattail_20_regular = 60859
ic_fluent_plant_grass_20_filled = 60860
ic_fluent_plant_grass_20_regular = 60861
ic_fluent_plant_ragweed_20_filled = 60862
ic_fluent_plant_ragweed_20_regular = 60863
ic_fluent_play_20_filled = 60864
ic_fluent_play_20_regular = 60865
ic_fluent_play_circle_20_filled = 60866
ic_fluent_play_circle_20_regular = 60867
ic_fluent_play_circle_hint_20_filled = 60868
ic_fluent_play_circle_hint_20_regular = 60869
ic_fluent_play_circle_hint_half_20_filled = 60870
ic_fluent_play_circle_hint_half_20_regular = 60871
ic_fluent_play_circle_sparkle_20_filled = 60872
ic_fluent_play_circle_sparkle_20_regular = 60873
ic_fluent_play_settings_20_filled = 60874
ic_fluent_play_settings_20_regular = 60875
ic_fluent_playing_cards_20_filled = 60876
ic_fluent_playing_cards_20_regular = 60877
ic_fluent_plug_connected_20_filled = 60878
ic_fluent_plug_connected_20_regular = 60879
ic_fluent_plug_connected_add_20_filled = 60880
ic_fluent_plug_connected_add_20_regular = 60881
ic_fluent_plug_connected_checkmark_20_filled = 60882
ic_fluent_plug_connected_checkmark_20_regular = 60883
ic_fluent_plug_connected_settings_20_filled = 60884
ic_fluent_plug_connected_settings_20_regular = 60885
ic_fluent_plug_disconnected_20_filled = 60886
ic_fluent_plug_disconnected_20_regular = 60887
ic_fluent_point_scan_20_filled = 60888
ic_fluent_point_scan_20_regular = 60889
ic_fluent_poll_20_filled = 60890
ic_fluent_poll_20_regular = 60891
ic_fluent_poll_horizontal_20_filled = 60892
ic_fluent_poll_horizontal_20_regular = 60893
ic_fluent_poll_off_20_filled = 60894
ic_fluent_poll_off_20_regular = 60895
ic_fluent_port_hdmi_20_filled = 60896
ic_fluent_port_hdmi_20_regular = 60897
ic_fluent_port_micro_usb_20_filled = 60898
ic_fluent_port_micro_usb_20_regular = 60899
ic_fluent_port_usb_a_20_filled = 60900
ic_fluent_port_usb_a_20_regular = 60901
ic_fluent_port_usb_c_20_filled = 60902
ic_fluent_port_usb_c_20_regular = 60903
ic_fluent_position_backward_20_filled = 60904
ic_fluent_position_backward_20_regular = 60905
ic_fluent_position_forward_20_filled = 60906
ic_fluent_position_forward_20_regular = 60907
ic_fluent_position_to_back_20_filled = 60908
ic_fluent_position_to_back_20_regular = 60909
ic_fluent_position_to_front_20_filled = 60910
ic_fluent_position_to_front_20_regular = 60911
ic_fluent_power_20_filled = 60912
ic_fluent_power_20_regular = 60913
ic_fluent_predictions_20_filled = 60914
ic_fluent_predictions_20_regular = 60915
ic_fluent_premium_20_filled = 60916
ic_fluent_premium_20_regular = 60917
ic_fluent_premium_person_20_filled = 60918
ic_fluent_premium_person_20_regular = 60919
ic_fluent_presence_available_20_filled = 60920
ic_fluent_presence_available_20_regular = 60921
ic_fluent_presence_away_20_filled = 60922
ic_fluent_presence_away_20_regular = 60923
ic_fluent_presence_blocked_20_regular = 60924
ic_fluent_presence_busy_20_filled = 60925
ic_fluent_presence_dnd_20_filled = 60926
ic_fluent_presence_dnd_20_regular = 60927
ic_fluent_presence_offline_20_regular = 60928
ic_fluent_presence_oof_20_regular = 60929
ic_fluent_presence_tentative_20_regular = 60930
ic_fluent_presence_unknown_20_regular = 60931
ic_fluent_presenter_20_filled = 60932
ic_fluent_presenter_20_regular = 60933
ic_fluent_presenter_off_20_filled = 60934
ic_fluent_presenter_off_20_regular = 60935
ic_fluent_preview_link_20_filled = 60936
ic_fluent_preview_link_20_regular = 60937
ic_fluent_previous_20_filled = 60938
ic_fluent_previous_20_regular = 60939
ic_fluent_previous_frame_20_filled = 60940
ic_fluent_previous_frame_20_regular = 60941
ic_fluent_print_20_filled = 60942
ic_fluent_print_20_regular = 60943
ic_fluent_print_add_20_filled = 60944
ic_fluent_print_add_20_regular = 60945
ic_fluent_production_20_filled = 60946
ic_fluent_production_20_regular = 60947
ic_fluent_production_checkmark_20_filled = 60948
ic_fluent_production_checkmark_20_regular = 60949
ic_fluent_prohibited_20_filled = 60950
ic_fluent_prohibited_20_regular = 60951
ic_fluent_prohibited_multiple_20_filled = 60952
ic_fluent_prohibited_multiple_20_regular = 60953
ic_fluent_prohibited_note_20_filled = 60954
ic_fluent_prohibited_note_20_regular = 60955
ic_fluent_projection_screen_20_filled = 60956
ic_fluent_projection_screen_20_regular = 60957
ic_fluent_projection_screen_dismiss_20_filled = 60958
ic_fluent_projection_screen_dismiss_20_regular = 60959
ic_fluent_projection_screen_text_20_filled = 60960
ic_fluent_projection_screen_text_20_regular = 60961
ic_fluent_projection_screen_text_sparkle_20_filled = 60962
ic_fluent_projection_screen_text_sparkle_20_regular = 60963
ic_fluent_prompt_20_filled = 60964
ic_fluent_prompt_20_regular = 60965
ic_fluent_protocol_handler_20_filled = 60966
ic_fluent_protocol_handler_20_regular = 60967
ic_fluent_pulse_20_filled = 60968
ic_fluent_pulse_20_regular = 60969
ic_fluent_pulse_square_20_filled = 60970
ic_fluent_pulse_square_20_regular = 60971
ic_fluent_puzzle_cube_20_filled = 60972
ic_fluent_puzzle_cube_20_regular = 60973
ic_fluent_puzzle_cube_piece_20_filled = 60974
ic_fluent_puzzle_cube_piece_20_regular = 60975
ic_fluent_puzzle_piece_20_filled = 60976
ic_fluent_puzzle_piece_20_regular = 60977
ic_fluent_puzzle_piece_shield_20_filled = 60978
ic_fluent_puzzle_piece_shield_20_regular = 60979
ic_fluent_qr_code_20_filled = 60980
ic_fluent_qr_code_20_regular = 60981
ic_fluent_question_20_filled = 60982
ic_fluent_question_20_regular = 60983
ic_fluent_question_circle_20_filled = 60984
ic_fluent_question_circle_20_regular = 60985
ic_fluent_quiz_new_20_filled = 60986
ic_fluent_quiz_new_20_regular = 60987
ic_fluent_radar_20_filled = 60988
ic_fluent_radar_20_regular = 60989
ic_fluent_radar_checkmark_20_filled = 60990
ic_fluent_radar_checkmark_20_regular = 60991
ic_fluent_radar_rectangle_multiple_20_filled = 60992
ic_fluent_radar_rectangle_multiple_20_regular = 60993
ic_fluent_radio_button_20_filled = 60994
ic_fluent_radio_button_20_regular = 60995
ic_fluent_ram_20_filled = 60996
ic_fluent_ram_20_regular = 60997
ic_fluent_rating_mature_20_filled = 60998
ic_fluent_rating_mature_20_regular = 60999
ic_fluent_ratio_one_to_one_20_filled = 61000
ic_fluent_ratio_one_to_one_20_regular = 61001
ic_fluent_re_order_20_filled = 61002
ic_fluent_re_order_20_regular = 61003
ic_fluent_re_order_dots_horizontal_20_filled = 61004
ic_fluent_re_order_dots_horizontal_20_regular = 61005
ic_fluent_re_order_dots_vertical_20_filled = 61006
ic_fluent_re_order_dots_vertical_20_regular = 61007
ic_fluent_re_order_vertical_20_filled = 61008
ic_fluent_re_order_vertical_20_regular = 61009
ic_fluent_read_aloud_20_filled = 61010
ic_fluent_read_aloud_20_regular = 61011
ic_fluent_reading_list_20_filled = 61012
ic_fluent_reading_list_20_regular = 61013
ic_fluent_reading_list_add_20_filled = 61014
ic_fluent_reading_list_add_20_regular = 61015
ic_fluent_reading_mode_mobile_20_filled = 61016
ic_fluent_reading_mode_mobile_20_regular = 61017
ic_fluent_real_estate_20_filled = 61018
ic_fluent_real_estate_20_regular = 61019
ic_fluent_receipt_20_filled = 61020
ic_fluent_receipt_20_regular = 61021
ic_fluent_receipt_add_20_filled = 61022
ic_fluent_receipt_add_20_regular = 61023
ic_fluent_receipt_bag_20_filled = 61024
ic_fluent_receipt_bag_20_regular = 61025
ic_fluent_receipt_cube_20_filled = 61026
ic_fluent_receipt_cube_20_regular = 61027
ic_fluent_receipt_money_20_filled = 61028
ic_fluent_receipt_money_20_regular = 61029
ic_fluent_receipt_play_20_filled = 61030
ic_fluent_receipt_play_20_regular = 61031
ic_fluent_receipt_search_20_filled = 61032
ic_fluent_receipt_search_20_regular = 61033
ic_fluent_receipt_sparkles_20_filled = 61034
ic_fluent_receipt_sparkles_20_regular = 61035
ic_fluent_record_20_filled = 61036
ic_fluent_record_20_regular = 61037
ic_fluent_record_stop_20_filled = 61038
ic_fluent_record_stop_20_regular = 61039
ic_fluent_rectangle_landscape_20_filled = 61040
ic_fluent_rectangle_landscape_20_regular = 61041
ic_fluent_rectangle_landscape_hint_copy_20_filled = 61042
ic_fluent_rectangle_landscape_hint_copy_20_regular = 61043
ic_fluent_rectangle_landscape_sparkle_20_filled = 61044
ic_fluent_rectangle_landscape_sparkle_20_regular = 61045
ic_fluent_rectangle_landscape_sync_20_filled = 61046
ic_fluent_rectangle_landscape_sync_20_regular = 61047
ic_fluent_rectangle_landscape_sync_off_20_filled = 61048
ic_fluent_rectangle_landscape_sync_off_20_regular = 61049
ic_fluent_rectangle_portrait_20_filled = 61050
ic_fluent_rectangle_portrait_20_regular = 61051
ic_fluent_rectangle_portrait_location_target_20_filled = 61052
ic_fluent_rectangle_portrait_location_target_20_regular = 61053
ic_fluent_recycle_20_filled = 61054
ic_fluent_recycle_20_regular = 61055
ic_fluent_remix_add_20_filled = 61056
ic_fluent_remix_add_20_regular = 61057
ic_fluent_remote_20_filled = 61058
ic_fluent_remote_20_regular = 61059
ic_fluent_rename_20_filled = 61060
ic_fluent_rename_20_regular = 61061
ic_fluent_reorder_20_filled = 61062
ic_fluent_reorder_20_regular = 61063
ic_fluent_replay_20_filled = 61064
ic_fluent_replay_20_regular = 61065
ic_fluent_resize_20_filled = 61066
ic_fluent_resize_20_regular = 61067
ic_fluent_resize_image_20_filled = 61068
ic_fluent_resize_image_20_regular = 61069
ic_fluent_resize_large_20_filled = 61070
ic_fluent_resize_large_20_regular = 61071
ic_fluent_resize_small_20_filled = 61072
ic_fluent_resize_small_20_regular = 61073
ic_fluent_resize_table_20_filled = 61074
ic_fluent_resize_table_20_regular = 61075
ic_fluent_resize_video_20_filled = 61076
ic_fluent_resize_video_20_regular = 61077
ic_fluent_reward_20_filled = 61078
ic_fluent_reward_20_regular = 61079
ic_fluent_rewind_20_filled = 61080
ic_fluent_rewind_20_regular = 61081
ic_fluent_rhombus_20_filled = 61082
ic_fluent_rhombus_20_regular = 61083
ic_fluent_ribbon_20_filled = 61084
ic_fluent_ribbon_20_regular = 61085
ic_fluent_ribbon_add_20_filled = 61086
ic_fluent_ribbon_add_20_regular = 61087
ic_fluent_ribbon_off_20_filled = 61088
ic_fluent_ribbon_off_20_regular = 61089
ic_fluent_ribbon_star_20_filled = 61090
ic_fluent_ribbon_star_20_regular = 61091
ic_fluent_road_20_filled = 61092
ic_fluent_road_20_regular = 61093
ic_fluent_road_cone_20_filled = 61094
ic_fluent_road_cone_20_regular = 61095
ic_fluent_rocket_20_filled = 61096
ic_fluent_rocket_20_regular = 61097
ic_fluent_rotate_left_20_filled = 61098
ic_fluent_rotate_left_20_regular = 61099
ic_fluent_rotate_right_20_filled = 61100
ic_fluent_rotate_right_20_regular = 61101
ic_fluent_router_20_filled = 61102
ic_fluent_router_20_regular = 61103
ic_fluent_row_child_20_filled = 61104
ic_fluent_row_child_20_regular = 61105
ic_fluent_row_triple_20_filled = 61106
ic_fluent_row_triple_20_regular = 61107
ic_fluent_rss_20_filled = 61108
ic_fluent_rss_20_regular = 61109
ic_fluent_ruler_20_filled = 61110
ic_fluent_ruler_20_regular = 61111
ic_fluent_run_20_filled = 61112
ic_fluent_run_20_regular = 61113
ic_fluent_sanitize_20_filled = 61114
ic_fluent_sanitize_20_regular = 61115
ic_fluent_save_20_filled = 61116
ic_fluent_save_20_regular = 61117
ic_fluent_save_arrow_right_20_filled = 61118
ic_fluent_save_arrow_right_20_regular = 61119
ic_fluent_save_copy_20_filled = 61120
ic_fluent_save_copy_20_regular = 61121
ic_fluent_save_edit_20_filled = 61122
ic_fluent_save_edit_20_regular = 61123
ic_fluent_save_image_20_filled = 61124
ic_fluent_save_image_20_regular = 61125
ic_fluent_save_multiple_20_filled = 61126
ic_fluent_save_multiple_20_regular = 61127
ic_fluent_save_search_20_filled = 61128
ic_fluent_save_search_20_regular = 61129
ic_fluent_save_sync_20_filled = 61130
ic_fluent_save_sync_20_regular = 61131
ic_fluent_savings_20_filled = 61132
ic_fluent_savings_20_regular = 61133
ic_fluent_scale_fill_20_filled = 61134
ic_fluent_scale_fill_20_regular = 61135
ic_fluent_scale_fit_20_filled = 61136
ic_fluent_scale_fit_20_regular = 61137
ic_fluent_scales_20_filled = 61138
ic_fluent_scales_20_regular = 61139
ic_fluent_scan_20_filled = 61140
ic_fluent_scan_20_regular = 61141
ic_fluent_scan_camera_20_filled = 61142
ic_fluent_scan_camera_20_regular = 61143
ic_fluent_scan_dash_20_filled = 61144
ic_fluent_scan_dash_20_regular = 61145
ic_fluent_scan_object_20_filled = 61146
ic_fluent_scan_object_20_regular = 61147
ic_fluent_scan_person_20_filled = 61148
ic_fluent_scan_person_20_regular = 61149
ic_fluent_scan_table_20_filled = 61150
ic_fluent_scan_table_20_regular = 61151
ic_fluent_scan_text_20_filled = 61152
ic_fluent_scan_text_20_regular = 61153
ic_fluent_scan_thumb_up_20_filled = 61154
ic_fluent_scan_thumb_up_20_regular = 61155
ic_fluent_scan_thumb_up_off_20_filled = 61156
ic_fluent_scan_thumb_up_off_20_regular = 61157
ic_fluent_scan_type_20_filled = 61158
ic_fluent_scan_type_20_regular = 61159
ic_fluent_scan_type_checkmark_20_filled = 61160
ic_fluent_scan_type_checkmark_20_regular = 61161
ic_fluent_scan_type_off_20_filled = 61162
ic_fluent_scan_type_off_20_regular = 61163
ic_fluent_scratchpad_20_filled = 61164
ic_fluent_scratchpad_20_regular = 61165
ic_fluent_screen_cut_20_filled = 61166
ic_fluent_screen_cut_20_regular = 61167
ic_fluent_screen_person_20_filled = 61168
ic_fluent_screen_person_20_regular = 61169
ic_fluent_screen_search_20_filled = 61170
ic_fluent_screen_search_20_regular = 61171
ic_fluent_screenshot_20_filled = 61172
ic_fluent_screenshot_20_regular = 61173
ic_fluent_screenshot_record_20_filled = 61174
ic_fluent_screenshot_record_20_regular = 61175
ic_fluent_script_20_filled = 61176
ic_fluent_script_20_regular = 61177
ic_fluent_search_20_filled = 61178
ic_fluent_search_20_regular = 61179
ic_fluent_search_info_20_filled = 61180
ic_fluent_search_info_20_regular = 61181
ic_fluent_search_settings_20_filled = 61182
ic_fluent_search_settings_20_regular = 61183
ic_fluent_search_shield_20_filled = 61184
ic_fluent_search_shield_20_regular = 61185
ic_fluent_search_sparkle_20_filled = 61186
ic_fluent_search_sparkle_20_regular = 61187
ic_fluent_search_square_20_filled = 61188
ic_fluent_search_square_20_regular = 61189
ic_fluent_search_visual_20_filled = 61190
ic_fluent_search_visual_20_regular = 61191
ic_fluent_seat_20_filled = 61192
ic_fluent_seat_20_regular = 61193
ic_fluent_seat_add_20_filled = 61194
ic_fluent_seat_add_20_regular = 61195
ic_fluent_select_all_off_20_filled = 61196
ic_fluent_select_all_off_20_regular = 61197
ic_fluent_select_all_on_20_filled = 61198
ic_fluent_select_all_on_20_regular = 61199
ic_fluent_select_object_20_filled = 61200
ic_fluent_select_object_20_regular = 61201
ic_fluent_select_object_skew_20_filled = 61202
ic_fluent_select_object_skew_20_regular = 61203
ic_fluent_select_object_skew_dismiss_20_filled = 61204
ic_fluent_select_object_skew_dismiss_20_regular = 61205
ic_fluent_select_object_skew_edit_20_filled = 61206
ic_fluent_select_object_skew_edit_20_regular = 61207
ic_fluent_send_20_filled = 61208
ic_fluent_send_20_regular = 61209
ic_fluent_send_beaker_20_filled = 61210
ic_fluent_send_beaker_20_regular = 61211
ic_fluent_send_clock_20_filled = 61212
ic_fluent_send_clock_20_regular = 61213
ic_fluent_send_copy_20_filled = 61214
ic_fluent_send_copy_20_regular = 61215
ic_fluent_send_person_20_filled = 61216
ic_fluent_send_person_20_regular = 61217
ic_fluent_serial_port_20_filled = 61218
ic_fluent_serial_port_20_regular = 61219
ic_fluent_server_20_filled = 61220
ic_fluent_server_20_regular = 61221
ic_fluent_server_link_20_filled = 61222
ic_fluent_server_link_20_regular = 61223
ic_fluent_server_multiple_20_filled = 61224
ic_fluent_server_multiple_20_regular = 61225
ic_fluent_server_play_20_filled = 61226
ic_fluent_server_play_20_regular = 61227
ic_fluent_service_bell_20_filled = 61228
ic_fluent_service_bell_20_regular = 61229
ic_fluent_settings_20_filled = 61230
ic_fluent_settings_20_regular = 61231
ic_fluent_settings_chat_20_filled = 61232
ic_fluent_settings_chat_20_regular = 61233
ic_fluent_settings_cog_multiple_20_filled = 61234
ic_fluent_settings_cog_multiple_20_regular = 61235
ic_fluent_shape_exclude_20_filled = 61236
ic_fluent_shape_exclude_20_regular = 61237
ic_fluent_shape_intersect_20_filled = 61238
ic_fluent_shape_intersect_20_regular = 61239
ic_fluent_shape_organic_20_filled = 61240
ic_fluent_shape_organic_20_regular = 61241
ic_fluent_shape_subtract_20_filled = 61242
ic_fluent_shape_subtract_20_regular = 61243
ic_fluent_shape_union_20_filled = 61244
ic_fluent_shape_union_20_regular = 61245
ic_fluent_shapes_20_filled = 61246
ic_fluent_shapes_20_regular = 61247
ic_fluent_share_20_filled = 61248
ic_fluent_share_20_regular = 61249
ic_fluent_share_android_20_filled = 61250
ic_fluent_share_android_20_regular = 61251
ic_fluent_share_close_tray_20_filled = 61252
ic_fluent_share_close_tray_20_regular = 61253
ic_fluent_share_ios_20_filled = 61254
ic_fluent_share_ios_20_regular = 61255
ic_fluent_share_multiple_20_filled = 61256
ic_fluent_share_multiple_20_regular = 61257
ic_fluent_share_screen_person_20_filled = 61258
ic_fluent_share_screen_person_20_regular = 61259
ic_fluent_share_screen_person_overlay_20_filled = 61260
ic_fluent_share_screen_person_overlay_20_regular = 61261
ic_fluent_share_screen_person_overlay_inside_20_filled = 61262
ic_fluent_share_screen_person_overlay_inside_20_regular = 61263
ic_fluent_share_screen_person_p_20_filled = 61264
ic_fluent_share_screen_person_p_20_regular = 61265
ic_fluent_share_screen_start_20_filled = 61266
ic_fluent_share_screen_start_20_regular = 61267
ic_fluent_share_screen_stop_20_filled = 61268
ic_fluent_share_screen_stop_20_regular = 61269
ic_fluent_shield_20_filled = 61270
ic_fluent_shield_20_regular = 61271
ic_fluent_shield_add_20_filled = 61272
ic_fluent_shield_add_20_regular = 61273
ic_fluent_shield_arrow_right_20_filled = 61274
ic_fluent_shield_arrow_right_20_regular = 61275
ic_fluent_shield_badge_20_filled = 61276
ic_fluent_shield_badge_20_regular = 61277
ic_fluent_shield_checkmark_20_filled = 61278
ic_fluent_shield_checkmark_20_regular = 61279
ic_fluent_shield_dismiss_20_filled = 61280
ic_fluent_shield_dismiss_20_regular = 61281
ic_fluent_shield_dismiss_shield_20_filled = 61282
ic_fluent_shield_dismiss_shield_20_regular = 61283
ic_fluent_shield_error_20_filled = 61284
ic_fluent_shield_error_20_regular = 61285
ic_fluent_shield_globe_20_filled = 61286
ic_fluent_shield_globe_20_regular = 61287
ic_fluent_shield_keyhole_20_filled = 61288
ic_fluent_shield_keyhole_20_regular = 61289
ic_fluent_shield_lock_20_filled = 61290
ic_fluent_shield_lock_20_regular = 61291
ic_fluent_shield_person_20_filled = 61292
ic_fluent_shield_person_20_regular = 61293
ic_fluent_shield_person_add_20_filled = 61294
ic_fluent_shield_person_add_20_regular = 61295
ic_fluent_shield_prohibited_20_filled = 61296
ic_fluent_shield_prohibited_20_regular = 61297
ic_fluent_shield_question_20_filled = 61298
ic_fluent_shield_question_20_regular = 61299
ic_fluent_shield_settings_20_filled = 61300
ic_fluent_shield_settings_20_regular = 61301
ic_fluent_shield_task_20_filled = 61302
ic_fluent_shield_task_20_regular = 61303
ic_fluent_shifts_20_filled = 61304
ic_fluent_shifts_20_regular = 61305
ic_fluent_shifts_30_minutes_20_filled = 61306
ic_fluent_shifts_30_minutes_20_regular = 61307
ic_fluent_shifts_activity_20_filled = 61308
ic_fluent_shifts_activity_20_regular = 61309
ic_fluent_shifts_add_20_filled = 61310
ic_fluent_shifts_add_20_regular = 61311
ic_fluent_shifts_availability_20_filled = 61312
ic_fluent_shifts_availability_20_regular = 61313
ic_fluent_shifts_checkmark_20_filled = 61314
ic_fluent_shifts_checkmark_20_regular = 61315
ic_fluent_shifts_day_20_filled = 61316
ic_fluent_shifts_day_20_regular = 61317
ic_fluent_shifts_open_20_filled = 61318
ic_fluent_shifts_open_20_regular = 61319
ic_fluent_shifts_prohibited_20_filled = 61320
ic_fluent_shifts_prohibited_20_regular = 61321
ic_fluent_shifts_question_mark_20_filled = 61322
ic_fluent_shifts_question_mark_20_regular = 61323
ic_fluent_shifts_team_20_filled = 61324
ic_fluent_shifts_team_20_regular = 61325
ic_fluent_shopping_bag_20_filled = 61326
ic_fluent_shopping_bag_20_regular = 61327
ic_fluent_shopping_bag_add_20_filled = 61328
ic_fluent_shopping_bag_add_20_regular = 61329
ic_fluent_shopping_bag_arrow_left_20_filled = 61330
ic_fluent_shopping_bag_arrow_left_20_regular = 61331
ic_fluent_shopping_bag_checkmark_20_filled = 61332
ic_fluent_shopping_bag_checkmark_20_regular = 61333
ic_fluent_shopping_bag_dismiss_20_filled = 61334
ic_fluent_shopping_bag_dismiss_20_regular = 61335
ic_fluent_shopping_bag_pause_20_filled = 61336
ic_fluent_shopping_bag_pause_20_regular = 61337
ic_fluent_shopping_bag_percent_20_filled = 61338
ic_fluent_shopping_bag_percent_20_regular = 61339
ic_fluent_shopping_bag_play_20_filled = 61340
ic_fluent_shopping_bag_play_20_regular = 61341
ic_fluent_shopping_bag_tag_20_filled = 61342
ic_fluent_shopping_bag_tag_20_regular = 61343
ic_fluent_shortpick_20_filled = 61344
ic_fluent_shortpick_20_regular = 61345
ic_fluent_showerhead_20_filled = 61346
ic_fluent_showerhead_20_regular = 61347
ic_fluent_sidebar_search_ltr_20_filled = 61348
ic_fluent_sidebar_search_ltr_20_regular = 61349
ic_fluent_sidebar_search_rtl_20_filled = 61350
ic_fluent_sidebar_search_rtl_20_regular = 61351
ic_fluent_sign_out_20_filled = 61352
ic_fluent_sign_out_20_regular = 61353
ic_fluent_signature_20_filled = 61354
ic_fluent_signature_20_regular = 61355
ic_fluent_sim_20_filled = 61356
ic_fluent_sim_20_regular = 61357
ic_fluent_skip_back_10_20_filled = 61358
ic_fluent_skip_back_10_20_regular = 61359
ic_fluent_skip_back_15_20_filled = 61360
ic_fluent_skip_back_15_20_regular = 61361
ic_fluent_skip_forward_10_20_filled = 61362
ic_fluent_skip_forward_10_20_regular = 61363
ic_fluent_skip_forward_15_20_filled = 61364
ic_fluent_skip_forward_15_20_regular = 61365
ic_fluent_skip_forward_30_20_filled = 61366
ic_fluent_skip_forward_30_20_regular = 61367
ic_fluent_skip_forward_tab_20_filled = 61368
ic_fluent_skip_forward_tab_20_regular = 61369
ic_fluent_slash_forward_20_filled = 61370
ic_fluent_slash_forward_20_regular = 61371
ic_fluent_sleep_20_filled = 61372
ic_fluent_sleep_20_regular = 61373
ic_fluent_slide_add_20_filled = 61374
ic_fluent_slide_add_20_regular = 61375
ic_fluent_slide_arrow_right_20_filled = 61376
ic_fluent_slide_arrow_right_20_regular = 61377
ic_fluent_slide_eraser_20_filled = 61378
ic_fluent_slide_eraser_20_regular = 61379
ic_fluent_slide_grid_20_filled = 61380
ic_fluent_slide_grid_20_regular = 61381
ic_fluent_slide_hide_20_filled = 61382
ic_fluent_slide_hide_20_regular = 61383
ic_fluent_slide_layout_20_filled = 61384
ic_fluent_slide_layout_20_regular = 61385
ic_fluent_slide_link_20_filled = 61386
ic_fluent_slide_link_20_regular = 61387
ic_fluent_slide_microphone_20_filled = 61388
ic_fluent_slide_microphone_20_regular = 61389
ic_fluent_slide_multiple_20_filled = 61390
ic_fluent_slide_multiple_20_regular = 61391
ic_fluent_slide_multiple_arrow_right_20_filled = 61392
ic_fluent_slide_multiple_arrow_right_20_regular = 61393
ic_fluent_slide_multiple_search_20_filled = 61394
ic_fluent_slide_multiple_search_20_regular = 61395
ic_fluent_slide_play_20_filled = 61396
ic_fluent_slide_play_20_regular = 61397
ic_fluent_slide_record_20_filled = 61398
ic_fluent_slide_record_20_regular = 61399
ic_fluent_slide_search_20_filled = 61400
ic_fluent_slide_search_20_regular = 61401
ic_fluent_slide_settings_20_filled = 61402
ic_fluent_slide_settings_20_regular = 61403
ic_fluent_slide_size_20_filled = 61404
ic_fluent_slide_size_20_regular = 61405
ic_fluent_slide_text_20_filled = 61406
ic_fluent_slide_text_20_regular = 61407
ic_fluent_slide_text_call_20_filled = 61408
ic_fluent_slide_text_call_20_regular = 61409
ic_fluent_slide_text_cursor_20_filled = 61410
ic_fluent_slide_text_cursor_20_regular = 61411
ic_fluent_slide_text_edit_20_filled = 61412
ic_fluent_slide_text_edit_20_regular = 61413
ic_fluent_slide_text_multiple_20_filled = 61414
ic_fluent_slide_text_multiple_20_regular = 61415
ic_fluent_slide_text_person_20_filled = 61416
ic_fluent_slide_text_person_20_regular = 61417
ic_fluent_slide_text_sparkle_20_filled = 61418
ic_fluent_slide_text_sparkle_20_regular = 61419
ic_fluent_slide_text_title_20_filled = 61420
ic_fluent_slide_text_title_20_regular = 61421
ic_fluent_slide_text_title_add_20_filled = 61422
ic_fluent_slide_text_title_add_20_regular = 61423
ic_fluent_slide_text_title_checkmark_20_filled = 61424
ic_fluent_slide_text_title_checkmark_20_regular = 61425
ic_fluent_slide_text_title_edit_20_filled = 61426
ic_fluent_slide_text_title_edit_20_regular = 61427
ic_fluent_slide_transition_20_filled = 61428
ic_fluent_slide_transition_20_regular = 61429
ic_fluent_smartwatch_20_filled = 61430
ic_fluent_smartwatch_20_regular = 61431
ic_fluent_smartwatch_dot_20_filled = 61432
ic_fluent_smartwatch_dot_20_regular = 61433
ic_fluent_snooze_20_filled = 61434
ic_fluent_snooze_20_regular = 61435
ic_fluent_sound_source_20_filled = 61436
ic_fluent_sound_source_20_regular = 61437
ic_fluent_sound_wave_circle_20_filled = 61438
ic_fluent_sound_wave_circle_20_regular = 61439
ic_fluent_sound_wave_circle_sparkle_20_filled = 61440
ic_fluent_sound_wave_circle_sparkle_20_regular = 61441
ic_fluent_space_3d_20_filled = 61442
ic_fluent_space_3d_20_regular = 61443
ic_fluent_spacebar_20_filled = 61444
ic_fluent_spacebar_20_regular = 61445
ic_fluent_sparkle_20_filled = 61446
ic_fluent_sparkle_20_regular = 61447
ic_fluent_sparkle_action_20_filled = 61448
ic_fluent_sparkle_action_20_regular = 61449
ic_fluent_sparkle_circle_20_filled = 61450
ic_fluent_sparkle_circle_20_regular = 61451
ic_fluent_sparkle_info_20_filled = 61452
ic_fluent_sparkle_info_20_regular = 61453
ic_fluent_spatula_spoon_20_filled = 61454
ic_fluent_spatula_spoon_20_regular = 61455
ic_fluent_speaker_0_20_filled = 61456
ic_fluent_speaker_0_20_regular = 61457
ic_fluent_speaker_1_20_filled = 61458
ic_fluent_speaker_1_20_regular = 61459
ic_fluent_speaker_2_20_filled = 61460
ic_fluent_speaker_2_20_regular = 61461
ic_fluent_speaker_bluetooth_20_filled = 61462
ic_fluent_speaker_bluetooth_20_regular = 61463
ic_fluent_speaker_box_20_filled = 61464
ic_fluent_speaker_box_20_regular = 61465
ic_fluent_speaker_edit_20_filled = 61466
ic_fluent_speaker_edit_20_regular = 61467
ic_fluent_speaker_mute_20_filled = 61468
ic_fluent_speaker_mute_20_regular = 61469
ic_fluent_speaker_off_20_filled = 61470
ic_fluent_speaker_off_20_regular = 61471
ic_fluent_speaker_settings_20_filled = 61472
ic_fluent_speaker_settings_20_regular = 61473
ic_fluent_speaker_usb_20_filled = 61474
ic_fluent_speaker_usb_20_regular = 61475
ic_fluent_spinner_ios_20_filled = 61476
ic_fluent_spinner_ios_20_regular = 61477
ic_fluent_split_hint_20_filled = 61478
ic_fluent_split_hint_20_regular = 61479
ic_fluent_split_horizontal_20_filled = 61480
ic_fluent_split_horizontal_20_regular = 61481
ic_fluent_split_vertical_20_filled = 61482
ic_fluent_split_vertical_20_regular = 61483
ic_fluent_sport_20_filled = 61484
ic_fluent_sport_20_regular = 61485
ic_fluent_sport_american_football_20_filled = 61486
ic_fluent_sport_american_football_20_regular = 61487
ic_fluent_sport_baseball_20_filled = 61488
ic_fluent_sport_baseball_20_regular = 61489
ic_fluent_sport_basketball_20_filled = 61490
ic_fluent_sport_basketball_20_regular = 61491
ic_fluent_sport_hockey_20_filled = 61492
ic_fluent_sport_hockey_20_regular = 61493
ic_fluent_sport_soccer_20_filled = 61494
ic_fluent_sport_soccer_20_regular = 61495
ic_fluent_square_20_filled = 61496
ic_fluent_square_20_regular = 61497
ic_fluent_square_add_20_filled = 61498
ic_fluent_square_add_20_regular = 61499
ic_fluent_square_arrow_forward_20_filled = 61500
ic_fluent_square_arrow_forward_20_regular = 61501
ic_fluent_square_dismiss_20_filled = 61502
ic_fluent_square_dismiss_20_regular = 61503
ic_fluent_square_dovetail_joint_20_filled = 61504
ic_fluent_square_dovetail_joint_20_regular = 61505
ic_fluent_square_eraser_20_filled = 61506
ic_fluent_square_eraser_20_regular = 61507
ic_fluent_square_hint_20_filled = 61508
ic_fluent_square_hint_20_regular = 61509
ic_fluent_square_hint_apps_20_filled = 61510
ic_fluent_square_hint_apps_20_regular = 61511
ic_fluent_square_hint_arrow_back_20_filled = 61512
ic_fluent_square_hint_arrow_back_20_regular = 61513
ic_fluent_square_hint_hexagon_20_filled = 61514
ic_fluent_square_hint_hexagon_20_regular = 61515
ic_fluent_square_hint_sparkles_20_filled = 61516
ic_fluent_square_hint_sparkles_20_regular = 61517
ic_fluent_square_multiple_20_filled = 61518
ic_fluent_square_multiple_20_regular = 61519
ic_fluent_square_shadow_20_filled = 61520
ic_fluent_square_shadow_20_regular = 61521
ic_fluent_square_text_arrow_repeat_all_20_filled = 61522
ic_fluent_square_text_arrow_repeat_all_20_regular = 61523
ic_fluent_squares_nested_20_filled = 61524
ic_fluent_squares_nested_20_regular = 61525
ic_fluent_stack_20_filled = 61526
ic_fluent_stack_20_regular = 61527
ic_fluent_stack_add_20_filled = 61528
ic_fluent_stack_add_20_regular = 61529
ic_fluent_stack_arrow_forward_20_filled = 61530
ic_fluent_stack_arrow_forward_20_regular = 61531
ic_fluent_stack_off_20_filled = 61532
ic_fluent_stack_off_20_regular = 61533
ic_fluent_stack_star_20_filled = 61534
ic_fluent_stack_star_20_regular = 61535
ic_fluent_stack_vertical_20_filled = 61536
ic_fluent_stack_vertical_20_regular = 61537
ic_fluent_star_20_filled = 61538
ic_fluent_star_20_regular = 61539
ic_fluent_star_add_20_filled = 61540
ic_fluent_star_add_20_regular = 61541
ic_fluent_star_arrow_back_20_filled = 61542
ic_fluent_star_arrow_back_20_regular = 61543
ic_fluent_star_arrow_right_end_20_filled = 61544
ic_fluent_star_arrow_right_end_20_regular = 61545
ic_fluent_star_arrow_right_start_20_filled = 61546
ic_fluent_star_arrow_right_start_20_regular = 61547
ic_fluent_star_checkmark_20_filled = 61548
ic_fluent_star_checkmark_20_regular = 61549
ic_fluent_star_dismiss_20_filled = 61550
ic_fluent_star_dismiss_20_regular = 61551
ic_fluent_star_edit_20_filled = 61552
ic_fluent_star_edit_20_regular = 61553
ic_fluent_star_emphasis_20_filled = 61554
ic_fluent_star_emphasis_20_regular = 61555
ic_fluent_star_half_20_filled = 61556
ic_fluent_star_half_20_regular = 61557
ic_fluent_star_line_horizontal_3_20_filled = 61558
ic_fluent_star_line_horizontal_3_20_regular = 61559
ic_fluent_star_off_20_filled = 61560
ic_fluent_star_off_20_regular = 61561
ic_fluent_star_one_quarter_20_filled = 61562
ic_fluent_star_one_quarter_20_regular = 61563
ic_fluent_star_prohibited_20_filled = 61564
ic_fluent_star_prohibited_20_regular = 61565
ic_fluent_star_settings_20_filled = 61566
ic_fluent_star_settings_20_regular = 61567
ic_fluent_star_three_quarter_20_filled = 61568
ic_fluent_star_three_quarter_20_regular = 61569
ic_fluent_status_20_filled = 61570
ic_fluent_status_20_regular = 61571
ic_fluent_step_20_filled = 61572
ic_fluent_step_20_regular = 61573
ic_fluent_steps_20_filled = 61574
ic_fluent_steps_20_regular = 61575
ic_fluent_stethoscope_20_filled = 61576
ic_fluent_stethoscope_20_regular = 61577
ic_fluent_sticker_20_filled = 61578
ic_fluent_sticker_20_regular = 61579
ic_fluent_sticker_add_20_filled = 61580
ic_fluent_sticker_add_20_regular = 61581
ic_fluent_stop_20_filled = 61582
ic_fluent_stop_20_regular = 61583
ic_fluent_storage_20_filled = 61584
ic_fluent_storage_20_regular = 61585
ic_fluent_store_microsoft_20_filled = 61586
ic_fluent_store_microsoft_20_regular = 61587
ic_fluent_stream_20_filled = 61588
ic_fluent_stream_20_regular = 61589
ic_fluent_stream_input_20_filled = 61590
ic_fluent_stream_input_20_regular = 61591
ic_fluent_stream_input_output_20_filled = 61592
ic_fluent_stream_input_output_20_regular = 61593
ic_fluent_stream_output_20_filled = 61594
ic_fluent_stream_output_20_regular = 61595
ic_fluent_street_sign_20_filled = 61596
ic_fluent_street_sign_20_regular = 61597
ic_fluent_style_guide_20_filled = 61598
ic_fluent_style_guide_20_regular = 61599
ic_fluent_sub_grid_20_filled = 61600
ic_fluent_sub_grid_20_regular = 61601
ic_fluent_subtitles_20_filled = 61602
ic_fluent_subtitles_20_regular = 61603
ic_fluent_subtract_20_filled = 61604
ic_fluent_subtract_20_regular = 61605
ic_fluent_subtract_circle_20_filled = 61606
ic_fluent_subtract_circle_20_regular = 61607
ic_fluent_subtract_circle_arrow_back_20_filled = 61608
ic_fluent_subtract_circle_arrow_back_20_regular = 61609
ic_fluent_subtract_circle_arrow_forward_20_filled = 61610
ic_fluent_subtract_circle_arrow_forward_20_regular = 61611
ic_fluent_subtract_parentheses_20_filled = 61612
ic_fluent_subtract_parentheses_20_regular = 61613
ic_fluent_subtract_square_20_filled = 61614
ic_fluent_subtract_square_20_regular = 61615
ic_fluent_subtract_square_multiple_20_filled = 61616
ic_fluent_subtract_square_multiple_20_regular = 61617
ic_fluent_surface_earbuds_20_filled = 61618
ic_fluent_surface_earbuds_20_regular = 61619
ic_fluent_surface_hub_20_filled = 61620
ic_fluent_surface_hub_20_regular = 61621
ic_fluent_swimming_pool_20_filled = 61622
ic_fluent_swimming_pool_20_regular = 61623
ic_fluent_swipe_down_20_filled = 61624
ic_fluent_swipe_down_20_regular = 61625
ic_fluent_swipe_right_20_filled = 61626
ic_fluent_swipe_right_20_regular = 61627
ic_fluent_swipe_up_20_filled = 61628
ic_fluent_swipe_up_20_regular = 61629
ic_fluent_symbols_20_filled = 61630
ic_fluent_symbols_20_regular = 61631
ic_fluent_sync_off_20_filled = 61632
ic_fluent_sync_off_20_regular = 61633
ic_fluent_syringe_20_filled = 61634
ic_fluent_syringe_20_regular = 61635
ic_fluent_system_20_filled = 61636
ic_fluent_system_20_regular = 61637
ic_fluent_tab_20_filled = 61638
ic_fluent_tab_20_regular = 61639
ic_fluent_tab_add_20_filled = 61640
ic_fluent_tab_add_20_regular = 61641
ic_fluent_tab_arrow_left_20_filled = 61642
ic_fluent_tab_arrow_left_20_regular = 61643
ic_fluent_tab_desktop_20_filled = 61644
ic_fluent_tab_desktop_20_regular = 61645
ic_fluent_tab_desktop_arrow_clockwise_20_filled = 61646
ic_fluent_tab_desktop_arrow_clockwise_20_regular = 61647
ic_fluent_tab_desktop_arrow_left_20_filled = 61648
ic_fluent_tab_desktop_arrow_left_20_regular = 61649
ic_fluent_tab_desktop_bottom_20_filled = 61650
ic_fluent_tab_desktop_bottom_20_regular = 61651
ic_fluent_tab_desktop_clock_20_filled = 61652
ic_fluent_tab_desktop_clock_20_regular = 61653
ic_fluent_tab_desktop_copy_20_filled = 61654
ic_fluent_tab_desktop_copy_20_regular = 61655
ic_fluent_tab_desktop_image_20_filled = 61656
ic_fluent_tab_desktop_image_20_regular = 61657
ic_fluent_tab_desktop_link_20_filled = 61658
ic_fluent_tab_desktop_link_20_regular = 61659
ic_fluent_tab_desktop_multiple_20_filled = 61660
ic_fluent_tab_desktop_multiple_20_regular = 61661
ic_fluent_tab_desktop_multiple_add_20_filled = 61662
ic_fluent_tab_desktop_multiple_add_20_regular = 61663
ic_fluent_tab_desktop_multiple_bottom_20_filled = 61664
ic_fluent_tab_desktop_multiple_bottom_20_regular = 61665
ic_fluent_tab_desktop_multiple_sparkle_20_filled = 61666
ic_fluent_tab_desktop_multiple_sparkle_20_regular = 61667
ic_fluent_tab_desktop_new_page_20_filled = 61668
ic_fluent_tab_desktop_new_page_20_regular = 61669
ic_fluent_tab_desktop_search_20_filled = 61670
ic_fluent_tab_desktop_search_20_regular = 61671
ic_fluent_tab_group_20_filled = 61672
ic_fluent_tab_group_20_regular = 61673
ic_fluent_tab_in_private_20_filled = 61674
ic_fluent_tab_in_private_20_regular = 61675
ic_fluent_tab_inprivate_account_20_filled = 61676
ic_fluent_tab_inprivate_account_20_regular = 61677
ic_fluent_tab_prohibited_20_filled = 61678
ic_fluent_tab_prohibited_20_regular = 61679
ic_fluent_tab_shield_dismiss_20_filled = 61680
ic_fluent_tab_shield_dismiss_20_regular = 61681
ic_fluent_table_20_filled = 61682
ic_fluent_table_20_regular = 61683
ic_fluent_table_add_20_filled = 61684
ic_fluent_table_add_20_regular = 61685
ic_fluent_table_alt_text_20_filled = 61686
ic_fluent_table_alt_text_20_regular = 61687
ic_fluent_table_arrow_repeat_all_20_filled = 61688
ic_fluent_table_arrow_repeat_all_20_regular = 61689
ic_fluent_table_arrow_up_20_filled = 61690
ic_fluent_table_arrow_up_20_regular = 61691
ic_fluent_table_bottom_row_20_filled = 61692
ic_fluent_table_bottom_row_20_regular = 61693
ic_fluent_table_calculator_20_filled = 61694
ic_fluent_table_calculator_20_regular = 61695
ic_fluent_table_cell_add_20_filled = 61696
ic_fluent_table_cell_add_20_regular = 61697
ic_fluent_table_cell_center_20_filled = 61698
ic_fluent_table_cell_center_20_regular = 61699
ic_fluent_table_cell_center_arrow_repeat_all_20_filled = 61700
ic_fluent_table_cell_center_arrow_repeat_all_20_regular = 61701
ic_fluent_table_cell_center_edit_20_filled = 61702
ic_fluent_table_cell_center_edit_20_regular = 61703
ic_fluent_table_cell_center_link_20_filled = 61704
ic_fluent_table_cell_center_link_20_regular = 61705
ic_fluent_table_cell_center_search_20_filled = 61706
ic_fluent_table_cell_center_search_20_regular = 61707
ic_fluent_table_cell_edit_20_filled = 61708
ic_fluent_table_cell_edit_20_regular = 61709
ic_fluent_table_cells_merge_20_filled = 61710
ic_fluent_table_cells_merge_20_regular = 61711
ic_fluent_table_cells_split_20_filled = 61712
ic_fluent_table_cells_split_20_regular = 61713
ic_fluent_table_checker_20_filled = 61714
ic_fluent_table_checker_20_regular = 61715
ic_fluent_table_column_top_bottom_20_filled = 61716
ic_fluent_table_column_top_bottom_20_regular = 61717
ic_fluent_table_column_top_bottom_arrow_repeat_all_20_filled = 61718
ic_fluent_table_column_top_bottom_arrow_repeat_all_20_regular = 61719
ic_fluent_table_column_top_bottom_edit_20_filled = 61720
ic_fluent_table_column_top_bottom_edit_20_regular = 61721
ic_fluent_table_column_top_bottom_link_20_filled = 61722
ic_fluent_table_column_top_bottom_link_20_regular = 61723
ic_fluent_table_column_top_bottom_search_20_filled = 61724
ic_fluent_table_column_top_bottom_search_20_regular = 61725
ic_fluent_table_copy_20_filled = 61726
ic_fluent_table_copy_20_regular = 61727
ic_fluent_table_cursor_20_filled = 61728
ic_fluent_table_cursor_20_regular = 61729
ic_fluent_table_delete_column_20_filled = 61730
ic_fluent_table_delete_column_20_regular = 61731
ic_fluent_table_delete_row_20_filled = 61732
ic_fluent_table_delete_row_20_regular = 61733
ic_fluent_table_dismiss_20_filled = 61734
ic_fluent_table_dismiss_20_regular = 61735
ic_fluent_table_edit_20_filled = 61736
ic_fluent_table_edit_20_regular = 61737
ic_fluent_table_freeze_column_20_filled = 61738
ic_fluent_table_freeze_column_20_regular = 61739
ic_fluent_table_freeze_column_and_row_20_filled = 61740
ic_fluent_table_freeze_column_and_row_20_regular = 61741
ic_fluent_table_freeze_row_20_filled = 61742
ic_fluent_table_freeze_row_20_regular = 61743
ic_fluent_table_image_20_filled = 61744
ic_fluent_table_image_20_regular = 61745
ic_fluent_table_insert_column_20_filled = 61746
ic_fluent_table_insert_column_20_regular = 61747
ic_fluent_table_insert_row_20_filled = 61748
ic_fluent_table_insert_row_20_regular = 61749
ic_fluent_table_lightning_20_filled = 61750
ic_fluent_table_lightning_20_regular = 61751
ic_fluent_table_link_20_filled = 61752
ic_fluent_table_link_20_regular = 61753
ic_fluent_table_lock_20_filled = 61754
ic_fluent_table_lock_20_regular = 61755
ic_fluent_table_move_above_20_filled = 61756
ic_fluent_table_move_above_20_regular = 61757
ic_fluent_table_move_below_20_filled = 61758
ic_fluent_table_move_below_20_regular = 61759
ic_fluent_table_move_left_20_filled = 61760
ic_fluent_table_move_left_20_regular = 61761
ic_fluent_table_move_right_20_filled = 61762
ic_fluent_table_move_right_20_regular = 61763
ic_fluent_table_multiple_20_filled = 61764
ic_fluent_table_multiple_20_regular = 61765
ic_fluent_table_offset_20_filled = 61766
ic_fluent_table_offset_20_regular = 61767
ic_fluent_table_offset_add_20_filled = 61768
ic_fluent_table_offset_add_20_regular = 61769
ic_fluent_table_offset_less_than_or_equal_to_20_filled = 61770
ic_fluent_table_offset_less_than_or_equal_to_20_regular = 61771
ic_fluent_table_offset_settings_20_filled = 61772
ic_fluent_table_offset_settings_20_regular = 61773
ic_fluent_table_resize_column_20_filled = 61774
ic_fluent_table_resize_column_20_regular = 61775
ic_fluent_table_resize_row_20_filled = 61776
ic_fluent_table_resize_row_20_regular = 61777
ic_fluent_table_search_20_filled = 61778
ic_fluent_table_search_20_regular = 61779
ic_fluent_table_settings_20_filled = 61780
ic_fluent_table_settings_20_regular = 61781
ic_fluent_table_simple_20_filled = 61782
ic_fluent_table_simple_20_regular = 61783
ic_fluent_table_simple_checkmark_20_filled = 61784
ic_fluent_table_simple_checkmark_20_regular = 61785
ic_fluent_table_simple_exclude_20_filled = 61786
ic_fluent_table_simple_exclude_20_regular = 61787
ic_fluent_table_simple_include_20_filled = 61788
ic_fluent_table_simple_include_20_regular = 61789
ic_fluent_table_simple_multiple_20_filled = 61790
ic_fluent_table_simple_multiple_20_regular = 61791
ic_fluent_table_sparkle_20_filled = 61792
ic_fluent_table_sparkle_20_regular = 61793
ic_fluent_table_split_20_filled = 61794
ic_fluent_table_split_20_regular = 61795
ic_fluent_table_stack_above_20_filled = 61796
ic_fluent_table_stack_above_20_regular = 61797
ic_fluent_table_stack_below_20_filled = 61798
ic_fluent_table_stack_below_20_regular = 61799
ic_fluent_table_stack_left_20_filled = 61800
ic_fluent_table_stack_left_20_regular = 61801
ic_fluent_table_stack_right_20_filled = 61802
ic_fluent_table_stack_right_20_regular = 61803
ic_fluent_table_switch_20_filled = 61804
ic_fluent_table_switch_20_regular = 61805
ic_fluent_tablet_20_filled = 61806
ic_fluent_tablet_20_regular = 61807
ic_fluent_tablet_laptop_20_filled = 61808
ic_fluent_tablet_laptop_20_regular = 61809
ic_fluent_tablet_speaker_20_filled = 61810
ic_fluent_tablet_speaker_20_regular = 61811
ic_fluent_tabs_20_filled = 61812
ic_fluent_tabs_20_regular = 61813
ic_fluent_tag_20_filled = 61814
ic_fluent_tag_20_regular = 61815
ic_fluent_tag_add_20_filled = 61816
ic_fluent_tag_add_20_regular = 61817
ic_fluent_tag_circle_20_filled = 61818
ic_fluent_tag_circle_20_regular = 61819
ic_fluent_tag_dismiss_20_filled = 61820
ic_fluent_tag_dismiss_20_regular = 61821
ic_fluent_tag_edit_20_filled = 61822
ic_fluent_tag_edit_20_regular = 61823
ic_fluent_tag_error_20_filled = 61824
ic_fluent_tag_error_20_regular = 61825
ic_fluent_tag_lock_20_filled = 61826
ic_fluent_tag_lock_20_regular = 61827
ic_fluent_tag_lock_accent_20_filled = 61828
ic_fluent_tag_multiple_20_filled = 61829
ic_fluent_tag_multiple_20_regular = 61830
ic_fluent_tag_off_20_filled = 61831
ic_fluent_tag_off_20_regular = 61832
ic_fluent_tag_percent_20_filled = 61833
ic_fluent_tag_percent_20_regular = 61834
ic_fluent_tag_question_mark_20_filled = 61835
ic_fluent_tag_question_mark_20_regular = 61836
ic_fluent_tag_reset_20_filled = 61837
ic_fluent_tag_reset_20_regular = 61838
ic_fluent_tag_search_20_filled = 61839
ic_fluent_tag_search_20_regular = 61840
ic_fluent_tap_double_20_filled = 61841
ic_fluent_tap_double_20_regular = 61842
ic_fluent_tap_single_20_filled = 61843
ic_fluent_tap_single_20_regular = 61844
ic_fluent_target_20_filled = 61845
ic_fluent_target_20_regular = 61846
ic_fluent_target_add_20_filled = 61847
ic_fluent_target_add_20_regular = 61848
ic_fluent_target_arrow_20_filled = 61849
ic_fluent_target_arrow_20_regular = 61850
ic_fluent_target_dismiss_20_filled = 61851
ic_fluent_target_dismiss_20_regular = 61852
ic_fluent_target_edit_20_filled = 61853
ic_fluent_target_edit_20_regular = 61854
ic_fluent_target_sparkle_20_filled = 61855
ic_fluent_target_sparkle_20_regular = 61856
ic_fluent_task_list_add_20_filled = 61857
ic_fluent_task_list_add_20_regular = 61858
ic_fluent_task_list_ltr_20_filled = 61859
ic_fluent_task_list_ltr_20_regular = 61860
ic_fluent_task_list_rtl_20_filled = 61861
ic_fluent_task_list_rtl_20_regular = 61862
ic_fluent_task_list_square_add_20_filled = 61863
ic_fluent_task_list_square_add_20_regular = 61864
ic_fluent_task_list_square_database_20_filled = 61865
ic_fluent_task_list_square_database_20_regular = 61866
ic_fluent_task_list_square_ltr_20_filled = 61867
ic_fluent_task_list_square_ltr_20_regular = 61868
ic_fluent_task_list_square_person_20_filled = 61869
ic_fluent_task_list_square_person_20_regular = 61870
ic_fluent_task_list_square_rtl_20_filled = 61871
ic_fluent_task_list_square_rtl_20_regular = 61872
ic_fluent_task_list_square_settings_20_filled = 61873
ic_fluent_task_list_square_settings_20_regular = 61874
ic_fluent_task_list_square_sparkle_20_filled = 61875
ic_fluent_task_list_square_sparkle_20_regular = 61876
ic_fluent_tasks_app_20_filled = 61877
ic_fluent_tasks_app_20_regular = 61878
ic_fluent_teaching_20_filled = 61879
ic_fluent_teaching_20_regular = 61880
ic_fluent_teardrop_bottom_right_20_filled = 61881
ic_fluent_teardrop_bottom_right_20_regular = 61882
ic_fluent_teddy_20_filled = 61883
ic_fluent_teddy_20_regular = 61884
ic_fluent_temperature_20_filled = 61885
ic_fluent_temperature_20_regular = 61886
ic_fluent_temperature_degree_celsius_20_filled = 61887
ic_fluent_temperature_degree_celsius_20_regular = 61888
ic_fluent_temperature_degree_fahrenheit_20_filled = 61889
ic_fluent_temperature_degree_fahrenheit_20_regular = 61890
ic_fluent_tent_20_filled = 61891
ic_fluent_tent_20_regular = 61892
ic_fluent_tetris_app_20_filled = 61893
ic_fluent_tetris_app_20_regular = 61894
ic_fluent_text_add_20_filled = 61895
ic_fluent_text_add_20_regular = 61896
ic_fluent_text_add_space_after_20_filled = 61897
ic_fluent_text_add_space_after_20_regular = 61898
ic_fluent_text_add_space_before_20_filled = 61899
ic_fluent_text_add_space_before_20_regular = 61900
ic_fluent_text_add_t_20_filled = 61901
ic_fluent_text_add_t_20_regular = 61902
ic_fluent_text_align_center_20_filled = 61903
ic_fluent_text_align_center_20_regular = 61904
ic_fluent_text_align_center_rotate_270_20_filled = 61905
ic_fluent_text_align_center_rotate_270_20_regular = 61906
ic_fluent_text_align_center_rotate_90_20_filled = 61907
ic_fluent_text_align_center_rotate_90_20_regular = 61908
ic_fluent_text_align_distributed_20_filled = 61909
ic_fluent_text_align_distributed_20_regular = 61910
ic_fluent_text_align_distributed_evenly_20_filled = 61911
ic_fluent_text_align_distributed_evenly_20_regular = 61912
ic_fluent_text_align_distributed_vertical_20_filled = 61913
ic_fluent_text_align_distributed_vertical_20_regular = 61914
ic_fluent_text_align_justify_20_filled = 61915
ic_fluent_text_align_justify_20_regular = 61916
ic_fluent_text_align_justify_low_20_filled = 61917
ic_fluent_text_align_justify_low_20_regular = 61918
ic_fluent_text_align_justify_low_90_20_filled = 61919
ic_fluent_text_align_justify_low_90_20_regular = 61920
ic_fluent_text_align_justify_low_rotate_270_20_filled = 61921
ic_fluent_text_align_justify_low_rotate_270_20_regular = 61922
ic_fluent_text_align_justify_low_rotate_90_20_filled = 61923
ic_fluent_text_align_justify_low_rotate_90_20_regular = 61924
ic_fluent_text_align_justify_rotate_270_20_filled = 61925
ic_fluent_text_align_justify_rotate_270_20_regular = 61926
ic_fluent_text_align_justify_rotate_90_20_filled = 61927
ic_fluent_text_align_justify_rotate_90_20_regular = 61928
ic_fluent_text_align_left_20_filled = 61929
ic_fluent_text_align_left_20_regular = 61930
ic_fluent_text_align_left_rotate_270_20_filled = 61931
ic_fluent_text_align_left_rotate_270_20_regular = 61932
ic_fluent_text_align_left_rotate_90_20_filled = 61933
ic_fluent_text_align_left_rotate_90_20_regular = 61934
ic_fluent_text_align_right_20_filled = 61935
ic_fluent_text_align_right_20_regular = 61936
ic_fluent_text_align_right_rotate_270_20_filled = 61937
ic_fluent_text_align_right_rotate_270_20_regular = 61938
ic_fluent_text_align_right_rotate_90_20_filled = 61939
ic_fluent_text_align_right_rotate_90_20_regular = 61940
ic_fluent_text_arrow_down_right_column_20_filled = 61941
ic_fluent_text_arrow_down_right_column_20_regular = 61942
ic_fluent_text_asterisk_20_filled = 61943
ic_fluent_text_asterisk_20_regular = 61944
ic_fluent_text_baseline_20_filled = 61945
ic_fluent_text_baseline_20_regular = 61946
ic_fluent_text_bold_20_filled = 61947
ic_fluent_text_bold_20_regular = 61948
ic_fluent_text_box_settings_20_filled = 61949
ic_fluent_text_box_settings_20_regular = 61950
ic_fluent_text_bullet_list_20_filled = 61951
ic_fluent_text_bullet_list_20_regular = 61952
ic_fluent_text_bullet_list_90_20_filled = 61953
ic_fluent_text_bullet_list_90_20_regular = 61954
ic_fluent_text_bullet_list_add_20_filled = 61955
ic_fluent_text_bullet_list_add_20_regular = 61956
ic_fluent_text_bullet_list_checkmark_20_filled = 61957
ic_fluent_text_bullet_list_checkmark_20_regular = 61958
ic_fluent_text_bullet_list_dismiss_20_filled = 61959
ic_fluent_text_bullet_list_dismiss_20_regular = 61960
ic_fluent_text_bullet_list_ltr_20_filled = 61961
ic_fluent_text_bullet_list_ltr_20_regular = 61962
ic_fluent_text_bullet_list_ltr_90_20_filled = 61963
ic_fluent_text_bullet_list_ltr_90_20_regular = 61964
ic_fluent_text_bullet_list_rtl_20_filled = 61965
ic_fluent_text_bullet_list_rtl_20_regular = 61966
ic_fluent_text_bullet_list_rtl_90_20_filled = 61967
ic_fluent_text_bullet_list_rtl_90_20_regular = 61968
ic_fluent_text_bullet_list_square_20_filled = 61969
ic_fluent_text_bullet_list_square_20_regular = 61970
ic_fluent_text_bullet_list_square_clock_20_filled = 61971
ic_fluent_text_bullet_list_square_clock_20_regular = 61972
ic_fluent_text_bullet_list_square_edit_20_filled = 61973
ic_fluent_text_bullet_list_square_edit_20_regular = 61974
ic_fluent_text_bullet_list_square_person_20_filled = 61975
ic_fluent_text_bullet_list_square_person_20_regular = 61976
ic_fluent_text_bullet_list_square_search_20_filled = 61977
ic_fluent_text_bullet_list_square_search_20_regular = 61978
ic_fluent_text_bullet_list_square_settings_20_filled = 61979
ic_fluent_text_bullet_list_square_settings_20_regular = 61980
ic_fluent_text_bullet_list_square_shield_20_filled = 61981
ic_fluent_text_bullet_list_square_shield_20_regular = 61982
ic_fluent_text_bullet_list_square_sparkle_20_filled = 61983
ic_fluent_text_bullet_list_square_sparkle_20_regular = 61984
ic_fluent_text_bullet_list_square_toolbox_20_filled = 61985
ic_fluent_text_bullet_list_square_toolbox_20_regular = 61986
ic_fluent_text_bullet_list_square_warning_20_filled = 61987
ic_fluent_text_bullet_list_square_warning_20_regular = 61988
ic_fluent_text_bullet_list_tree_20_filled = 61989
ic_fluent_text_bullet_list_tree_20_regular = 61990
ic_fluent_text_case_lowercase_20_filled = 61991
ic_fluent_text_case_lowercase_20_regular = 61992
ic_fluent_text_case_title_20_filled = 61993
ic_fluent_text_case_title_20_regular = 61994
ic_fluent_text_case_uppercase_20_filled = 61995
ic_fluent_text_case_uppercase_20_regular = 61996
ic_fluent_text_change_case_20_filled = 61997
ic_fluent_text_change_case_20_regular = 61998
ic_fluent_text_clear_formatting_20_filled = 61999
ic_fluent_text_clear_formatting_20_regular = 62000
ic_fluent_text_collapse_20_filled = 62001
ic_fluent_text_collapse_20_regular = 62002
ic_fluent_text_color_20_filled = 62003
ic_fluent_text_color_20_regular = 62004
ic_fluent_text_color_accent_20_filled = 62005
ic_fluent_text_column_one_20_filled = 62006
ic_fluent_text_column_one_20_regular = 62007
ic_fluent_text_column_one_narrow_20_filled = 62008
ic_fluent_text_column_one_narrow_20_regular = 62009
ic_fluent_text_column_one_semi_narrow_20_filled = 62010
ic_fluent_text_column_one_semi_narrow_20_regular = 62011
ic_fluent_text_column_one_wide_20_filled = 62012
ic_fluent_text_column_one_wide_20_regular = 62013
ic_fluent_text_column_one_wide_lightning_20_filled = 62014
ic_fluent_text_column_one_wide_lightning_20_regular = 62015
ic_fluent_text_column_three_20_filled = 62016
ic_fluent_text_column_three_20_regular = 62017
ic_fluent_text_column_two_20_filled = 62018
ic_fluent_text_column_two_20_regular = 62019
ic_fluent_text_column_two_left_20_filled = 62020
ic_fluent_text_column_two_left_20_regular = 62021
ic_fluent_text_column_two_right_20_filled = 62022
ic_fluent_text_column_two_right_20_regular = 62023
ic_fluent_text_column_wide_20_filled = 62024
ic_fluent_text_column_wide_20_regular = 62025
ic_fluent_text_continuous_20_filled = 62026
ic_fluent_text_continuous_20_regular = 62027
ic_fluent_text_density_20_filled = 62028
ic_fluent_text_density_20_regular = 62029
ic_fluent_text_description_20_filled = 62030
ic_fluent_text_description_20_regular = 62031
ic_fluent_text_description_ltr_20_filled = 62032
ic_fluent_text_description_ltr_20_regular = 62033
ic_fluent_text_description_rtl_20_filled = 62034
ic_fluent_text_description_rtl_20_regular = 62035
ic_fluent_text_direction_horizontal_left_20_filled = 62036
ic_fluent_text_direction_horizontal_left_20_regular = 62037
ic_fluent_text_direction_horizontal_ltr_20_filled = 62038
ic_fluent_text_direction_horizontal_ltr_20_regular = 62039
ic_fluent_text_direction_horizontal_right_20_filled = 62040
ic_fluent_text_direction_horizontal_right_20_regular = 62041
ic_fluent_text_direction_horizontal_rtl_20_filled = 62042
ic_fluent_text_direction_horizontal_rtl_20_regular = 62043
ic_fluent_text_direction_rotate_270_right_20_filled = 62044
ic_fluent_text_direction_rotate_270_right_20_regular = 62045
ic_fluent_text_direction_rotate_315_right_20_filled = 62046
ic_fluent_text_direction_rotate_315_right_20_regular = 62047
ic_fluent_text_direction_rotate_45_right_20_filled = 62048
ic_fluent_text_direction_rotate_45_right_20_regular = 62049
ic_fluent_text_direction_rotate_90_left_20_filled = 62050
ic_fluent_text_direction_rotate_90_left_20_regular = 62051
ic_fluent_text_direction_rotate_90_ltr_20_filled = 62052
ic_fluent_text_direction_rotate_90_ltr_20_regular = 62053
ic_fluent_text_direction_rotate_90_right_20_filled = 62054
ic_fluent_text_direction_rotate_90_right_20_regular = 62055
ic_fluent_text_direction_rotate_90_rtl_20_filled = 62056
ic_fluent_text_direction_rotate_90_rtl_20_regular = 62057
ic_fluent_text_direction_vertical_20_filled = 62058
ic_fluent_text_direction_vertical_20_regular = 62059
ic_fluent_text_edit_style_20_filled = 62060
ic_fluent_text_edit_style_20_regular = 62061
ic_fluent_text_effects_20_filled = 62062
ic_fluent_text_effects_20_regular = 62063
ic_fluent_text_effects_sparkle_20_filled = 62064
ic_fluent_text_effects_sparkle_20_regular = 62065
ic_fluent_text_expand_20_filled = 62066
ic_fluent_text_expand_20_regular = 62067
ic_fluent_text_field_20_filled = 62068
ic_fluent_text_field_20_regular = 62069
ic_fluent_text_first_line_20_filled = 62070
ic_fluent_text_first_line_20_regular = 62071
ic_fluent_text_font_20_filled = 62072
ic_fluent_text_font_20_regular = 62073
ic_fluent_text_font_info_20_filled = 62074
ic_fluent_text_font_info_20_regular = 62075
ic_fluent_text_font_size_20_filled = 62076
ic_fluent_text_font_size_20_regular = 62077
ic_fluent_text_footnote_20_filled = 62078
ic_fluent_text_footnote_20_regular = 62079
ic_fluent_text_grammar_arrow_left_20_filled = 62080
ic_fluent_text_grammar_arrow_left_20_regular = 62081
ic_fluent_text_grammar_arrow_right_20_filled = 62082
ic_fluent_text_grammar_arrow_right_20_regular = 62083
ic_fluent_text_grammar_checkmark_20_filled = 62084
ic_fluent_text_grammar_checkmark_20_regular = 62085
ic_fluent_text_grammar_dismiss_20_filled = 62086
ic_fluent_text_grammar_dismiss_20_regular = 62087
ic_fluent_text_grammar_error_20_filled = 62088
ic_fluent_text_grammar_error_20_regular = 62089
ic_fluent_text_grammar_lightning_20_filled = 62090
ic_fluent_text_grammar_lightning_20_regular = 62091
ic_fluent_text_grammar_settings_20_filled = 62092
ic_fluent_text_grammar_settings_20_regular = 62093
ic_fluent_text_grammar_wand_20_filled = 62094
ic_fluent_text_grammar_wand_20_regular = 62095
ic_fluent_text_hanging_20_filled = 62096
ic_fluent_text_hanging_20_regular = 62097
ic_fluent_text_header_1_20_filled = 62098
ic_fluent_text_header_1_20_regular = 62099
ic_fluent_text_header_1_lines_20_filled = 62100
ic_fluent_text_header_1_lines_20_regular = 62101
ic_fluent_text_header_1_lines_caret_20_filled = 62102
ic_fluent_text_header_1_lines_caret_20_regular = 62103
ic_fluent_text_header_2_20_filled = 62104
ic_fluent_text_header_2_20_regular = 62105
ic_fluent_text_header_2_lines_20_filled = 62106
ic_fluent_text_header_2_lines_20_regular = 62107
ic_fluent_text_header_2_lines_caret_20_filled = 62108
ic_fluent_text_header_2_lines_caret_20_regular = 62109
ic_fluent_text_header_3_20_filled = 62110
ic_fluent_text_header_3_20_regular = 62111
ic_fluent_text_header_3_lines_20_filled = 62112
ic_fluent_text_header_3_lines_20_regular = 62113
ic_fluent_text_header_3_lines_caret_20_filled = 62114
ic_fluent_text_header_3_lines_caret_20_regular = 62115
ic_fluent_text_header_4_20_filled = 62116
ic_fluent_text_header_4_20_regular = 62117
ic_fluent_text_header_4_lines_caret_20_filled = 62118
ic_fluent_text_header_4_lines_caret_20_regular = 62119
ic_fluent_text_header_5_20_filled = 62120
ic_fluent_text_header_5_20_regular = 62121
ic_fluent_text_header_6_20_filled = 62122
ic_fluent_text_header_6_20_regular = 62123
ic_fluent_text_indent_decrease_20_filled = 62124
ic_fluent_text_indent_decrease_20_regular = 62125
ic_fluent_text_indent_decrease_ltr_20_filled = 62126
ic_fluent_text_indent_decrease_ltr_20_regular = 62127
ic_fluent_text_indent_decrease_ltr_90_20_filled = 62128
ic_fluent_text_indent_decrease_ltr_90_20_regular = 62129
ic_fluent_text_indent_decrease_ltr_rotate_270_20_filled = 62130
ic_fluent_text_indent_decrease_ltr_rotate_270_20_regular = 62131
ic_fluent_text_indent_decrease_rotate_270_20_filled = 62132
ic_fluent_text_indent_decrease_rotate_270_20_regular = 62133
ic_fluent_text_indent_decrease_rotate_90_20_filled = 62134
ic_fluent_text_indent_decrease_rotate_90_20_regular = 62135
ic_fluent_text_indent_decrease_rtl_20_filled = 62136
ic_fluent_text_indent_decrease_rtl_20_regular = 62137
ic_fluent_text_indent_decrease_rtl_90_20_filled = 62138
ic_fluent_text_indent_decrease_rtl_90_20_regular = 62139
ic_fluent_text_indent_decrease_rtl_rotate_270_20_filled = 62140
ic_fluent_text_indent_decrease_rtl_rotate_270_20_regular = 62141
ic_fluent_text_indent_increase_20_filled = 62142
ic_fluent_text_indent_increase_20_regular = 62143
ic_fluent_text_indent_increase_ltr_20_filled = 62144
ic_fluent_text_indent_increase_ltr_20_regular = 62145
ic_fluent_text_indent_increase_ltr_90_20_filled = 62146
ic_fluent_text_indent_increase_ltr_90_20_regular = 62147
ic_fluent_text_indent_increase_ltr_rotate_270_20_filled = 62148
ic_fluent_text_indent_increase_ltr_rotate_270_20_regular = 62149
ic_fluent_text_indent_increase_rotate_270_20_filled = 62150
ic_fluent_text_indent_increase_rotate_270_20_regular = 62151
ic_fluent_text_indent_increase_rotate_90_20_filled = 62152
ic_fluent_text_indent_increase_rotate_90_20_regular = 62153
ic_fluent_text_indent_increase_rtl_20_filled = 62154
ic_fluent_text_indent_increase_rtl_20_regular = 62155
ic_fluent_text_indent_increase_rtl_90_20_filled = 62156
ic_fluent_text_indent_increase_rtl_90_20_regular = 62157
ic_fluent_text_indent_increase_rtl_rotate_270_20_filled = 62158
ic_fluent_text_indent_increase_rtl_rotate_270_20_regular = 62159
ic_fluent_text_italic_20_filled = 62160
ic_fluent_text_italic_20_regular = 62161
ic_fluent_text_line_spacing_20_filled = 62162
ic_fluent_text_line_spacing_20_regular = 62163
ic_fluent_text_list_abc_lowercase_ltr_20_filled = 62164
ic_fluent_text_list_abc_lowercase_ltr_20_regular = 62165
ic_fluent_text_list_abc_uppercase_ltr_20_filled = 62166
ic_fluent_text_list_abc_uppercase_ltr_20_regular = 62167
ic_fluent_text_list_roman_numeral_lowercase_20_filled = 62168
ic_fluent_text_list_roman_numeral_lowercase_20_regular = 62169
ic_fluent_text_list_roman_numeral_uppercase_20_filled = 62170
ic_fluent_text_list_roman_numeral_uppercase_20_regular = 62171
ic_fluent_text_more_20_filled = 62172
ic_fluent_text_more_20_regular = 62173
ic_fluent_text_number_format_20_filled = 62174
ic_fluent_text_number_format_20_regular = 62175
ic_fluent_text_number_list_ltr_20_filled = 62176
ic_fluent_text_number_list_ltr_20_regular = 62177
ic_fluent_text_number_list_ltr_90_20_filled = 62178
ic_fluent_text_number_list_ltr_90_20_regular = 62179
ic_fluent_text_number_list_ltr_rotate_270_20_filled = 62180
ic_fluent_text_number_list_ltr_rotate_270_20_regular = 62181
ic_fluent_text_number_list_rotate_270_20_filled = 62182
ic_fluent_text_number_list_rotate_270_20_regular = 62183
ic_fluent_text_number_list_rotate_90_20_filled = 62184
ic_fluent_text_number_list_rotate_90_20_regular = 62185
ic_fluent_text_number_list_rtl_20_filled = 62186
ic_fluent_text_number_list_rtl_20_regular = 62187
ic_fluent_text_number_list_rtl_90_20_filled = 62188
ic_fluent_text_number_list_rtl_90_20_regular = 62189
ic_fluent_text_number_list_rtl_rotate_270_20_filled = 62190
ic_fluent_text_number_list_rtl_rotate_270_20_regular = 62191
ic_fluent_text_paragraph_20_filled = 62192
ic_fluent_text_paragraph_20_regular = 62193
ic_fluent_text_paragraph_direction_20_filled = 62194
ic_fluent_text_paragraph_direction_20_regular = 62195
ic_fluent_text_paragraph_direction_left_20_filled = 62196
ic_fluent_text_paragraph_direction_left_20_regular = 62197
ic_fluent_text_paragraph_direction_right_20_filled = 62198
ic_fluent_text_paragraph_direction_right_20_regular = 62199
ic_fluent_text_percent_20_filled = 62200
ic_fluent_text_percent_20_regular = 62201
ic_fluent_text_period_asterisk_20_filled = 62202
ic_fluent_text_period_asterisk_20_regular = 62203
ic_fluent_text_position_behind_20_filled = 62204
ic_fluent_text_position_behind_20_regular = 62205
ic_fluent_text_position_front_20_filled = 62206
ic_fluent_text_position_front_20_regular = 62207
ic_fluent_text_position_line_20_filled = 62208
ic_fluent_text_position_line_20_regular = 62209
ic_fluent_text_position_square_20_filled = 62210
ic_fluent_text_position_square_20_regular = 62211
ic_fluent_text_position_square_left_20_filled = 62212
ic_fluent_text_position_square_left_20_regular = 62213
ic_fluent_text_position_square_right_20_filled = 62214
ic_fluent_text_position_square_right_20_regular = 62215
ic_fluent_text_position_through_20_filled = 62216
ic_fluent_text_position_through_20_regular = 62217
ic_fluent_text_position_tight_20_filled = 62218
ic_fluent_text_position_tight_20_regular = 62219
ic_fluent_text_position_top_bottom_20_filled = 62220
ic_fluent_text_position_top_bottom_20_regular = 62221
ic_fluent_text_proofing_tools_20_filled = 62222
ic_fluent_text_proofing_tools_20_regular = 62223
ic_fluent_text_quote_20_filled = 62224
ic_fluent_text_quote_20_regular = 62225
ic_fluent_text_sort_ascending_20_filled = 62226
ic_fluent_text_sort_ascending_20_regular = 62227
ic_fluent_text_sort_descending_20_filled = 62228
ic_fluent_text_sort_descending_20_regular = 62229
ic_fluent_text_strikethrough_20_filled = 62230
ic_fluent_text_strikethrough_20_regular = 62231
ic_fluent_text_subscript_20_filled = 62232
ic_fluent_text_subscript_20_regular = 62233
ic_fluent_text_superscript_20_filled = 62234
ic_fluent_text_superscript_20_regular = 62235
ic_fluent_text_t_20_filled = 62236
ic_fluent_text_t_20_regular = 62237
ic_fluent_text_underline_20_filled = 62238
ic_fluent_text_underline_20_regular = 62239
ic_fluent_text_underline_character_u_20_filled = 62240
ic_fluent_text_underline_character_u_20_regular = 62241
ic_fluent_text_underline_double_20_filled = 62242
ic_fluent_text_underline_double_20_regular = 62243
ic_fluent_text_whole_word_20_filled = 62244
ic_fluent_text_whole_word_20_regular = 62245
ic_fluent_text_word_count_20_filled = 62246
ic_fluent_text_word_count_20_regular = 62247
ic_fluent_text_wrap_20_filled = 62248
ic_fluent_text_wrap_20_regular = 62249
ic_fluent_text_wrap_off_20_filled = 62250
ic_fluent_text_wrap_off_20_regular = 62251
ic_fluent_textbox_20_filled = 62252
ic_fluent_textbox_20_regular = 62253
ic_fluent_textbox_align_bottom_20_filled = 62254
ic_fluent_textbox_align_bottom_20_regular = 62255
ic_fluent_textbox_align_bottom_center_20_filled = 62256
ic_fluent_textbox_align_bottom_center_20_regular = 62257
ic_fluent_textbox_align_bottom_left_20_filled = 62258
ic_fluent_textbox_align_bottom_left_20_regular = 62259
ic_fluent_textbox_align_bottom_right_20_filled = 62260
ic_fluent_textbox_align_bottom_right_20_regular = 62261
ic_fluent_textbox_align_bottom_rotate_90_20_filled = 62262
ic_fluent_textbox_align_bottom_rotate_90_20_regular = 62263
ic_fluent_textbox_align_center_20_filled = 62264
ic_fluent_textbox_align_center_20_regular = 62265
ic_fluent_textbox_align_middle_20_filled = 62266
ic_fluent_textbox_align_middle_20_regular = 62267
ic_fluent_textbox_align_middle_left_20_filled = 62268
ic_fluent_textbox_align_middle_left_20_regular = 62269
ic_fluent_textbox_align_middle_right_20_filled = 62270
ic_fluent_textbox_align_middle_right_20_regular = 62271
ic_fluent_textbox_align_middle_rotate_90_20_filled = 62272
ic_fluent_textbox_align_middle_rotate_90_20_regular = 62273
ic_fluent_textbox_align_top_20_filled = 62274
ic_fluent_textbox_align_top_20_regular = 62275
ic_fluent_textbox_align_top_center_20_filled = 62276
ic_fluent_textbox_align_top_center_20_regular = 62277
ic_fluent_textbox_align_top_left_20_filled = 62278
ic_fluent_textbox_align_top_left_20_regular = 62279
ic_fluent_textbox_align_top_right_20_filled = 62280
ic_fluent_textbox_align_top_right_20_regular = 62281
ic_fluent_textbox_align_top_rotate_90_20_filled = 62282
ic_fluent_textbox_align_top_rotate_90_20_regular = 62283
ic_fluent_textbox_checkmark_20_filled = 62284
ic_fluent_textbox_checkmark_20_regular = 62285
ic_fluent_textbox_more_20_filled = 62286
ic_fluent_textbox_more_20_regular = 62287
ic_fluent_textbox_rotate_90_20_filled = 62288
ic_fluent_textbox_rotate_90_20_regular = 62289
ic_fluent_textbox_settings_20_filled = 62290
ic_fluent_textbox_settings_20_regular = 62291
ic_fluent_thinking_20_filled = 62292
ic_fluent_thinking_20_regular = 62293
ic_fluent_thumb_dislike_20_filled = 62294
ic_fluent_thumb_dislike_20_regular = 62295
ic_fluent_thumb_like_20_filled = 62296
ic_fluent_thumb_like_20_regular = 62297
ic_fluent_thumb_like_dislike_20_filled = 62298
ic_fluent_thumb_like_dislike_20_regular = 62299
ic_fluent_ticket_diagonal_20_filled = 62300
ic_fluent_ticket_diagonal_20_regular = 62301
ic_fluent_ticket_horizontal_20_filled = 62302
ic_fluent_ticket_horizontal_20_regular = 62303
ic_fluent_time_and_weather_20_filled = 62304
ic_fluent_time_and_weather_20_regular = 62305
ic_fluent_time_picker_20_filled = 62306
ic_fluent_time_picker_20_regular = 62307
ic_fluent_timeline_20_filled = 62308
ic_fluent_timeline_20_regular = 62309
ic_fluent_timer_10_20_filled = 62310
ic_fluent_timer_10_20_regular = 62311
ic_fluent_timer_2_20_filled = 62312
ic_fluent_timer_2_20_regular = 62313
ic_fluent_timer_20_filled = 62314
ic_fluent_timer_20_regular = 62315
ic_fluent_timer_3_20_filled = 62316
ic_fluent_timer_3_20_regular = 62317
ic_fluent_timer_off_20_filled = 62318
ic_fluent_timer_off_20_regular = 62319
ic_fluent_toggle_left_20_filled = 62320
ic_fluent_toggle_left_20_regular = 62321
ic_fluent_toggle_multiple_20_filled = 62322
ic_fluent_toggle_multiple_20_regular = 62323
ic_fluent_toggle_right_20_filled = 62324
ic_fluent_toggle_right_20_regular = 62325
ic_fluent_toolbox_20_filled = 62326
ic_fluent_toolbox_20_regular = 62327
ic_fluent_tooltip_quote_20_filled = 62328
ic_fluent_tooltip_quote_20_regular = 62329
ic_fluent_tooltip_quote_off_20_filled = 62330
ic_fluent_tooltip_quote_off_20_regular = 62331
ic_fluent_top_speed_20_filled = 62332
ic_fluent_top_speed_20_regular = 62333
ic_fluent_translate_20_filled = 62334
ic_fluent_translate_20_regular = 62335
ic_fluent_translate_auto_20_filled = 62336
ic_fluent_translate_auto_20_regular = 62337
ic_fluent_translate_off_20_filled = 62338
ic_fluent_translate_off_20_regular = 62339
ic_fluent_transmission_20_filled = 62340
ic_fluent_transmission_20_regular = 62341
ic_fluent_transparency_square_20_filled = 62342
ic_fluent_transparency_square_20_regular = 62343
ic_fluent_tray_item_add_20_filled = 62344
ic_fluent_tray_item_add_20_regular = 62345
ic_fluent_tray_item_remove_20_filled = 62346
ic_fluent_tray_item_remove_20_regular = 62347
ic_fluent_tree_deciduous_20_filled = 62348
ic_fluent_tree_deciduous_20_regular = 62349
ic_fluent_tree_evergreen_20_filled = 62350
ic_fluent_tree_evergreen_20_regular = 62351
ic_fluent_triangle_20_filled = 62352
ic_fluent_triangle_20_regular = 62353
ic_fluent_triangle_down_20_filled = 62354
ic_fluent_triangle_down_20_regular = 62355
ic_fluent_triangle_left_20_filled = 62356
ic_fluent_triangle_left_20_regular = 62357
ic_fluent_triangle_right_20_filled = 62358
ic_fluent_triangle_right_20_regular = 62359
ic_fluent_triangle_up_20_filled = 62360
ic_fluent_triangle_up_20_regular = 62361
ic_fluent_trophy_20_filled = 62362
ic_fluent_trophy_20_regular = 62363
ic_fluent_trophy_lock_20_filled = 62364
ic_fluent_trophy_lock_20_regular = 62365
ic_fluent_trophy_off_20_filled = 62366
ic_fluent_trophy_off_20_regular = 62367
ic_fluent_tv_20_filled = 62368
ic_fluent_tv_20_regular = 62369
ic_fluent_tv_arrow_right_20_filled = 62370
ic_fluent_tv_arrow_right_20_regular = 62371
ic_fluent_tv_usb_20_filled = 62372
ic_fluent_tv_usb_20_regular = 62373
ic_fluent_umbrella_20_filled = 62374
ic_fluent_umbrella_20_regular = 62375
ic_fluent_uninstall_app_20_filled = 62376
ic_fluent_uninstall_app_20_regular = 62377
ic_fluent_usb_plug_20_filled = 62378
ic_fluent_usb_plug_20_regular = 62379
ic_fluent_usb_stick_20_filled = 62380
ic_fluent_usb_stick_20_regular = 62381
ic_fluent_vault_20_filled = 62382
ic_fluent_vault_20_regular = 62383
ic_fluent_vehicle_bicycle_20_filled = 62384
ic_fluent_vehicle_bicycle_20_regular = 62385
ic_fluent_vehicle_bus_20_filled = 62386
ic_fluent_vehicle_bus_20_regular = 62387
ic_fluent_vehicle_cab_20_filled = 62388
ic_fluent_vehicle_cab_20_regular = 62389
ic_fluent_vehicle_cable_car_20_filled = 62390
ic_fluent_vehicle_cable_car_20_regular = 62391
ic_fluent_vehicle_car_20_filled = 62392
ic_fluent_vehicle_car_20_regular = 62393
ic_fluent_vehicle_car_collision_20_filled = 62394
ic_fluent_vehicle_car_collision_20_regular = 62395
ic_fluent_vehicle_car_parking_20_filled = 62396
ic_fluent_vehicle_car_parking_20_regular = 62397
ic_fluent_vehicle_car_profile_20_filled = 62398
ic_fluent_vehicle_car_profile_20_regular = 62399
ic_fluent_vehicle_car_profile_ltr_20_filled = 62400
ic_fluent_vehicle_car_profile_ltr_20_regular = 62401
ic_fluent_vehicle_car_profile_ltr_clock_20_filled = 62402
ic_fluent_vehicle_car_profile_ltr_clock_20_regular = 62403
ic_fluent_vehicle_car_profile_rtl_20_filled = 62404
ic_fluent_vehicle_car_profile_rtl_20_regular = 62405
ic_fluent_vehicle_motorcycle_20_filled = 62406
ic_fluent_vehicle_motorcycle_20_regular = 62407
ic_fluent_vehicle_ship_20_filled = 62408
ic_fluent_vehicle_ship_20_regular = 62409
ic_fluent_vehicle_subway_20_filled = 62410
ic_fluent_vehicle_subway_20_regular = 62411
ic_fluent_vehicle_subway_clock_20_filled = 62412
ic_fluent_vehicle_subway_clock_20_regular = 62413
ic_fluent_vehicle_tractor_20_filled = 62414
ic_fluent_vehicle_tractor_20_regular = 62415
ic_fluent_vehicle_truck_20_filled = 62416
ic_fluent_vehicle_truck_20_regular = 62417
ic_fluent_vehicle_truck_bag_20_filled = 62418
ic_fluent_vehicle_truck_bag_20_regular = 62419
ic_fluent_vehicle_truck_checkmark_20_filled = 62420
ic_fluent_vehicle_truck_checkmark_20_regular = 62421
ic_fluent_vehicle_truck_cube_20_filled = 62422
ic_fluent_vehicle_truck_cube_20_regular = 62423
ic_fluent_vehicle_truck_profile_20_filled = 62424
ic_fluent_vehicle_truck_profile_20_regular = 62425
ic_fluent_video_20_filled = 62426
ic_fluent_video_20_regular = 62427
ic_fluent_video_360_20_filled = 62428
ic_fluent_video_360_20_regular = 62429
ic_fluent_video_360_off_20_filled = 62430
ic_fluent_video_360_off_20_regular = 62431
ic_fluent_video_add_20_filled = 62432
ic_fluent_video_add_20_regular = 62433
ic_fluent_video_background_effect_20_filled = 62434
ic_fluent_video_background_effect_20_regular = 62435
ic_fluent_video_background_effect_horizontal_20_filled = 62436
ic_fluent_video_background_effect_horizontal_20_regular = 62437
ic_fluent_video_bluetooth_20_filled = 62438
ic_fluent_video_bluetooth_20_regular = 62439
ic_fluent_video_chat_20_filled = 62440
ic_fluent_video_chat_20_regular = 62441
ic_fluent_video_clip_20_filled = 62442
ic_fluent_video_clip_20_regular = 62443
ic_fluent_video_clip_multiple_20_filled = 62444
ic_fluent_video_clip_multiple_20_regular = 62445
ic_fluent_video_clip_off_20_filled = 62446
ic_fluent_video_clip_off_20_regular = 62447
ic_fluent_video_clip_optimize_20_filled = 62448
ic_fluent_video_clip_optimize_20_regular = 62449
ic_fluent_video_clip_wand_20_filled = 62450
ic_fluent_video_clip_wand_20_regular = 62451
ic_fluent_video_multiple_20_filled = 62452
ic_fluent_video_multiple_20_regular = 62453
ic_fluent_video_off_20_filled = 62454
ic_fluent_video_off_20_regular = 62455
ic_fluent_video_person_20_filled = 62456
ic_fluent_video_person_20_regular = 62457
ic_fluent_video_person_call_20_filled = 62458
ic_fluent_video_person_call_20_regular = 62459
ic_fluent_video_person_clock_20_filled = 62460
ic_fluent_video_person_clock_20_regular = 62461
ic_fluent_video_person_off_20_filled = 62462
ic_fluent_video_person_off_20_regular = 62463
ic_fluent_video_person_pulse_20_filled = 62464
ic_fluent_video_person_pulse_20_regular = 62465
ic_fluent_video_person_sparkle_20_filled = 62466
ic_fluent_video_person_sparkle_20_regular = 62467
ic_fluent_video_person_sparkle_off_20_filled = 62468
ic_fluent_video_person_sparkle_off_20_regular = 62469
ic_fluent_video_person_star_20_filled = 62470
ic_fluent_video_person_star_20_regular = 62471
ic_fluent_video_person_star_off_20_filled = 62472
ic_fluent_video_person_star_off_20_regular = 62473
ic_fluent_video_play_pause_20_filled = 62474
ic_fluent_video_play_pause_20_regular = 62475
ic_fluent_video_prohibited_20_filled = 62476
ic_fluent_video_prohibited_20_regular = 62477
ic_fluent_video_recording_20_filled = 62478
ic_fluent_video_recording_20_regular = 62479
ic_fluent_video_security_20_filled = 62480
ic_fluent_video_security_20_regular = 62481
ic_fluent_video_settings_20_filled = 62482
ic_fluent_video_settings_20_regular = 62483
ic_fluent_video_switch_20_filled = 62484
ic_fluent_video_switch_20_regular = 62485
ic_fluent_video_sync_20_filled = 62486
ic_fluent_video_sync_20_regular = 62487
ic_fluent_video_usb_20_filled = 62488
ic_fluent_video_usb_20_regular = 62489
ic_fluent_view_desktop_20_filled = 62490
ic_fluent_view_desktop_20_regular = 62491
ic_fluent_view_desktop_mobile_20_filled = 62492
ic_fluent_view_desktop_mobile_20_regular = 62493
ic_fluent_virtual_network_20_filled = 62494
ic_fluent_virtual_network_20_regular = 62495
ic_fluent_virtual_network_toolbox_20_filled = 62496
ic_fluent_virtual_network_toolbox_20_regular = 62497
ic_fluent_voicemail_20_filled = 62498
ic_fluent_voicemail_20_regular = 62499
ic_fluent_voicemail_arrow_back_20_filled = 62500
ic_fluent_voicemail_arrow_back_20_regular = 62501
ic_fluent_voicemail_arrow_forward_20_filled = 62502
ic_fluent_voicemail_arrow_forward_20_regular = 62503
ic_fluent_voicemail_arrow_subtract_20_filled = 62504
ic_fluent_voicemail_arrow_subtract_20_regular = 62505
ic_fluent_voicemail_shield_20_filled = 62506
ic_fluent_voicemail_shield_20_regular = 62507
ic_fluent_voicemail_subtract_20_filled = 62508
ic_fluent_voicemail_subtract_20_regular = 62509
ic_fluent_vote_20_filled = 62510
ic_fluent_vote_20_regular = 62511
ic_fluent_walkie_talkie_20_filled = 62512
ic_fluent_walkie_talkie_20_regular = 62513
ic_fluent_wallet_20_filled = 62514
ic_fluent_wallet_20_regular = 62515
ic_fluent_wallet_credit_card_20_filled = 62516
ic_fluent_wallet_credit_card_20_regular = 62517
ic_fluent_wallpaper_20_filled = 62518
ic_fluent_wallpaper_20_regular = 62519
ic_fluent_wand_20_filled = 62520
ic_fluent_wand_20_regular = 62521
ic_fluent_warning_20_filled = 62522
ic_fluent_warning_20_regular = 62523
ic_fluent_warning_lock_open_20_filled = 62524
ic_fluent_warning_lock_open_20_regular = 62525
ic_fluent_warning_shield_20_filled = 62526
ic_fluent_warning_shield_20_regular = 62527
ic_fluent_washer_20_filled = 62528
ic_fluent_washer_20_regular = 62529
ic_fluent_water_20_filled = 62530
ic_fluent_water_20_regular = 62531
ic_fluent_weather_blowing_snow_20_filled = 62532
ic_fluent_weather_blowing_snow_20_regular = 62533
ic_fluent_weather_cloudy_20_filled = 62534
ic_fluent_weather_cloudy_20_regular = 62535
ic_fluent_weather_drizzle_20_filled = 62536
ic_fluent_weather_drizzle_20_regular = 62537
ic_fluent_weather_duststorm_20_filled = 62538
ic_fluent_weather_duststorm_20_regular = 62539
ic_fluent_weather_fog_20_filled = 62540
ic_fluent_weather_fog_20_regular = 62541
ic_fluent_weather_hail_day_20_filled = 62542
ic_fluent_weather_hail_day_20_regular = 62543
ic_fluent_weather_hail_night_20_filled = 62544
ic_fluent_weather_hail_night_20_regular = 62545
ic_fluent_weather_haze_20_filled = 62546
ic_fluent_weather_haze_20_regular = 62547
ic_fluent_weather_moon_20_filled = 62548
ic_fluent_weather_moon_20_regular = 62549
ic_fluent_weather_moon_off_20_filled = 62550
ic_fluent_weather_moon_off_20_regular = 62551
ic_fluent_weather_partly_cloudy_day_20_filled = 62552
ic_fluent_weather_partly_cloudy_day_20_regular = 62553
ic_fluent_weather_partly_cloudy_night_20_filled = 62554
ic_fluent_weather_partly_cloudy_night_20_regular = 62555
ic_fluent_weather_rain_20_filled = 62556
ic_fluent_weather_rain_20_regular = 62557
ic_fluent_weather_rain_showers_day_20_filled = 62558
ic_fluent_weather_rain_showers_day_20_regular = 62559
ic_fluent_weather_rain_showers_night_20_filled = 62560
ic_fluent_weather_rain_showers_night_20_regular = 62561
ic_fluent_weather_rain_snow_20_filled = 62562
ic_fluent_weather_rain_snow_20_regular = 62563
ic_fluent_weather_snow_20_filled = 62564
ic_fluent_weather_snow_20_regular = 62565
ic_fluent_weather_snow_shower_day_20_filled = 62566
ic_fluent_weather_snow_shower_day_20_regular = 62567
ic_fluent_weather_snow_shower_night_20_filled = 62568
ic_fluent_weather_snow_shower_night_20_regular = 62569
ic_fluent_weather_snowflake_20_filled = 62570
ic_fluent_weather_snowflake_20_regular = 62571
ic_fluent_weather_squalls_20_filled = 62572
ic_fluent_weather_squalls_20_regular = 62573
ic_fluent_weather_sunny_20_filled = 62574
ic_fluent_weather_sunny_20_regular = 62575
ic_fluent_weather_sunny_high_20_filled = 62576
ic_fluent_weather_sunny_high_20_regular = 62577
ic_fluent_weather_sunny_low_20_filled = 62578
ic_fluent_weather_sunny_low_20_regular = 62579
ic_fluent_weather_thunderstorm_20_filled = 62580
ic_fluent_weather_thunderstorm_20_regular = 62581
ic_fluent_web_asset_20_filled = 62582
ic_fluent_web_asset_20_regular = 62583
ic_fluent_whiteboard_20_filled = 62584
ic_fluent_whiteboard_20_regular = 62585
ic_fluent_whiteboard_off_20_filled = 62586
ic_fluent_whiteboard_off_20_regular = 62587
ic_fluent_wifi_1_20_filled = 62588
ic_fluent_wifi_1_20_regular = 62589
ic_fluent_wifi_2_20_filled = 62590
ic_fluent_wifi_2_20_regular = 62591
ic_fluent_wifi_3_20_filled = 62592
ic_fluent_wifi_3_20_regular = 62593
ic_fluent_wifi_4_20_filled = 62594
ic_fluent_wifi_4_20_regular = 62595
ic_fluent_wifi_lock_20_filled = 62596
ic_fluent_wifi_lock_20_regular = 62597
ic_fluent_wifi_off_20_filled = 62598
ic_fluent_wifi_off_20_regular = 62599
ic_fluent_wifi_settings_20_filled = 62600
ic_fluent_wifi_settings_20_regular = 62601
ic_fluent_wifi_warning_20_filled = 62602
ic_fluent_wifi_warning_20_regular = 62603
ic_fluent_window_20_filled = 62604
ic_fluent_window_20_regular = 62605
ic_fluent_window_ad_20_filled = 62606
ic_fluent_window_ad_20_regular = 62607
ic_fluent_window_ad_off_20_filled = 62608
ic_fluent_window_ad_off_20_regular = 62609
ic_fluent_window_ad_person_20_filled = 62610
ic_fluent_window_ad_person_20_regular = 62611
ic_fluent_window_apps_20_filled = 62612
ic_fluent_window_apps_20_regular = 62613
ic_fluent_window_arrow_up_20_filled = 62614
ic_fluent_window_arrow_up_20_regular = 62615
ic_fluent_window_brush_20_filled = 62616
ic_fluent_window_brush_20_regular = 62617
ic_fluent_window_bullet_list_20_filled = 62618
ic_fluent_window_bullet_list_20_regular = 62619
ic_fluent_window_bullet_list_add_20_filled = 62620
ic_fluent_window_bullet_list_add_20_regular = 62621
ic_fluent_window_column_one_fourth_left_20_filled = 62622
ic_fluent_window_column_one_fourth_left_20_regular = 62623
ic_fluent_window_column_one_fourth_left_focus_left_20_filled = 62624
ic_fluent_window_column_one_fourth_left_focus_top_20_filled = 62625
ic_fluent_window_console_20_filled = 62626
ic_fluent_window_console_20_regular = 62627
ic_fluent_window_database_20_filled = 62628
ic_fluent_window_database_20_regular = 62629
ic_fluent_window_dev_edit_20_filled = 62630
ic_fluent_window_dev_edit_20_regular = 62631
ic_fluent_window_dev_tools_20_filled = 62632
ic_fluent_window_dev_tools_20_regular = 62633
ic_fluent_window_edit_20_filled = 62634
ic_fluent_window_edit_20_regular = 62635
ic_fluent_window_fingerprint_20_filled = 62636
ic_fluent_window_fingerprint_20_regular = 62637
ic_fluent_window_header_horizontal_20_filled = 62638
ic_fluent_window_header_horizontal_20_regular = 62639
ic_fluent_window_header_horizontal_off_20_filled = 62640
ic_fluent_window_header_horizontal_off_20_regular = 62641
ic_fluent_window_header_vertical_20_filled = 62642
ic_fluent_window_header_vertical_20_regular = 62643
ic_fluent_window_inprivate_20_filled = 62644
ic_fluent_window_inprivate_20_regular = 62645
ic_fluent_window_inprivate_account_20_filled = 62646
ic_fluent_window_inprivate_account_20_regular = 62647
ic_fluent_window_location_target_20_filled = 62648
ic_fluent_window_location_target_20_regular = 62649
ic_fluent_window_multiple_20_filled = 62650
ic_fluent_window_multiple_20_regular = 62651
ic_fluent_window_multiple_swap_20_filled = 62652
ic_fluent_window_multiple_swap_20_regular = 62653
ic_fluent_window_new_20_filled = 62654
ic_fluent_window_new_20_regular = 62655
ic_fluent_window_play_20_filled = 62656
ic_fluent_window_play_20_regular = 62657
ic_fluent_window_settings_20_filled = 62658
ic_fluent_window_settings_20_regular = 62659
ic_fluent_window_shield_20_filled = 62660
ic_fluent_window_shield_20_regular = 62661
ic_fluent_window_text_20_filled = 62662
ic_fluent_window_text_20_regular = 62663
ic_fluent_window_wrench_20_filled = 62664
ic_fluent_window_wrench_20_regular = 62665
ic_fluent_wrench_20_filled = 62666
ic_fluent_wrench_20_regular = 62667
ic_fluent_wrench_screwdriver_20_filled = 62668
ic_fluent_wrench_screwdriver_20_regular = 62669
ic_fluent_wrench_settings_20_filled = 62670
ic_fluent_wrench_settings_20_regular = 62671
ic_fluent_xbox_console_20_filled = 62672
ic_fluent_xbox_console_20_regular = 62673
ic_fluent_xbox_controller_20_filled = 62674
ic_fluent_xbox_controller_20_regular = 62675
ic_fluent_xbox_controller_error_20_filled = 62676
ic_fluent_xbox_controller_error_20_regular = 62677
ic_fluent_xray_20_filled = 62678
ic_fluent_xray_20_regular = 62679
ic_fluent_zoom_fit_20_filled = 62680
ic_fluent_zoom_fit_20_regular = 62681
ic_fluent_zoom_in_20_filled = 62682
ic_fluent_zoom_in_20_regular = 62683
ic_fluent_zoom_out_20_filled = 62684
ic_fluent_zoom_out_20_regular = 62685
